@@ -1,7 +1,52 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
 * Prototyping the default Date object
-*
-*@author Michael Erkens <m.erkens@connectux.com>
 */
 
 
@@ -39,11 +84,12 @@ Date.prototype.getDaysInMonth = function(month, year)
 
 
 /**
- * Function will add one or more days to current date.
+ * Function will add one or more days to current date
+ * @param	integer		dayCount	number of days to add
  */
 Date.prototype.addDays = function(dayCount)
 {
-	if (!dayCount) {
+	if (typeof dayCount == "undefined" || dayCount === null || dayCount === false) {
 		dayCount = 1;
 	}
 	
@@ -52,7 +98,53 @@ Date.prototype.addDays = function(dayCount)
 	var newOffset = this.getTimezoneOffset();
 	
 	this.setTime(this.getTime()+((newOffset-oldOffset)*60000));
-} 
+}
+
+/**
+ * Function will add one or more hours to current time (timezone/dst safe)
+ * @param	integer		hourCount	number of hours to add
+ */
+Date.prototype.addHours = function(hourCount)
+{
+	if (typeof hourCount == "undefined" || hourCount === null || hourCount === false) {
+		hourCount = 1;
+	}
+
+	var oldOffset = this.getTimezoneOffset();
+	this.setTime(this.getTime() + (ONE_HOUR * hourCount));
+	var newOffset = this.getTimezoneOffset();
+
+	this.setTime(this.getTime() + ((newOffset - oldOffset) * 60000));
+}
+
+/**
+ * Function will add timestamp to date object (timezone/dst safe)
+ * @param	integer		unixTimestampToAdd	unixtimestamp in seconds
+ */
+Date.prototype.addUnixTimeStampToDate = function(unixTimeStampToAdd)
+{
+	// convert timestamp into miliseconds from seconds
+	unixTimeStampToAdd = unixTimeStampToAdd * 1000;
+
+	var oldOffset = this.getTimezoneOffset();
+	this.setTime(this.getTime() + unixTimeStampToAdd);
+	var newOffset = this.getTimezoneOffset();
+
+	this.setTime(this.getTime() + ((newOffset - oldOffset) * 60000));
+}
+
+/**
+ * Function will add one or more months to current date
+ * @param	integer		dayCount	number of months to add
+ */
+Date.prototype.addMonths = function(monthCount)
+{
+	if (typeof monthCount == "undefined" || monthCount === null || monthCount === false) {
+		monthCount = 1;
+	}
+
+	this.setMonth(this.getMonth() + monthCount);
+}
 
 /**
  * Function which verifies if the given year is a leap year.
@@ -249,35 +341,45 @@ function timeToZero(unixtimestamp)
 
 /**
  * Function will convert time "1:40" to seconds "6000" 
+ * If time format is in AM/PM format then it converts "1:40 PM" to "49200" sedonds
  */
 function timeToSeconds(value)
 {
-	value = value.split(":");
-	var hour = parseInt(value[0], 10);
-	var min = parseInt(value[1], 10);
-	return ((hour*60)+min)*60;
+	// Get current date.
+	var tempDate = new Date();
+	/**
+	 * For using parseDate function for parsing date in am/pm or 24hr format one should have complete Date string, 
+	 * here only time values is passed to the function so create one dummy Date object,
+	 * and using dummy object and time from the form parameter, use parseDate function and let it do all formating work.
+	 * parseDate function will return a new Date object, using it get timeInSeconds
+	 * and Using new Date object get the value
+	 */
+	// parseDate function works with Date value so create current datetime string
+	var tempDateTimeStr = tempDate.getDate() + "-" + tempDate.getMonth() + "-" + tempDate.getYear() + " " + value;
+
+	// Set the timeformat for parsing.
+	var format = "%d-%m-%Y "+_("%H:%M");
+	// Get the date object for specific hour and minutes
+	var newDate = Date.parseDate(tempDateTimeStr, format, false);
+	var timeInSeconds = ((newDate.getHours() * 60) + newDate.getMinutes()) * 60;
+
+	return timeInSeconds;
 }
 
 /**
  * Function will convert seconds "6000" to time "1:40"
+ * If time format is in AM/PM format then it converts "49200" seconds to "1:40 PM"
  * @param value = int time in seconds
  * @param fourDigit = boolean true for "01:40" or false for "1:40"  
  */
 function secondsToTime(value,fourDigit)
 {
-	var minutes = parseInt(value/60);
-	var hours = parseInt(minutes/60);
-	var result;
-	
-	minutes = minutes - (hours*60);	
-	
-	if(fourDigit == false){
-		result = hours+":"+minutes;
-	}
-	else{
-		result = (hours<10?"0":"")+hours+":"+(minutes<10?"0":"")+minutes;
-	}
-	
+	// Get current Date and time and set its time to zero
+	var tempDate = new Date();
+	value += timeToZero(tempDate.getTime()/1000);
+
+	// Add time in to today's time stamp and return it.
+	result = strftime(_('%H:%M'),value).toUpperCase();
 	return result
 }
 
@@ -477,3 +579,77 @@ function strftime_gmt(format,timestamp) {
 
 	return t.strftime_gmt(format);
 }
+
+/**
+ * global function to add number of days in unixtimestamp (dst/timezone safe)
+ * @param	integer		baseUnixTimestamp	timestamp to use for adding days
+ * @param	integer		dayCount			number of days to add
+ * @return	integer							timestamp after adding day
+ */
+function addDaysToUnixTimeStamp(baseUnixTimeStamp, dayCount) {
+	var dateObj = new Date(baseUnixTimeStamp * 1000);
+	dateObj.addDays(dayCount);
+
+	return (dateObj.getTime() / 1000);
+}
+
+/**
+ * global function to add number of hours in unixtimestamp (dst/timezone safe)
+ * @param	integer		baseUnixTimestamp	timestamp to use for adding days
+ * @param	integer		hourCount			number of hours to add
+ * @return	integer							timestamp after adding day
+ */
+function addHoursToUnixTimeStamp(baseUnixTimeStamp, hourCount) {
+	var dateObj = new Date(baseUnixTimeStamp * 1000);
+	dateObj.addHours(hourCount);
+
+	return (dateObj.getTime() / 1000);
+}
+
+/**
+ * global function to add unixtimestamp to unixtimestamp (dst/timezone safe)
+ * @param	integer		baseUnixTimestamp	timestamp to use for adding another timestamp
+ * @param	integer		unixTimeStampToAdd	timestamp to add
+ * @return	integer							timestamp after adding another timestamp
+ */
+function addUnixTimestampToUnixTimeStamp(baseUnixTimeStamp, unixTimeStampToAdd) {
+	var dateObj = new Date(baseUnixTimeStamp * 1000);
+	dateObj.addUnixTimeStampToDate(unixTimeStampToAdd);
+
+	return (dateObj.getTime() / 1000);
+}
+
+/**
+ * global function to get date range of a particular week from week number
+ * @param	integer		weekNo		week number of week
+ * @return	Object					timestamp of start and end date of week
+ * @TODO check DST
+ */
+function getDateRangeOfWeek(weekNo) {
+	var currentDate = new Date();
+	var result = new Object();
+
+	if(typeof weekNo == "undefined" || weekNo === null || weekNo === false) {
+		weekNo = currentDate.getWeekNumber();
+	}
+
+	// set current day as monday
+	var numOfDaysPastSinceLastMonday = currentDate.getDay() - 1;
+	currentDate.addDays(-numOfDaysPastSinceLastMonday);
+
+	// find difference between current week number and supplied week number
+	var currentWeekNo = currentDate.getWeekNumber();
+	var weeksInTheFuture = weekNo - currentWeekNo;
+
+	// add days difference to current week
+	if(weeksInTheFuture !== 0) {
+		currentDate.addDays(7 * weeksInTheFuture);
+	}
+	result["week_start_date"] = timeToZero(currentDate.getTime() / 1000);
+
+	// add 6 days to get end of week
+	currentDate.addDays(6);
+	result["week_end_date"] = timeToZero(currentDate.getTime() / 1000);
+
+	return result;
+}
