@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * LayoutManager
  * This object is responisble for managing the layout. It has three 
@@ -293,14 +340,14 @@ LayoutManager.prototype.setFooter = function()
 	settings.innerHTML = _("settings");
 	loggedon.appendChild(settings);
 
-	var seperator2 = document.createElement("span");
-	seperator2.innerHTML = "&nbsp;<b>&#183;</b>&nbsp;";
-	loggedon.appendChild(seperator2);
+	if (!SSO_LOGIN) {
+		var seperator2 = document.createElement("span");
+		seperator2.innerHTML = "&nbsp;<b>&#183;</b>&nbsp;";
+		loggedon.appendChild(seperator2);
 
-	var logout = document.createElement("a");
-	logout.href = "index.php?logout";
-	logout.innerHTML = _("log out");
-	loggedon.appendChild(logout);
+		var logout = dhtml.addElement(loggedon, "span", "loggoutbutton", false, _("log out"));
+		dhtml.addEvent(-1, logout, "click", eventLogout);
+	}
 }
 
 /**
@@ -343,7 +390,7 @@ function eventBodyResizePanesMouseUp(moduleObject, element, event)
 		}
 		
 		
-		webclient.settings.set("global/sizeinpercent", true);
+		webclient.settings.set("global/sizeinpercent", "true");
 	}
 	
 	//remove div element over the webaccess.
@@ -369,7 +416,15 @@ function eventResizePanes(moduleObject, element, event)
 	var left = dhtml.getElementById("left");
 	if(left){
 		if (webclient.settings.get("global/sizeinpercent", false)){
-			left.style.width = parseFloat(webclient.settings.get("global/hierarchylistwidth", 0.15)) * parseFloat(windowWidth) + "px";
+			var hierarchyListWidth = parseFloat(webclient.settings.get("global/hierarchylistwidth", 0.15));
+			if(hierarchyListWidth > 0.5) {
+				/** 
+				 * width of hierarchy list can not be greater than 50%,
+				 * if incase its greater than 50% then set it to its default value
+				 */
+				hierarchyListWidth = 0.15;
+			}
+			left.style.width = hierarchyListWidth * parseFloat(windowWidth) + "px";
 		} else {
 			left.style.width = parseInt(windowWidth * 0.15) + "px";
 		}
@@ -626,4 +681,13 @@ LayoutManager.prototype.removeAllresizebars = function (position)
 			dhtml.deleteElement(child);
 		}
 	}
+}
+/**
+ * Function which logout from WA.
+ */
+function eventLogout(moduleObject, element, event)
+{
+	// Abort all xml requests whoes response is not yet received
+	webclient.xmlrequest.abortAll();
+	window.location = "index.php?logout";
 }
\ No newline at end of file
