@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
 * Adding trim function to the String class
 */
@@ -28,7 +75,6 @@ String.prototype.htmlEntities = function()
  *
  * Original by Jonas Raoni Soares Silva (http://jsfromhell.com/string/wordwrap)
  * Modified by nkallen (http://snippets.dzone.com/posts/show/869)
- * Modified by M. Erkens (m.erkens@zarafa.com)
  */
 String.prototype.wordWrap = function(maxLength, breakWidth, cutWords){
 	var i, j, s, result = this.split("\n");
@@ -127,18 +173,16 @@ String.prototype.sprintf = function()
  * and return it.
  */
 function uniqueArray(array){
-	if(!array) return;
-
-	var arr = new Array();
-	for(var i = 0, n = array.length; i < n; i++){
-		for(var x = 0, y = arr.length; x < y; x++){
-			if(arr[x]==array[i]){
-				continue;
-			}
-		}
-		arr[arr.length] = array[i];
+	var obj = new Object();
+	var i, arrElem;
+	for (i = 0; arrElem = array[i]; i++) {
+		obj[arrElem] = 1;
 	}
-	return arr;
+	var resultArr = new Array();
+	for (arrElem in obj) {
+		resultArr.push (arrElem);
+	}
+	return resultArr;
 }
 
 // sorting select boxes
@@ -165,10 +209,10 @@ function sortSelectBox(element)
 
 /**
  * Function will make long notation of e-mail address
- * @param name = "string" like: "Frans van Veen"
- * @param email = "string" like: "f.vanveen@zarafa.com"
- * @param html = "bool" true will return &lg;f.vanveen@zarafa.com&gt; 
- * @return "string" like: "Frans van Veen <f.vanveen@zarafa.com>" 
+ * @param name = "string" like: "John Doe"
+ * @param email = "string" like: "john.doe@foo.com"
+ * @param html = "bool" true will return &lg;john.doe@foo.com&gt; 
+ * @return "string" like: "John Doe <john.doe@foo.com>" 
  */
 function nameAndEmailToString(name,email,html)
 {
@@ -308,7 +352,6 @@ function getType(variable)
 *
 *@param object element The DOM element to convert
 *@returns Object-array
-*@author Michael Erkens <michael@connectux.com>
 */
 function dom2array(element)
 {
@@ -512,7 +555,7 @@ function validateEmailAddress(fieldString, forceSingleAddress, suppressPopupMsg)
 	for(i in data){
 		// check e-mail address
 		var email = data[i].trim();
-		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9=_\+\.\-\'])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$/i);
+		var filter = new RegExp(/^([^<]*<){0,1}(([a-z0-9=_\+\.\-\'\/])+\@(([a-z0-9\-])+\.)+([a-z0-9]{2,5})+)>{0,1}$/i);
 		if(email.length > 0 && !filter.test(email)){
 			result += "\n"+email;
 		}
@@ -598,6 +641,30 @@ function iconIndexToClassName(icon_index,messageClass, isRead)
 		case 1024:
 			className += "icon_appointment";
 			break;
+		case 1025:
+			className += "icon_appointment_recurring";		
+			break;
+		case 1027:
+			className += "icon_meeting_recurring";		
+			break;
+		case 1028:
+			className += "icon_meetingrequest";
+			break;
+		case 1029:
+			className += "icon_meetingrequest_pos";
+			break;
+		case 1030:
+			className += "icon_meetingrequest_neg";
+			break;
+		case 1031:
+			className += "icon_meetingrequest_tent";
+			break;
+		case 1032:
+			className += "icon_meetingrequest_canceled";		
+			break;
+		case 1033:
+			className += "icon_meetingrequest_outofdate";
+			break;
 		default:
 			switch(messageClass){
 				case "IPM.Appointment":
@@ -673,7 +740,7 @@ function convertPlainToHtml(content)
 	content = content.replace(/(^|\b|\s)(mailto:){0,1}([a-z0-9_'+*$%\^&!\.\-]+\@(?:[a-z0-9\-]+\.)+[a-z]{2,})(\?subject=[a-z0-9\+\%]+){0,1}($|[\s,;>\]\)])/ig, "$1<a href=\"mailto:$3$4\" onclick=\"parent.eventReadmailClickEmail(false,this,\'click\');return false;\">$3$4</a>$5");
 
 	// url
-	content = content.replace(/(((https{0,1}|ftp):\/\/([a-z0-9\-\_]+@){0,1}|www\.)([a-z0-9\-]+[a-z0-9\.]*)+\.[a-z0-9]+(:[0-9]{1,5}){0,1}(\/[a-z0-9\-_#&@\?=%+;:\.\[\]~\$!\*'\(\),\{\}|\^`]*)*)/ig, "<a href=\"$1\" target=\"_blank\">$1</a>");
+	content = content.replace(/(((https{0,1}|ftp):\/\/([a-z0-9\-\_]+@){0,1}|www\.)([a-z0-9\-]+[a-z0-9\.]*)+\.?[a-z0-9]+(:[0-9]{1,5}){0,1}(\/[a-z0-9\-_#&@\?=%+;:\.\[\]~\$!\*'\(\),\{\}|\^`]*)*)/ig, "<a href=\"$1\" target=\"_blank\">$1</a>");
 	content = content.replace(/(<a href\=\"www)/ig, "<a href=\"http://www");
 		
 	return content;
@@ -681,9 +748,14 @@ function convertPlainToHtml(content)
 
 function convertAnchors(content)
 {
-    content = content.replace(/<a href=\"#(.*)\"/gi, "<a target=\"_self\" href=\"javascript:parent.DHTML.prototype.scrollFrame('html_body', '$1');\"");
-    
-    return content;
+	/**
+	 * TODO: enhance this regular expression
+	 * It matches all anchor tags instead it should only match if href is specified that starts with '#' tag
+	 * and it should also preserve name, target, class etc attributes.
+	 */
+	content = content.replace(/<a(.*?)(href=\"[ \s]*#[\s]*(.*?)\"(.*?))>/gi, "<a $1 target=\"_self\" href=\"javascript:parent.DHTML.prototype.scrollFrame('html_body', '$3');\" $4>");
+
+	return content;
 }
 
 function removeTagFromSource(content, tagName, closingTag, saveDocOnNoClosingTag){
@@ -863,14 +935,14 @@ function buildDOM(root, type)
 /**
  * Function which returns true, if object is Array()
  * @param object Object
- * @return boolean true if object is Array otherwise false if not.
+ * @return boolean true if object is Array otherwise false.
  */
 function isArray(object)
 {
 	if (object == "undefined" || object.constructor.toString().indexOf("Array") == -1)
-      return false;
-   else
-      return true;
+		return false;
+	else
+		return true;
 }
 /**
  * Function which returns true, if needle is found in the array
@@ -886,4 +958,319 @@ function inArray(needle, haystack)
 		}
 	}
 	return false;
-}
\ No newline at end of file
+}
+/**
+ * Function which generates random strings with default length of 8.
+ * @param integer length -length of random string to be generated
+ * @return string -random string
+ */
+function generateRandomString(length) {
+	var chars = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXTZabcdefghiklmnopqrstuvwxyz";
+	var randomstring = "";
+	for (var i=0; i<length; i++) {
+		var rnum = Math.floor(Math.random() * chars.length);
+		randomstring += chars.substring(rnum,rnum+1);
+	}
+	return randomstring;
+}
+
+/**
+ * Function which converts HTML text to PLAIN text
+ * @param string content -html text
+ * @return string -plain text
+ */
+function convertHtmlToPlain(content)
+{
+	//strip all unwanted tags
+	content = strip_tags( content, '<title><hr><h1><h2><h3><h4><h5><h6><div><p><pre><sup><ul><ol><dl><dt><table><caption><tr><li><dd><th><td><a><area><img><form><input><textarea><button><select><option>' );
+	//remove all options from select inputs
+	content = content.replace( /<option[^>]*>[^<]*/i, '');
+	//remove all breaklines
+	content = content.replace( /<br>[^<]*/i, '\n');
+	//replace all tags with their text equivalents
+	content = content.replace( /<(h|div|p)[^>]*>/i, "\n\n");
+	content = content.replace( /<(ul|ol|br|dl|dt|table|caption|\/textarea|tr[^>]*>\s*<(td|th))[^>]*>/i, "\n");
+	content = content.replace( /<li[^>]*>/i, "\n ");
+	content = content.replace( /<dd[^>]*>/i, "\n\t");
+	content = content.replace( /<(th|td)[^>]*>/i, "\t");
+	content = content.replace( /<a[^>]* href=(\"((?!\"|#|javascript:)[^\"#]*)(\"|#)|'((?!'|#|javascript:)[^'#]*)('|#)|((?!'|\"|>|#|javascript:)[^#\"'> ]*))[^>]*>/i, " ");
+	//convert html entities
+	content = html_entity_decode(content);
+	//remove remaining html entities
+	content = content.replace( /([&][a-zA-Z]*[;])/g, "");	
+	//remove extra newlines
+	content = content.replace( /[\n]+/g, "\n");
+
+	return content;
+}
+
+/**
+ * Function which strips specified tags
+ * @param string str  -html text
+ * @param string tags -tags
+ * @return string -string after removing tags
+ */
+function strip_tags(str, tags) {
+	
+	var key = '', tag = '', allowed = false;
+	var matches = allowed_array = new Array();
+	var allowed_keys = new Object();
+	
+	var replacer = function(search, replace, str) {
+		var tmp_arr = new Array();
+		tmp_arr = str.split(search);
+		return tmp_arr.join(replace);
+	};
+	
+	// Build allowes tags associative array
+	if (tags) {
+		tags  = tags.replace(/[^a-zA-Z,]+/g, '');;
+		allowed_array = tags.split(',');
+	}
+	
+	// Match tags
+	matches = str.match(/(<\/?[^>]+>)/gi);
+	
+	// Go through all HTML tags 
+	for (key in matches) {
+		if (isNaN(key)) {
+			// IE7 Hack
+			continue;
+		}
+		
+		// Save HTML tag
+		html = matches[key].toString();
+		
+		// Is tag not in allowed list? Remove from str!
+		allowed = false;
+		
+		// Go through all allowed tags
+		for (k in allowed_array) {
+			// Init    
+			allowed_tag = allowed_array[k];
+			i = -1;
+			
+			if (i != 0) { i = html.toLowerCase().indexOf('<'+allowed_tag+'>');}
+			if (i != 0) { i = html.toLowerCase().indexOf('<'+allowed_tag+' ');}
+			if (i != 0) { i = html.toLowerCase().indexOf('</'+allowed_tag)   ;}
+			
+			// Determine
+			if (i == 0) {
+				allowed = true;
+				break;
+			}
+		}
+		
+		if (!allowed) {
+			str = replacer(html, "\n", str); // Custom replace. No regexing
+		}
+	}
+	
+	return str;
+}
+
+
+/**
+ * Function which converts HTML entities
+ * into plain text.
+ * @param String string
+ * @return String with 
+ */
+function html_entity_decode( string ) {
+	var histogram = new Array();
+	var histogram_r = new Array();
+	var entity = chr = '', code = 0;;
+
+	histogram['34'] = 'quot';
+	histogram['38'] = 'amp';
+	histogram['60'] = 'lt';
+	histogram['62'] = 'gt';
+	histogram['153'] = 'trade';
+	histogram['160'] = 'nbsp';
+	histogram['161'] = 'iexcl';
+	histogram['162'] = 'cent';
+	histogram['163'] = 'pound';
+	histogram['164'] = 'curren';
+	histogram['165'] = 'yen';
+	histogram['166'] = 'brvbar';
+	histogram['167'] = 'sect';
+	histogram['168'] = 'uml';
+	histogram['169'] = 'copy';
+	histogram['170'] = 'ordf';
+	histogram['171'] = 'laquo';
+	histogram['172'] = 'not';
+	histogram['173'] = 'shy';
+	histogram['174'] = 'reg';
+	histogram['175'] = 'macr';
+	histogram['176'] = 'deg';
+	histogram['177'] = 'plusmn';
+	histogram['178'] = 'sup2';
+	histogram['179'] = 'sup3';
+	histogram['180'] = 'acute';
+	histogram['181'] = 'micro';
+	histogram['182'] = 'para';
+	histogram['183'] = 'middot';
+	histogram['184'] = 'cedil';
+	histogram['185'] = 'sup1';
+	histogram['186'] = 'ordm';
+	histogram['187'] = 'raquo';
+	histogram['188'] = 'frac14';
+	histogram['189'] = 'frac12';
+	histogram['190'] = 'frac34';
+	histogram['191'] = 'iquest';
+	histogram['192'] = 'Agrave';
+	histogram['193'] = 'Aacute';
+	histogram['194'] = 'Acirc';
+	histogram['195'] = 'Atilde';
+	histogram['196'] = 'Auml';
+	histogram['197'] = 'Aring';
+	histogram['198'] = 'AElig';
+	histogram['199'] = 'Ccedil';
+	histogram['200'] = 'Egrave';
+	histogram['201'] = 'Eacute';
+	histogram['202'] = 'Ecirc';
+	histogram['203'] = 'Euml';
+	histogram['204'] = 'Igrave';
+	histogram['205'] = 'Iacute';
+	histogram['206'] = 'Icirc';
+	histogram['207'] = 'Iuml';
+	histogram['208'] = 'ETH';
+	histogram['209'] = 'Ntilde';
+	histogram['210'] = 'Ograve';
+	histogram['211'] = 'Oacute';
+	histogram['212'] = 'Ocirc';
+	histogram['213'] = 'Otilde';
+	histogram['214'] = 'Ouml';
+	histogram['215'] = 'times';
+	histogram['216'] = 'Oslash';
+	histogram['217'] = 'Ugrave';
+	histogram['218'] = 'Uacute';
+	histogram['219'] = 'Ucirc';
+	histogram['220'] = 'Uuml';
+	histogram['221'] = 'Yacute';
+	histogram['222'] = 'THORN';
+	histogram['223'] = 'szlig';
+	histogram['224'] = 'agrave';
+	histogram['225'] = 'aacute';
+	histogram['226'] = 'acirc';
+	histogram['227'] = 'atilde';
+	histogram['228'] = 'auml';
+	histogram['229'] = 'aring';
+	histogram['230'] = 'aelig';
+	histogram['231'] = 'ccedil';
+	histogram['232'] = 'egrave';
+	histogram['233'] = 'eacute';
+	histogram['234'] = 'ecirc';
+	histogram['235'] = 'euml';
+	histogram['236'] = 'igrave';
+	histogram['237'] = 'iacute';
+	histogram['238'] = 'icirc';
+	histogram['239'] = 'iuml';
+	histogram['240'] = 'eth';
+	histogram['241'] = 'ntilde';
+	histogram['242'] = 'ograve';
+	histogram['243'] = 'oacute';
+	histogram['244'] = 'ocirc';
+	histogram['245'] = 'otilde';
+	histogram['246'] = 'ouml';
+	histogram['247'] = 'divide';
+	histogram['248'] = 'oslash';
+	histogram['249'] = 'ugrave';
+	histogram['250'] = 'uacute';
+	histogram['251'] = 'ucirc';
+	histogram['252'] = 'uuml';
+	histogram['253'] = 'yacute';
+	histogram['254'] = 'thorn';
+	histogram['255'] = 'yuml';
+ 
+	// Reverse table. Cause for maintainability purposes, the histogram is
+	// identical to the one in htmlentities.
+	for (code in histogram) {
+		entity = histogram[code];
+		histogram_r[entity] = code;
+	}
+ 
+	return (string+'').replace(/(\&([a-zA-Z]+)\;)/g, function(full, m1, m2){
+		if (m2 in histogram_r) {
+			return String.fromCharCode(histogram_r[m2]);
+		} else {
+			return m2;
+		}
+	});
+}
+
+/**
+ * compareEntryIds
+ * Compares two entryIds. It is possible to have two different entryIds that should match as they 
+ * represent the same object (in multiserver environments)
+ * @param String entryid1 EntryID
+ * @param String entryid2 EntryID
+ * @return Boolean Result of the comparison 
+ */
+function compareEntryIds(entryid1, entryid2){
+	var eid1 = createEntryIdObj(entryid1);
+	var eid2 = createEntryIdObj(entryid2);
+
+	if(eid1.version == eid2.version){
+
+		if(eid1.length != eid2.length)
+			return false;
+
+		if(eid1.length < eid1.MIN_LENGTH)
+			return false;
+
+		if(eid1.version == '00000000'){
+			if(eid1.id != eid2.id)
+				return false;
+		}else{
+			if(eid1.exid != eid2.exid)
+				return false;
+		}
+
+	}else{
+
+		if(eid1.length < eid1.MIN_LENGTH || eid2.length < eid2.MIN_LENGTH)
+			return false;
+
+		if(eid1.id != eid2.id)
+			return false;
+	}
+
+	if(eid1.guid != eid2.guid)
+		return false;
+
+	if(eid1.type != eid2.type)
+		return false;
+
+	return true;
+}
+/**
+ * createEntryIdObj
+ * Creates an object that has split up all the components of an entryID.
+ * @param String entryid Entryid
+ * @return Object EntryID object
+ */
+function createEntryIdObj(entryid){
+	var eidObj = {
+		flags: '',  	// BYTE[4],   4 bytes,  8 hex characters
+		guid: '',   	// GUID,     16 bytes, 32 hex characters
+		version: '',	// ULONG,     4 bytes,  8 hex characters
+		type: '',   	// ULONG,     4 bytes,  8 hex characters
+		id: '',     	// ULONG,     4 bytes,  8 hex characters
+		exid: '',   	// TCHAR[1],  1 byte,   2 hex characters
+		padding: '',	// TCHAR[3],  3 bytes,  6 hex characters
+
+		length: entryid.length,
+		MIN_LENGTH: 72
+	}
+
+	eidObj.flags = entryid.substr(0,8);
+	eidObj.guid = entryid.substr(8,32);
+	eidObj.version = entryid.substr(40,8);
+	eidObj.type = entryid.substr(48,8);
+	eidObj.id = entryid.substr(56,8);
+	eidObj.exid = entryid.slice(64,-6);
+	eidObj.padding = entryid.slice(-6);
+
+	return eidObj;
+}
