@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * WebClient
  * Object which is available for every other object. It startups the client and
@@ -14,8 +61,9 @@ function WebClient()
  * @param string modulePrefix the module prefix (used for create unique id in the XML)
  * @param object availableModules all the available modules
  * @param object settings all the settings
+ * @param object pluginData all the plugin data
  */ 
-WebClient.prototype.init = function(base_url, modulePrefix, availableModules, settings)
+WebClient.prototype.init = function(base_url, modulePrefix, availableModules, settings, pluginData)
 {
 	this.window = window;
 	this.base_url = base_url;
@@ -35,14 +83,20 @@ WebClient.prototype.init = function(base_url, modulePrefix, availableModules, se
 		this.settings = parentWebclient.settings;
 	}
 	
+	// Fire up the PluginManager, let is know about the plugins and initialize them.
+	this.pluginManager = new PluginManager();
+	this.pluginManager.setPluginData(pluginData);
+	this.pluginManager.init();
+
 	startKeepAlive();
 }
 
-WebClient.prototype.setUserInfo = function(username, fullname, entryid)
+WebClient.prototype.setUserInfo = function(username, fullname, entryid, emailaddress)
 {
 	this.username = username;
 	this.fullname = fullname;
 	this.userEntryid = entryid;
+	this.emailaddress = emailaddress;
 }
 
 
@@ -91,6 +145,17 @@ WebClient.prototype.startClient = function()
 		this.hierarchy.list(true);
 	}
 	
+	if (webclient.settings.get("global/startup/folder","inbox")=="inbox"){	
+	    // If the user has selected 'open inbox at startup', we know we want the inbox
+	    // so we can post the request here already, instead of waiting for the hierarchy module
+	    // to load.
+	    
+	    // This ignores the first event from the hierarchy module since we have already loaded that
+	    // folder
+    	this.folderOpened = true;
+    	this.openFolder();
+    }
+	
 	// start notification
 	this.notification = this.dispatcher.loadModule("notificationmodule");
 	if (this.notification) {
@@ -252,7 +317,7 @@ WebClient.prototype.getModule = function(moduleID)
 		// Loop through dialogs
 		for(var dialogname in this.dialogs){
 			if(this.dialogs[dialogname].window){
-				if(typeof this.dialogs[dialogname].window.webclient == "object"){
+				if(typeof this.dialogs[dialogname].window.webclient != "unknown" && typeof this.dialogs[dialogname].window.webclient == "object" && this.dialogs[dialogname].window.webclient != null){
 					module = this.dialogs[dialogname].window.webclient.getModule(moduleID);
 					if(module){
 						break;
@@ -418,7 +483,12 @@ WebClient.prototype.onHierarchyChangeFolder = function(storeid, folder)
 		webclient.settings.set("global/startup/folder_lastopened",folder["entryid"]);
 	}
 
-	this.openFolder(storeid, folder)
+	if(!this.folderOpened) {
+    	this.openFolder(storeid, folder);
+    }
+
+    // Any next request should trigger openFolder
+    this.folderOpened = false;
 }
 
 /**
@@ -427,17 +497,28 @@ WebClient.prototype.onHierarchyChangeFolder = function(storeid, folder)
 WebClient.prototype.openFolder = function(storeid, folder)
 {
 	var data = new Object;
+	var name;
 	
-	data["storeid"] = storeid;
-	data["entryid"] = folder["entryid"];
-	
-	var moduleName = folder["container_class"].substring(folder["container_class"].indexOf(".") + 1).toLowerCase();
-	if(moduleName.indexOf(".") != -1) {
-		// if IPF.Note.OutlookHomepage
-		moduleName = moduleName.substring(0, moduleName.lastIndexOf("."));
-	}
+	if(storeid)
+    	data["storeid"] = storeid;
+    if(folder) {
+    	data["entryid"] = folder["entryid"];
 
-	moduleName = moduleName + "list";
+        var moduleName = folder["container_class"].substring(folder["container_class"].indexOf(".") + 1).toLowerCase();
+        if(moduleName.indexOf(".") != -1) {
+            // if IPF.Note.OutlookHomepage
+            moduleName = moduleName.substring(0, moduleName.lastIndexOf("."));
+        }
+
+        moduleName = moduleName + "list";
+        name = folder["display_name"];
+    } else {
+        moduleName = "maillist";
+        name = _("Inbox");
+		//Here we get the inbox folder data from settings to get its display settings.
+		data["storeid"] = webclient.settings.get("folders/entryid_inbox/storeid","");
+ 		data["entryid"] = webclient.settings.get("folders/entryid_inbox/entryid","");
+    }
 
 	// if folder is an appointmentlist, load the folder via the datepicker
 	if (moduleName == "appointmentlist") {
@@ -452,7 +533,7 @@ WebClient.prototype.openFolder = function(storeid, folder)
 			webclient.datepicker = null;
 			dragdrop.updateTargets("folder");
 		}
-		webclient.loadModule(moduleName, folder["display_name"], "main", data, BORDER_LAYOUT);
+		webclient.loadModule(moduleName, name, "main", data, BORDER_LAYOUT);
 	}
 }
 
