@@ -1,10 +1,59 @@
 <?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
+<?php
 
 require("client/layout/tabbar.class.php");
 
 function initWindow(){
 	global $tabbar, $tabs;
-	if(get("entryid","false","'") != "false"){
+	if(get("entryid","false","'", ID_REGEX) != "false"){
 		$tabs = array("appointment" => _("Appointment"), "scheduling" => _("Scheduling"), "tracking" => _("Tracking"));//@TODO
 	}else{
 		$tabs = array("appointment" => _("Appointment"), "scheduling" => _("Scheduling"));
@@ -36,6 +85,9 @@ function getIncludes(){
 			"client/layout/js/date-picker-setup.js",
 			"client/layout/css/date-picker.css",
 			"client/modules/".getModuleName().".js",
+			"client/widgets/suggestionlist.js",
+			"client/modules/suggestemailaddressmodule.js",
+			"client/layout/css/suggestionlayer.css",
 			"client/layout/css/freebusymodule.css",
 			"client/modules/freebusymodule.js",
 			"client/widgets/datetimepicker.js",
@@ -63,6 +115,8 @@ function getJavaScript_other(){ ?>
 			var fb_module = null;
 			var appoint_dtp;
 			var tableWidget = null;
+			var FREEBUSY_DAYBEFORE_COUNT;
+			var FREEBUSY_NUMBEROFDAYS_COUNT;
 <?php } // getJavaScript_other
 
 function getJavaScript_onload(){ 
@@ -76,17 +130,17 @@ function getJavaScript_onload(){
 																				
 					//first tab
 					module.init(moduleID);
-					module.setData(<?=get("storeid","false","'")?>, <?=get("parententryid","false","'")?>);
+					module.setData(<?=get("storeid","false","'", ID_REGEX)?>, <?=get("parententryid","false","'", ID_REGEX)?>);
 					
 					var appoint_start = new DateTimePicker(dhtml.getElementById("appoint_start"),"<?=_("Start time")?>");
 					var appoint_end = new DateTimePicker(dhtml.getElementById("appoint_end"),"<?=_("End time")?>");			
 					appoint_dtp = new combinedDateTimePicker(appoint_start,appoint_end);
 					
-					var entryid = <?=get("entryid","false","'")?>;
+					var entryid = <?=get("entryid","false","'", ID_REGEX)?>;
 					if(entryid) {
-						module.open(entryid, entryid, <?=(isset($_GET["basedate"]))?('new Array(\'' . intval(get("basedate")) .'\')') :"false"?>);
+						module.open(entryid, entryid, <?=(isset($_GET["basedate"]))?('new Array(\'' . intval(get("basedate", false, false, TIMESTAMP_REGEX)) .'\')') :"false"?>);
 					} else {
-						initDate(<?=isset($_GET["date"]) ? "new Date(".intval(get("date"))."*1000)":""?>);
+						initDate(<?=isset($_GET["date"]) ? "new Date(".intval(get("date", false, false, TIMESTAMP_REGEX))."*1000)":""?>);
 						webclient.menu.showMenu();
 					}
 															
@@ -111,6 +165,31 @@ function getJavaScript_onload(){
 					dhtml.addEvent(false, dhtml.getElementById("subject"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("location"), "contextmenu", forceDefaultActionEvent);
 					dhtml.addEvent(false, dhtml.getElementById("html_body"), "contextmenu", forceDefaultActionEvent);
+
+					//checks for default reminder setting  
+					if(parentWebclient.settings.get("calendar/reminder","true") == 'true' && !entryid){
+						
+						// open the reminder default checkbox on.
+						dhtml.setValue(dhtml.getElementById("checkbox_reminder"), true);
+
+						//get the value of reminder time and set it to reminder_minutes
+						var value = parentWebclient.settings.get("calendar/reminder_minutes",15);
+						dhtml.setValue(dhtml.getElementById("select_reminder_minutes"), parseInt(value));
+
+						onChangeReminder();
+					}
+					FREEBUSY_DAYBEFORE_COUNT = <?= defined('FREEBUSY_DAYBEFORE_COUNT') ? FREEBUSY_DAYBEFORE_COUNT : 7 ?>;
+					FREEBUSY_NUMBEROFDAYS_COUNT = <?= defined('FREEBUSY_NUMBEROFDAYS_COUNT') ? FREEBUSY_NUMBEROFDAYS_COUNT : 90 ?>;
+
+					var suggestEmailModule = webclient.dispatcher.loadModule("suggestEmailAddressModule");
+					if(suggestEmailModule != null) {
+						var suggestEmailModuleID = webclient.addModule(suggestEmailModule);
+						suggestEmailModule.init(suggestEmailModuleID);
+						// Setup TO field
+						suggestlistTO = new suggestionList("meetingrequest_to_fld", dhtml.getElementById("toccbcc"), suggestEmailModule);
+						suggestEmailModule.addSuggestionList(suggestlistTO);
+					}
+
 <?php } // getJavaScript_onload						
 					
 function getBody() { 
@@ -143,6 +222,7 @@ function getBody() {
 		<input id="commonassign" type="hidden" value="0">
 		<input id="sent_representing_email_address" type="hidden" value="">
 		<input id="sent_representing_entryid" type="hidden" value="">
+		<input id="meeting" type="hidden" value="0">
 		
 		<!-- Recurring information -->
 		
@@ -181,6 +261,7 @@ function getBody() {
 		<input id="responsestatus" type=hidden value="">
 		
 		<div id="conflict"></div>
+		<div id="extrainfo"></div>
 		
 		<div id="meetingrequest_recipient" class="properties">
 			<div id="meetingrequest_responses">
@@ -302,6 +383,12 @@ function getBody() {
 							<option value="720">0,5 <?=_("day")?></option>
 							<option value="1440">1 <?=_("day")?></option>
 							<option value="2880">2 <?=_("days")?></option>
+							<option value="4320">3 <?=_("days")?></option>
+							<option value="5760">4 <?=_("days")?></option>
+							<option value="7200">5 <?=_("days")?></option>
+							<option value="10080">1 <?=_("week")?></option>
+							<option value="20160">2 <?=_("weeks")?></option>
+							<option value="43200">1 <?=_("month")?></option>
 						</select>
 					</td>
 					<td>
@@ -367,7 +454,7 @@ function getBody() {
 
 	$tabbar->endTab();
 	
-	if(get("entryid","false","'") != "false"){// check whether the user is owner of the appointment or not.
+	if(get("entryid","false","'", ID_REGEX) != "false"){// check whether the user is owner of the appointment or not.
 		$tabbar->beginTab("tracking");
 ?>
 		<div id="tracking_container" class="tracking_container">
@@ -387,19 +474,19 @@ function getMenuButtons(){
 				'id'=>"accept",
 				'name'=>_("Accept"),
 				'title'=>_("Accept"),
-				'callback'=>'function(){submitAppointment(false, "accept");window.close();}'
+				'callback'=>'function(){submitAppointment(false, "accept");}'
 			),
 			array(
 				'id'=>"tentative",
 				'name'=>_("Tentative"),
 				'title'=>_("Tentative"),
-				'callback'=>'function(){submitAppointment(false, "tentative");window.close();}'
+				'callback'=>'function(){submitAppointment(false, "tentative");}'
 			),
 			array(
 				'id'=>"decline",
 				'name'=>_("Decline"),
 				'title'=>_("Decline"),
-				'callback'=>'function(){submitAppointment(false, "decline");window.close();}'
+				'callback'=>'function(){submitAppointment(false, "decline");}'
 			),
 			array(
 				'id'=>"proposenewtime",
@@ -429,7 +516,7 @@ function getMenuButtons(){
 				'id'=>"print",
 				'name'=>"",
 				'title'=>_("Print"),
-				'callback'=>"function(){webclient.openModalDialog(module, 'printing', DIALOG_URL+'entryid='+module.messageentryid+'&storeid='+module.storeid+'&task=printitem_modal', 600, 600);}"
+				'callback'=>'function(){eventOpenPrintAppointmentItemDialog(module);}'
 			),
 			array(
 				'id'=>"seperator0",
@@ -443,6 +530,18 @@ function getMenuButtons(){
 				'title'=>_("Add Attachments"),
 				'callback'=>"function(){webclient.openWindow(module, 'attachments', DIALOG_URL+'task=attachments_modal&store=' + module.storeid + '&entryid=' + (module.messageentryid?module.messageentryid:'') + '&dialog_attachments=' + dhtml.getElementById('dialog_attachments').value, 550, 350, '0');}"
 			),
+			array(
+				'id'=>"seperator",
+				'name'=>"",
+				'title'=>"",
+				'callback'=>""
+			),
+			array(
+				'id'=>"checknames",
+				'name'=>"",
+				'title'=>_("Check Names"),
+				'callback'=>'function(){checkNames(checkNamesCallBackAppointment);}'
+			),
 			array(
 				'id'=>"seperator1",
 				'name'=>"",
