@@ -1,4 +1,53 @@
 <?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
+<?php
 
 require("client/layout/tabbar.class.php");
 
@@ -40,18 +89,21 @@ function getJavaScript_onload(){
 	$tabbar->initJavascript("tabbar", "\t\t\t\t\t");
  ?>
  					module.init(moduleID);
-					module.setData(<?=get("storeid","false","'")?>, <?=get("parententryid","false","'")?>);
+					module.setData(<?=get("storeid","false","'", ID_REGEX)?>, <?=get("parententryid","false","'", ID_REGEX)?>);
 
 					var attachNum = false;
 					<? if(isset($_GET["attachNum"]) && is_array($_GET["attachNum"])) { ?>
 						attachNum = new Array();
 					
-						<? foreach($_GET["attachNum"] as $attachNum) { ?>
-						attachNum.push(<?=intval($attachNum)?>);
-						<? } ?>
+						<? foreach($_GET["attachNum"] as $attachNum) { 
+							if(preg_match_all(NUMERIC_REGEX, $attachNum, $matches)) {
+							?>
+								attachNum.push(<?=intval($attachNum)?>);
+						<?	}
+					} ?>
 					
 					<? } ?>
-					module.open(<?=get("entryid","false","'")?>, <?=get("rootentryid","false","'")?>, attachNum);
+					module.open(<?=get("entryid","false","'", ID_REGEX)?>, <?=get("rootentryid","false","'", ID_REGEX)?>, attachNum);
 				
 					Calendar.setup({
 						inputField	:	"text_duedate",				// id of the input field
@@ -133,6 +185,7 @@ function getBody() {
 		<input id="importance" type="hidden" value="1">
 		<input id="complete" type="hidden" value="0">
 		<input id="percent_complete" type="hidden" value="0">
+		<input id="flagdueby" type="hidden" value="">
 		<input id="reminder" type="hidden" value="0">
 		<input id="reminder_time" type="hidden" value="">
 		<input id="reminderdate" type="hidden" value="">
@@ -195,7 +248,7 @@ function getBody() {
                             <option value="1"><?=_("In Progress")?></option>
                             <option value="2"><?=_("Complete")?></option>
                             <option value="3"><?=_("Wait for other person")?></option>
-                            <option value="5"><?=_("Expelled")?></option>
+                            <option value="4"><?=_("Deferred")?></option>
                 		</select>
                 	</td>
 				</tr>
@@ -223,7 +276,7 @@ function getBody() {
                 		% <?=_("Complete")?>:
                 	</td>
                 	<td>
-                		<input id="text_percent_complete" class="fieldsize" type="text" size="2" value="0%">
+                		<input id="text_percent_complete" onchange="onChangeComplete();" class="fieldsize" type="text" size="2" value="0%">
                 	</td>
                 	<td width="18">
 						<div class="spinner_up" onclick="completeSpinnerUp();">&nbsp;</div>
