@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 function initAppointment()
 {
 	// Label
@@ -52,8 +99,7 @@ function initAppointment()
 		var responseStatus = parseInt(dhtml.getElementById("responsestatus").value);		
 		meetingRequestSetup(responseStatus);
 
-		// Exception, turn off meeting request and recurrence
-		dhtml.getElementById("inviteattendees").style.display = "none";
+		// Exception, turn off recurrence button
 		dhtml.getElementById("seperator1").style.display = "none";
 		dhtml.getElementById("seperator2").style.display = "none";
 		dhtml.getElementById("recurrence").style.display = "none";
@@ -224,7 +270,7 @@ function syncRecipientFields(newRecipsInFields){
 
 	// Get value of recipeints;
 	var recips = {
-		visible: fields.visible.value.split(";"),
+		visible: fields.visible.value.trim().split(";"),
 		to: fields.to.value.split(";"),
 		cc: fields.cc.value.split(";"),
 		bcc: fields.bcc.value.split(";")
@@ -350,6 +396,11 @@ function submitAppointment(send, requestStatus)
 	// Busy Status
 	dhtml.getElementById("busystatus").value = dhtml.getValue(dhtml.getElementById("select_busystatus"));
 
+	if(isNaN(appoint_dtp.getEndValue())){
+		alert(_("The end date you entered occurs before the start date."));
+		return false;
+	}
+
 	// Startdate
 	dhtml.getElementById("startdate").value = appoint_dtp.getStartValue();
 	dhtml.getElementById("commonstart").value = appoint_dtp.getStartValue();
@@ -464,25 +515,45 @@ function submitAppointment(send, requestStatus)
 		/**
 		 * If changes are to be saved for accepting/tentatively
 		 * meeting request, then send response.
+		 * Ask for confirmation to user of sending response to organizer.
 		 */
 		if (requestStatus) {
-			switch(requestStatus)
-			{
-				case "accept":
-					module.acceptMeetingRequest();
-					break;
-				case "tentative":
-					module.tentativeMeetingRequest();
-					break;
-				case "decline":
-					module.declineMeetingRequest();
-					break;
-			}
 			module.savingMeetingRequest = true;
+			// Open send Metting Request Mail Confirmation dialog box.
+			webclient.openModalDialog(module, 'sendMRMailConfirmation', DIALOG_URL+'task=sendMRMailConfirmation_modal', 320, 160, sendMRMailConfirmationCallback, requestStatus);
 		}
 	}
 }
 
+/**
+ * Function which sends request for saving request status.
+ * @param boolean sendResponse if it is true than reponse is sent to organizer via mail otherwise it is not sent.
+ * @param string requestStatus it is a type of request values are accept, tentative or decline.
+ */
+function sendMRMailConfirmationCallback(noResponse, requestStatus)
+{
+	var basedateEle = dhtml.getElementById("basedate");
+	var basedate = false;
+	if(basedateEle && basedateEle.value)
+		basedate = basedateEle.value;
+
+	switch(requestStatus)
+	{
+		case "accept":
+			module.acceptMeetingRequest(noResponse, basedate);
+			break;
+		case "tentative":
+			module.tentativeMeetingRequest(noResponse, basedate);
+			break;
+		case "decline":
+			module.declineMeetingRequest(basedate);
+			break;
+	}
+	module.savingMeetingRequest = true;
+
+	window.setTimeout("window.close()",1200);
+}
+
 // Cancelling an already-sent invitation causes a 'cancel' message to be sent and
 // the message window to be closed. If this is a new invitation, just go back to a
 // non-meetingrequest mode.
@@ -497,8 +568,12 @@ function cancelInvitation()
 		var isOrganizer = module.itemProps.responsestatus && module.itemProps.responsestatus==1;
 		if (isMeeting && isOrganizer)
 			send = confirm(_("Would you like to send an update to the attendees regarding cancellation to this meeting?"));
-		
-		deleteAppointment(send);
+			var basedate = dhtml.getElementById('basedate').getAttribute('unixtime');
+			if(basedate){
+				webclient.openModalDialog(module,"deleteoccurence", DIALOG_URL+"entryid="+module.messageentryid+"&storeid="+module.storeid+"&task=deleteoccurrence_modal&basedate="+basedate+"&parententryid="+module.parententryid+"&meeting="+1+"&send="+send, 300, 200, callbackdeleteoccurence);
+			}else{
+				deleteAppointment(send);
+			}
 	} if(responseStatus == 3 || responseStatus == 5) {
 		// We're an attendee, we cannot cancel
 	} else {
@@ -506,10 +581,18 @@ function cancelInvitation()
 	}
 }
 
+//callback which sends a cancelation message to attendees and close the appointment window
+function callbackdeleteoccurence()
+{
+	window.setTimeout("window.close()",1200);	
+}
+
 // If 'send' is TRUE, then send a cancellation
 function deleteAppointment(send)
 {
-	module.deleteMessage(send);
+	var basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
+	basedate = basedate ? parseInt(basedate, 10) : 0;
+	module.deleteMessage(send, basedate);
 	window.close();
 }
 
@@ -565,6 +648,8 @@ function meetingRequestSetup(level) {
 	var proposenewtimebutton = dhtml.getElementById("proposenewtime");
 	var inviteattendeesbutton = dhtml.getElementById("inviteattendees");
 	var cancelinviteattendeesbutton = dhtml.getElementById("cancelinviteattendees");
+	var checknames = dhtml.getElementById("checknames");
+	var seperator1 = dhtml.getElementById("seperator1");
 	
 	if(level == 0) { // normal
 		meetingrequest_recipient.style.display = "none";
@@ -578,8 +663,11 @@ function meetingRequestSetup(level) {
 		tentativebutton.style.display = "none";
 		declinebutton.style.display = "none";
 		proposenewtimebutton.style.display = "none";
+		checknames.style.display = "none";
+		seperator1.style.display = "none";
 		dhtml.getElementById("windowtitle").innerHTML = _("Appointment");
 		window.document.title = _("Appointment");
+		module.isMeeting = false;
 	} else if(level == 1) {	// organiser
 		meetingrequest_recipient.style.display = "block";
 		meetingrequest_organiser.style.display = "none";
@@ -592,13 +680,14 @@ function meetingRequestSetup(level) {
 		tentativebutton.style.display = "none";
 		declinebutton.style.display = "none";
 		proposenewtimebutton.style.display = "none";
+		checknames.style.display = "block";
+		seperator1.style.display = "block";
 		dhtml.getElementById("windowtitle").innerHTML = _("Meeting");
 		window.document.title = _("Meeting");
-
 		if(window.propNewTime_tableWidget)
 			window.propNewTime_tableWidget.resize();
 		resizeFreeBusyContainer();
-
+		module.isMeeting = true;
 	} else { // attendee
 		meetingrequest_recipient.style.display = "none";
 		meetingrequest_organiser.style.display = "";
@@ -612,9 +701,11 @@ function meetingRequestSetup(level) {
 		tentativebutton.style.display = "block";
 		declinebutton.style.display = "block";
 		proposenewtimebutton.style.display = "block";
+		checknames.style.display = "none";
+		seperator1.style.display = "none";
 		dhtml.getElementById("windowtitle").innerHTML = _("Meeting");
 		window.document.title = _("Meeting");
-
+		module.isMeeting = true;
 		if(window.propNewTime_tableWidget) 
 			window.propNewTime_tableWidget.resize();
 		resizeFreeBusyContainer();
@@ -637,6 +728,22 @@ function meetingRequestSetup(level) {
 		proposenewtimebutton.style.display = "block";
 	}
 
+	var meeting = dhtml.getElementById('meeting');
+	var extrainfo = dhtml.getElementById("extrainfo");
+	// Meeting has been cancelled
+	if (meeting.value == 7) {
+		sendbutton.style.display = "none";
+		acceptbutton.style.display = "none";
+		tentativebutton.style.display = "none";
+		declinebutton.style.display = "none";
+		proposenewtimebutton.style.display = "none";
+		deletebutton.style.display = "block";
+		extrainfo.style.display = "block";
+		extrainfo.innerHTML = "<p>"+ NBSP + _("Meeting has been canceled.") +"</p>";
+	} else {
+		extrainfo.style.display = "none";
+	}
+
 	resizeBody();
 }
 
@@ -672,7 +779,13 @@ function onAppointmentTabChange(newTab,oldTab)
 			if (module.itemProps && module.itemProps.sent_representing_name) {
 				organizer = module.itemProps.sent_representing_name;
 			} else if (!organizer) {
-				organizer = webclient.username;
+				var organizerStore = parentWebclient.hierarchy.getStore(module.storeid);
+				//if user is creating a meeting as delegate the organizer name in freebusy should me the owner of the calendar.
+				if(organizerStore.emailaddress && organizerStore.emailaddress != webclient.username){
+					organizer = organizerStore.username;
+				}else{
+					organizer = webclient.username;
+				}
 			}
 			fb_module.initView(1, organizer, module.getUserList());
 			
@@ -696,6 +809,9 @@ function onAppointmentTabChange(newTab,oldTab)
 			fb_module.resize();
 			fb_module.setUserList(module.getUserList());
 		}
+		// Case in which schedule tab is selected after tracking tab.
+		if(oldTab == "tracking")
+			syncTrackingTabWithAppointmentTab("scheduling", "appointment");
 	}
 	if(oldTab == "scheduling"){
 		//update the appointment time in appointment tab
@@ -706,7 +822,13 @@ function onAppointmentTabChange(newTab,oldTab)
 		if(fb_module){
 			var fbUserlist = fb_module.getUserList();
 			if(fbUserlist.length>0){
-				meetingRequestSetup(1);
+				// Check wheather the username is the organiser or not to set menubar in Appointment module 
+				var meetingRecipientStatus = false;
+				for (var j = 0; j < fbUserlist.length; j++){
+					if(fbUserlist[j]["emailaddress"] != undefined && fbUserlist[j]["emailaddress"].toLowerCase() == webclient.emailaddress.toLowerCase() && fbUserlist[j]["recipient_flags"] != 3)
+						meetingRecipientStatus = true;
+				}
+				meetingRecipientStatus? meetingRequestSetup(2): meetingRequestSetup(1);
 			}
 			else{
 				meetingRequestSetup(0);
@@ -981,7 +1103,7 @@ function updateInfoBox(module){
 			}
 		}
 		infobox.style.display = "block";
-		infobox.innerHTML = NBSP + accepted + _(" attendee accepted, ") + tentative + _(" tentatively accepted, ") + declined + _(" declined.");
+		infobox.innerHTML = NBSP + accepted +" "+ _("attendee accepted") +", "+ tentative +" "+ _("tentatively accepted") +", "+ declined +" "+ _("declined") +".";
 	}
 }
 
@@ -1224,7 +1346,7 @@ function createCompatibleRecipientList(userList)
 				item["name"] = recipients[j]["display_name"];
 				item["address"] = recipients[j]["email_address"];
 				item["type"] = userList[i]["type"];				
-				item["recipient_flags"] = recipients[j]["recipient_flags"];
+				item["recipient_flags"] = (recipients[j]["recipient_flags"])?recipients[j]["recipient_flags"]: recipSendable;
 				item["recipient_status_num"] = recipients[j]["recipient_status_num"];
 				item["recipient_attendees"] = recipients[j]["recipient_attendees"];
 				recipientList.push(item);
@@ -1284,7 +1406,38 @@ function eventAppointmentDialogProposeNewTimeClick(moduleObject)
 // This method is called after the user has select a time to propose for the meeting
 function appointmentdialogProposenewtime_dialog_callback(result, callbackData){
 	if(callbackData.moduleObject){
-		callbackData.moduleObject.proposalMeetingRequest(parseInt(result.combineddatetimepicker.start,10), parseInt(result.combineddatetimepicker.end,10), result.body);
+		var basedate = false;
+		if(dhtml.getElementById("basedate").getAttribute("unixtime"))
+			basedate = dhtml.getElementById("basedate").getAttribute("unixtime");
+
+		callbackData.moduleObject.proposalMeetingRequest(parseInt(result.combineddatetimepicker.start,10), parseInt(result.combineddatetimepicker.end,10), result.body, basedate);
 	}
 
 }
+/**
+ * Callback function for checknames in appointment.
+ * @param Object resolveObj obj of the resolved names
+ */
+function checkNamesCallBackAppointment(resolveObj)
+{
+	checkNamesCallBack(resolveObj);
+
+	var elements = new Array("to", "cc", "bcc");
+	var toccbcc = dhtml.getElementById("toccbcc");
+
+	toccbcc.value = "";
+
+	// Collect resolved values from ("to", "cc", "bcc") and put them together in "toccbcc".
+	for (var i = 0; i < elements.length; i++){
+		var value = dhtml.getElementById(elements[i]).value;
+		toccbcc.value += (value.trim() != ";") ? value : "";
+	}
+}
+
+function eventOpenPrintAppointmentItemDialog(moduleObject)
+{
+	if(moduleObject.attachNum)
+		webclient.openModalDialog(moduleObject, 'printing', DIALOG_URL+'entryid='+moduleObject.messageentryid+'&storeid='+moduleObject.storeid+'&task=printitem_modal'+'&attachNum[]='+moduleObject.attachNum, 600, 600);
+	else
+		webclient.openModalDialog(moduleObject, 'printing', DIALOG_URL+'entryid='+moduleObject.messageentryid+'&storeid='+moduleObject.storeid+'&task=printitem_modal', 600, 600);
+}
