@@ -1,10 +1,65 @@
-function initEditor(useHTMLEditor, FCKEDITOR_JS_PATH, client_lang, spellchecker){
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+function initEditor(useHTMLEditor, FCKEDITOR_JS_PATH, client_lang, spellchecker, elementId, editorHeight){
 	if (useHTMLEditor){
-		var height = 366;
+		var height = (parseInt(editorHeight)) ?editorHeight:366;
+		var editorElement = new String("html_body");
+		
 		if(parentWebclient.settings.get("createmail/from", "false") != "false"){
 			height -= 24;
 		}
-		var oFCKeditor = new FCKeditor("html_body", "100%", height+"px");
+		
+		//Set id of edior element.
+		if (elementId && elementId.length > 0) {
+			editorElement = elementId;
+		}
+		
+		var oFCKeditor = new FCKeditor(editorElement, "100%", height+"px");
 		oFCKeditor.EditorPath = FCKEDITOR_JS_PATH + "/";
 		oFCKeditor.BasePath = oFCKeditor.EditorPath;
 		oFCKeditor.ReplaceTextarea();
@@ -60,6 +115,9 @@ function getPropsFromDialog() {
 				case "radio":
 					props[input[i].id] = input[i].checked;
 					break;
+				case "button":
+					// if button with id then don't send it as props
+					break;
 				case "hidden":
 				case "text":
 				default:
@@ -115,17 +173,17 @@ function getRecipients() {
 					var regex = new RegExp(/([^<]*){0,1}\s*(<\s*([^>]*)>\s*){0,1}/);
 					var result = regex.exec(recipientRows[j].trim());
 
-					if(typeof result[1] != "undefined" || result[1] != ""){	
+					if(typeof result[1] != "undefined" && result[1] != ""){	
 						result[1] = result[1];
 					} else {
 						// username
 						result[1] = result[3];
 					}
 					
-					if(typeof result[3] != "undefined" || result[3] != ""){
+					if(typeof result[3] != "undefined" && result[3] != ""){
 						result[3] = result[3];
 					} else {
-						// username@zarafa.com
+						// username@domain.com
 						result[3] = result[1];
 					}
 					
@@ -143,12 +201,34 @@ function getRecipients() {
 			}
 		}
 	}
-	
+	/**
+	 * create a temp object on basis of email addresses
+	 * which basically removes the duplicate recipients from recipients array
+	 */
+	var tempRecipientObject = new Object();
+	for(var i=recipients.length-1;i>=0;i--){
+		tempRecipientObject[recipients[i]["address"]] = recipients[i];
+	}
+	//empty the recipient list
+	recipients = new Array();
+
+	// create the array again from unique recipient Object.
+	for(var address in tempRecipientObject){
+		recipients.push(tempRecipientObject[address]);
+	}
 	return recipients;
 }
 
 function submit_createmail(send) {
-    if (!window.waitForSaveResponse){ 
+
+	if (!window.waitForSaveResponse){
+		var inlineimages = new Object();
+		if (typeof FCKeditorAPI != "undefined" && (fckeditor = FCKeditorAPI.GetInstance('html_body'))){
+			var fckEditorDocument = fckeditor.EditorDocument;
+			module.setCIDInlineImages(fckEditorDocument);
+			inlineimages["images"] = module.checkUsedInlineAttachments(fckEditorDocument);
+		}
+		
 		if(send && module){
 			if(validateEmailAddress(dhtml.getElementById("to").value, false, window.resolveForSendingMessage?false:true) && 
 			 validateEmailAddress(dhtml.getElementById("cc").value, false, window.resolveForSendingMessage?false:true) && 
@@ -159,11 +239,12 @@ function submit_createmail(send) {
 				recipients["recipient"] = getRecipients();
 				if (recipients["recipient"].length==0){
 					alert(_("Please input a valid email address!"));
+					window.waitForSaveResponse = false;
 					return;
 				}
 				
-				module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value);
-
+				module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value, inlineimages);
+	
 				// close opener window
 				if (webclient.settings.get("createmail/close_read_on_reply", "no")=="yes" && window.opener && window.opener.name.indexOf("readmail")==0){
 					window.opener.close();
@@ -175,10 +256,10 @@ function submit_createmail(send) {
 			} else if (window.resolveForSendingMessage !== true) {
 				// Set status for the resolver to know he has to call this function again
 				window.resolveForSendingMessage = true;
-				checkNames();
-			}else{
-				// Reset status for the resolver to know he does not have to call this function again
-				window.resolveForSendingMessage = false;
+	  			checkNames(checkNamesCallBackCreateMail);
+	 		}else{
+	  			// Reset status for the resolver to know he does not have to call this function again
+	  			window.resolveForSendingMessage = false;
 			}
 		} else{
 			window.waitForSaveResponse = true;
@@ -191,7 +272,7 @@ function submit_createmail(send) {
 			
 			window.document.title = _("Create E-Mail");
 			window.messageChanged = false;
-			module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value);
+			module.save(props, send, recipients, dhtml.getElementById("dialog_attachments").value, inlineimages);
 		}
 	}
 }
@@ -377,24 +458,28 @@ function eventMenuAddSignature(){
 function addSignature(signatureID)
 {
 	setMessageChanged();
-	var signature = module.getSignature(signatureID);
-	
-	if(signature) {
+
+	var signatureData = module.getSignatureData(signatureID);
+	if(signatureData) {
 		var use_html = dhtml.getElementById("use_html");
 		if(use_html) {
 			if(use_html.value == "false") {
+				// Convert html signature to plain text
+				if(signatureData["type"] != "plain") {
+					signatureData["content"] = convertHtmlToPlain(signatureData["content"]);
+				}
+				
 				var body = dhtml.getElementById("html_body");
 				if (body.setSelectionRange){
-					body.value = body.value.substring(0, body.selectionStart) + signature + body.value.substring(body.selectionStart, body.selectionEnd) + body.value.substring(body.selectionEnd, body.value.length);
+					body.value = body.value.substring(0, body.selectionStart) + signatureData["content"] + body.value.substring(body.selectionStart, body.selectionEnd) + body.value.substring(body.selectionEnd, body.value.length);
 				} else if (document.selection && document.selection.createRange) {
-					body.value = body.value.substring(0, window.start) + signature + body.value.substring(window.start, window.end) + body.value.substring(window.end, body.value.length);
+					body.value = body.value.substring(0, window.start) + signatureData["content"] + body.value.substring(window.start, window.end) + body.value.substring(window.end, body.value.length);
 				}
 			} else {
 				if(typeof(FCKeditorAPI) != "undefined" && (fckEditor = FCKeditorAPI.GetInstance("html_body"))) {
-					signature = signature.htmlEntities();
 					fckEditor.Selection.Restore();
-					signature = signature.replace(/\n/g, "<br>");
-					fckEditor.InsertHtml(signature);
+					signatureData["content"] = signatureData["content"].replace(/\n/g, "<br>");
+					fckEditor.InsertHtml(signatureData["content"]);
 				}
 			}
 		}
@@ -447,8 +532,9 @@ function getMailOptions()
 
 /**
  * Function will start the resolveNames process
+ * @param object callBackFunction callback function
  */ 
-function checkNames()
+function checkNames(callBackFunction)
 {
 	var recipients = new Array("to", "cc", "bcc");
 	var resolveObj = new Object();
@@ -460,7 +546,7 @@ function checkNames()
 			resolveObj[recipients[i]] = "";
 		}
 	}
-	parentWebclient.resolvenames.resolveNames(resolveObj,checkNamesCallBack);
+	parentWebclient.resolvenames.resolveNames(resolveObj, callBackFunction);
 }
 
 /**
@@ -486,16 +572,12 @@ function checkNamesCallBack(resolveObj)
 			//build string
 			var newString = "";
 			for(var j=0; j<unResolved.length; j++){
-				newString += unResolved[j]+";";
+				if (unResolved[j].trim().length > 0)
+					newString += unResolved[j]+";";
 			}
 			dhtml.getElementById(i).value = newString;
 		}
 	}
-
-	//Send mail
-	if(window.resolveForSendingMessage === true){
-		submit_createmail(true);
-	}
 }
 
 function timeSpinnerUp(time_element)
@@ -667,6 +749,12 @@ function setDnDAttachments(input){
 		newattachments.push(attachment);
 	}
 	module.newattachments = newattachments;
+
+	if(module.messageAction == "reply" || module.messageAction == "replyall") {
+		// remove previous attachments when replying to a mail
+		module.attachments = new Array();
+	}
+
 	module.setAttachments();
 }
 function allowDnDFiles(element){
@@ -686,20 +774,14 @@ function allowDnDFiles(element){
 function cleanHTML(html)
 {
 	html = html.replace(/<o:p>\s*<\/o:p>/g, '') ;
-	html = html.replace(/<o:p>.*?<\/o:p>/g, '&nbsp;') ;
+	html = html.replace(/<o:p>(.*?)<\/o:p>/g, "<p>$1</p>") ;
 
 	// Remove mso-xxx styles.
 	html = html.replace( /\s*mso-[^:]+:[^;"]+;?/gi, '' ) ;
 
-	// Remove margin styles.
-	html = html.replace( /\s*MARGIN: 0cm 0cm 0pt\s*;/gi, '' ) ;
-	html = html.replace( /\s*MARGIN: 0cm 0cm 0pt\s*"/gi, "\"" ) ;
-
 	html = html.replace( /\s*TEXT-INDENT: 0cm\s*;/gi, '' ) ;
 	html = html.replace( /\s*TEXT-INDENT: 0cm\s*"/gi, "\"" ) ;
 
-	html = html.replace( /\s*TEXT-ALIGN: [^\s;]+;?"/gi, "\"" ) ;
-
 	html = html.replace( /\s*PAGE-BREAK-BEFORE: [^\s;]+;?"/gi, "\"" ) ;
 
 	html = html.replace( /\s*FONT-VARIANT: [^\s;]+;?"/gi, "\"" ) ;
@@ -772,16 +854,14 @@ function cleanHTML(html)
 function IE_getCursorPosition(textArea)
 {
     if (document.selection) { // IE
-        var sel1 = document.selection.createRange();
-        var sel2 = sel1.duplicate();
-        sel2.moveToElementText(textArea);
-        var selText = sel1.text;
-        sel1.text = "}#{";
-        var index = sel2.text.indexOf("}#{");
-        window.start = (index == -1) ? sel2.text.length : sel2.text.substring(0, index).length;
-        window.end = selText.length + window.start;
-        sel1.moveStart('character', -3);
-        sel1.text = selText;
+        var selectedRange = document.selection.createRange();
+        var tmpSelectedRange = selectedRange.duplicate();
+		tmpSelectedRange.moveToElementText(textArea);
+		// Now set 'tmpSelectedRange' end point to end point of original range that is selectedRange 
+		tmpSelectedRange.setEndPoint('EndToEnd', selectedRange );
+		// Now we can calculate start and end points
+		window.start = tmpSelectedRange.text.length - selectedRange.text.length;
+		window.end = window.start + selectedRange.text.length;
     } else if (textArea.selectionStart || (textArea.selectionStart == "0")) { // Mozilla/Netscape
         window.start = textArea.selectionStart;
         window.end = textArea.selectionEnd;
@@ -804,8 +884,9 @@ function IE_tracCursorPosition(moduleObject, element)
  * Function which keeps trac of cursor position
  * when editor is loaded.
  */
-function IE_tracCursorInEditor(fckEditor)
+function IE_tracCursorInEditor()
 {
+	var fckEditor = FCKeditorAPI.GetInstance("html_body");
 	if (fckEditor && fckEditor.HasFocus){
 		if (fckEditor.Selection.GetSelection().type != "None") fckEditor.Selection.Save();
 	}
