@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 //  Setup the screen to display the given rule
 function showRule(rule)
 {
@@ -86,6 +133,13 @@ function showCondition(condition)
     {
         // No condition selected; matches all 
     }
+	// From contains to compatible with OL07
+	else if(condition.restype.value == "RES_COMMENT" && condition.restriction.proptag.value == "PR_SENDER_SEARCH_KEY")
+	{
+		var fromString = hex2bin(condition.restriction.value.value).toLowerCase(); // hex because sender search key is hex ;
+		fromString = fromString.substring(fromString.indexOf(":")+1, fromString.length-1);
+		dhtml.getElementById("cond_from").value = fromString;
+	}
     else return false;
         
     return true;
@@ -477,6 +531,8 @@ function getAction()
 
         action.action = new Object;
         action.action.value = "OP_FORWARD";
+        action.flavor = new Object;
+        action.flavor.value = 3; // FWD_PRESERVE_SENDER | FWD_DO_NOT_MUNGE_MSG -> Redirect
         action.adrlist = new Object;
         action.adrlist.address = new Object;
         action.adrlist.address.property = new Array();
