@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * initSignatures
  * 
@@ -10,8 +57,8 @@ function initSignatures(){
 	// Get signature data from settings and put them into the global Data Object.
 	var signatures = getSignaturesFromSettings();
 	data["signatures"] = signatures;
-	data["select_sig_newmsg"] = settings.get("createmail/signatures/select_sig_newmsg","");
-	data["select_sig_replyfwd"] = settings.get("createmail/signatures/select_sig_replyfwd","");
+	data["select_sig_newmsg"] = webclient.settings.get("createmail/signatures/select_sig_newmsg","");
+	data["select_sig_replyfwd"] = webclient.settings.get("createmail/signatures/select_sig_replyfwd","");
 
 	// Setup signature list using a TableWidget.
 	signatureTable = new TableWidget(dhtml.getElementById("signatureslist_container"), false);
@@ -38,7 +85,7 @@ function getSignaturesFromSettings(){
 	sigLookupTbl = new Object();
 
 	// Get signature IDs 
-	var id_lookup = String(settings.get("createmail/signatures/id_lookup",""));
+	var id_lookup = String(webclient.settings.get("createmail/signatures/id_lookup",""));
 	if(id_lookup != ""){
 		var signatureIDs = id_lookup.split(";");
 
@@ -46,8 +93,9 @@ function getSignaturesFromSettings(){
 		for(var i=0;i<signatureIDs.length;i++){
 			signatures[ i ] = new Object();
 			signatures[ i ]["id"] = signatureIDs[i];
-			signatures[ i ]["name"] = settings.get("createmail/signatures/"+signatureIDs[i]+"/name","");
-			signatures[ i ]["content"] = settings.get("createmail/signatures/"+signatureIDs[i]+"/content","");
+			signatures[ i ]["name"] = webclient.settings.get("createmail/signatures/"+signatureIDs[i]+"/name","");
+			signatures[ i ]["content"] = webclient.settings.get("createmail/signatures/"+signatureIDs[i]+"/content","");
+			signatures[ i ]["type"] = webclient.settings.get("createmail/signatures/"+signatureIDs[i]+"/type","");
 		}
 
 		// Sort the signatures
@@ -63,6 +111,7 @@ function getSignaturesFromSettings(){
 			sigLookupTbl[ signatures[i]["id"] ]["id"]      = signatures[i]["id"];
 			sigLookupTbl[ signatures[i]["id"] ]["name"]    = signatures[i]["name"];
 			sigLookupTbl[ signatures[i]["id"] ]["content"] = signatures[i]["content"];
+			sigLookupTbl[ signatures[i]["id"] ]["type"]    = signatures[i]["type"];  // Set type of signature
 		}
 	}
 	return sigLookupTbl;
@@ -106,6 +155,9 @@ function populateSignatureList(signatures){
 		signatureTable.clearSelection();
 		signatureTable.selectRow(tblRowID);
 		startEditSignature(content, tblRowID);
+	} else if(tableData.length > 0 && !USE_FCKEDITOR){
+		// Select first signature if there is no signature selected yet
+		signatureTable.selectRow(tableData[0].rowID);
 	}
 
 	// Now lets fill the option lists
@@ -141,7 +193,6 @@ function populateSignatureList(signatures){
 			}
 		}
 	}
-
 }
 
 /**
@@ -153,7 +204,22 @@ function populateSignatureList(signatures){
  * @param shadow_sigID number ID of the signature that is selected in the signature table.
  */
 function startEditSignature(content, shadow_sigID){
-	dhtml.getElementById("signature_editor", "textarea").value = content;
+	// Check if HTML editor is loaded and set the body
+	if (checkEditor() && (fckeditor = FCKeditorAPI.GetInstance("signature_editor"))){
+		// If plain text signature, convert to html text.
+		if (data["signatures"][shadow_sigID] && data["signatures"][shadow_sigID]["type"] == "plain") {
+			content = convertPlainToHtml(content);
+		}
+		fckeditor.SetHTML(content.replace(/\n/g, "<br />"));
+	} else {
+		if (data["signatures"][shadow_sigID] && data["signatures"][shadow_sigID]["type"] == "plain") {
+			// plain text so no need to convert
+			dhtml.getElementById("signature_editor", "textarea").value = content;
+		} else {
+			// convert to plain text
+			dhtml.getElementById("signature_editor", "textarea").value = convertHtmlToPlain(content);
+		}
+	}
 	dhtml.getElementById("signature_editor", "textarea").shadow_sigID = ((shadow_sigID)?shadow_sigID:false);
 }
 
@@ -164,11 +230,16 @@ function startEditSignature(content, shadow_sigID){
  * check if a RTE editor is used or just a plain textarea.
  */
 function getSignatureFromEditor(){
-	var editor = dhtml.getElementById("signature_editor", "textarea");
-	if(editor){
-		return editor.value;
-	}else{
-		return "";
+	// Check if HTML editor is loaded and get the body
+	if (checkEditor() && (fckeditor = FCKeditorAPI.GetInstance("signature_editor"))){
+		return fckeditor.GetHTML();
+	} else {
+		var editor = dhtml.getElementById("signature_editor", "textarea");
+		if(editor){
+			return editor.value;
+		}else{
+			return "";
+		}
 	}
 }
 
@@ -199,27 +270,31 @@ function saveSignaturesInSettings(){
 	for(var i in old_sigs){
 		// Check if old signature is not still in the current list.
 		if(!data["signatures"][ old_sigs[i]["id"] ]){
-			settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"/name");
-			settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"/content");
-			settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"");
+			webclient.settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"/name");
+			webclient.settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"/content");
+			webclient.settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"/type");
+			webclient.settings.deleteSetting("createmail/signatures/"+old_sigs[i]["id"]+"");
 		}
 	}
 
-	var signatureIDlist = Array();
+	var signatureIDlist = new Array();
 	for(var i in data["signatures"]){
 		// Retrieve the signature IDs to combine them into the id_lookup string
 		signatureIDlist.push(data["signatures"][i]["id"]);
 
 		// Setting the name and content in the settings
-		settings.set("createmail/signatures/"+data["signatures"][i]["id"]+"/name", data["signatures"][i]["name"]);
-		settings.set("createmail/signatures/"+data["signatures"][i]["id"]+"/content", data["signatures"][i]["content"]);
+		webclient.settings.set("createmail/signatures/"+data["signatures"][i]["id"]+"/name", data["signatures"][i]["name"]);
+		webclient.settings.set("createmail/signatures/"+data["signatures"][i]["id"]+"/content", data["signatures"][i]["content"]);
+		webclient.settings.set("createmail/signatures/"+data["signatures"][i]["id"]+"/type", data["signatures"][i]["type"]);
 	}
 	// Finally adding the id_lookup string to the settings
-	settings.set("createmail/signatures/id_lookup", signatureIDlist.join(";"));
+	webclient.settings.set("createmail/signatures/id_lookup", signatureIDlist.join(";"));
 
 	// Let's not forget to add the selections for the newmsg and replyfwd signature as well.
-	settings.set("createmail/signatures/select_sig_newmsg", data["select_sig_newmsg"]);
-	settings.set("createmail/signatures/select_sig_replyfwd", data["select_sig_replyfwd"]);
+	webclient.settings.set("createmail/signatures/select_sig_newmsg", data["select_sig_newmsg"]);
+	webclient.settings.set("createmail/signatures/select_sig_replyfwd", data["select_sig_replyfwd"]);
+	
+	window.signatureChanged = false;
 }
 
 /**
@@ -231,14 +306,13 @@ function saveSignaturesInSettings(){
 function checkSignatureContentModified(){
 	// Get ID from signature table and content from the editor.
 	var id = getShadowSignatureIDFromEditor();
-	var content = getSignatureFromEditor();
 
 	// Check if the signature exists.
 	if(data["signatures"][ id ]){
 		// Check if the signature content has been changed and offer option 
 		// to save the content.
-		if(data["signatures"][ id ]["content"] != content){
-			if(window.confirm(_("The signature has been changed. Do you want to save the changes?"),"b")){
+		if(window.signatureChanged){
+			if(window.confirm(_("The signature has been changed. Do you want to save the changes?"))){
 				saveSignatureContentModification(id);
 			}
 		}
@@ -256,8 +330,17 @@ function checkSignatureContentModified(){
  * @param select list of rowIDs of newly selected rows
  */
 function selectSignature(tblWidget, type, selected, select){
+	// Prevent selecting of any signatures till FCKeditor is loaded.
+	if (checkEditor() && !window.FCKeditorLoaded) {
+		window.setTimeout(function (){
+			selectSignature(tblWidget, type, selected, select);
+		}, 1000);
+		return false;
+	}
+
 	// Prevent loss of unsaved data in modified signature.
 	checkSignatureContentModified();
+
 	// Retrieve data from row in signature table
 	var rowData = tblWidget.getDataByRowID(select[0]);
 	if(rowData){
@@ -280,8 +363,17 @@ function selectSignature(tblWidget, type, selected, select){
  * @param deselect array list of deselected rowIDs 
  */
 function deselectSignature(tblWidget, type, selected, deselect){
+	// Prevent deselecting of any signatures till FCKeditor is loaded.
+	if (checkEditor() && !window.FCKeditorLoaded){
+		window.setTimeout(function (){
+			deselectSignature(tblWidget, type, selected, deselect);
+		}, 1000);
+		return false;
+	}
+
 	// Prevent loss of unsaved data in modified signature.
 	checkSignatureContentModified();
+
 	// Empty editor
 	startEditSignature("");
 }
@@ -354,7 +446,8 @@ function createSignature_namesig_callback(result, callbackData){
 		data["signatures"][ uniqueID ]["id"] = uniqueID;
 		data["signatures"][ uniqueID ]["name"] = result.signame;
 		data["signatures"][ uniqueID ]["content"] = "";
-
+		data["signatures"][ uniqueID ]["type"] = (checkEditor())?"html":"plain";
+		
 		// Refresh the all the signature lists.
 		// We use the callbackData.winObj to force the populateSignatureList to 
 		// be called in the scope of this window instead of the scope of the 
@@ -374,6 +467,7 @@ function saveSelectedSignature(){
 	var selected = signatureTable.getSelectedRowData();
 	if(selected[0]){
 		saveSignatureContentModification(selected[0]["data"]["id"]);
+		window.document.title = _("Signatures");
 	}
 }
 
@@ -387,10 +481,28 @@ function saveSignatureContentModification(signatureID){
 	// Check if the signature exists.
 	if(data["signatures"][ signatureID ]){
 		var content = getSignatureFromEditor();
-		// Save content in global Data Object.
-		data["signatures"][ signatureID ]["content"] = content;
 		
-		saveSignaturesInSettings();
+		if (checkEditor()) {
+			// Save content in global Data Object.
+			data["signatures"][ signatureID ]["content"] = cleanHTML(content); // for copy&paste from WORD, apply cleaning of HTML
+			data["signatures"][ signatureID ]["type"] = "html";
+			saveSignaturesInSettings();
+		} else {
+			// Prompt user that modifing html signature, will remove text formatting.
+			if (data["signatures"][ signatureID ]["type"] && data["signatures"][ signatureID ]["type"] == "html") {
+				if (confirm(_("Your signature is edited in plain text mode. When saving you will lose the original text formatting of your HTML signature. \n\nDo you want to proceed?"))) {
+					// Save content in global Data Object.
+					data["signatures"][ signatureID ]["content"] = cleanHTML(content); // for copy&paste from WORD, apply cleaning of HTML
+					data["signatures"][ signatureID ]["type"] = "plain";
+					saveSignaturesInSettings();
+				}
+			} else {
+				// Save content in global Data Object.
+				data["signatures"][ signatureID ]["content"] = cleanHTML(content); 
+				data["signatures"][ signatureID ]["type"] = "plain";
+				saveSignaturesInSettings();
+			}
+		}
 	}
 }
 
@@ -458,7 +570,7 @@ function eventChangeSelectionSignatureOptions(moduleObject, element, event){
  */
 function checkLegacySignature(){
 	// Get old signature value
-	oldsig_content = settings.get("createmail/signature/text", false);
+	oldsig_content = webclient.settings.get("createmail/signature/text", false);
 	if(oldsig_content && oldsig_content != ""){
 		// Use create signature callback function to add new signature.
 		// Pass the result object with the new signame and a callbackdata object
@@ -466,13 +578,28 @@ function checkLegacySignature(){
 		var sigID = createSignature_namesig_callback({signame: _("Default Signature")}, {winObj: window});
 		data["signatures"][ sigID ]["content"] = oldsig_content;
 		// Set default signature to be added when this setting is set in the legacy version.
-		if(settings.get("createmail/signature/use","false")=="true"){
+		if(webclient.settings.get("createmail/signature/use","false")=="true"){
 			data["select_sig_newmsg"] = sigID;
 			data["select_sig_replyfwd"] = sigID;
 		}
 		// Set old signature to empty
-		settings.deleteSetting("createmail/signature/text");
+		webclient.settings.deleteSetting("createmail/signature/text");
 		// Save it!
 		saveSignaturesInSettings();
 	}
+}
+
+/**
+ * checkEditor
+ * 
+ * Check if editor is loaded. and also check we should be using fckediotr or not
+ * @return boolean returns true when editor is loaded, otherwise returns false.
+ */
+function checkEditor(){
+	// Check if HTML editor API is defined.
+	if(typeof FCKeditorAPI != "undefined" && USE_FCKEDITOR){
+		return true;
+	}else{
+		return false;
+	}
 }
\ No newline at end of file
