@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 createmailitemmodule.prototype = new ItemModule;
 createmailitemmodule.prototype.constructor = createmailitemmodule;
 createmailitemmodule.superclass = ItemModule.prototype;
@@ -67,6 +114,9 @@ createmailitemmodule.prototype.updateMessage = function(action)
 	property["entryid"] = (entryid && entryid.firstChild ?entryid.firstChild.nodeValue:false);
 	property["parententryid"] = (parententryid && parententryid.firstChild ?parententryid.firstChild.nodeValue:false);
 	
+	// Update message entryID.
+	this.messageentryid = property["entryid"];
+	
 	var entryidElement = dhtml.getElementById("entryid");
 	var parententryidElement = dhtml.getElementById("parent_entryid");
 	
@@ -86,6 +136,9 @@ createmailitemmodule.prototype.updateMessage = function(action)
 			var attach_method = attachments[i].getElementsByTagName("attach_method")[0];
 			var name = attachments[i].getElementsByTagName("name")[0];
 			var size = attachments[i].getElementsByTagName("size")[0];
+			var filetype = attachments[i].getElementsByTagName("filetype")[0];
+			var cid = attachments[i].getElementsByTagName("cid")[0];
+			var hidden = attachments[i].getElementsByTagName("hidden")[0];
 			
 			if(attach_num && attach_num.firstChild) {
 				var attachment = new Object();
@@ -102,11 +155,20 @@ createmailitemmodule.prototype.updateMessage = function(action)
 				if(size && size.firstChild) {
 					attachment["size"] = size.firstChild.nodeValue;
 				}
-				
+				attachment["filetype"] = (filetype && filetype.firstChild?filetype.firstChild.nodeValue:false);
+				attachment["cid"] = (cid && cid.firstChild?cid.firstChild.nodeValue:false);
+				attachment["hidden"] = (dhtml.getTextNode(hidden, false) == "1")?true:false;
 				this.attachments.push(attachment);
 			}
 		}
+		/**
+		 * Since message is saved, attachments are no longer avaliable from $_SESSION.
+		 * So, initialize inlineattachments and inlineimages again.
+		 */
+		this.inlineattachments = new Object();
+		this.inlineimages = new Array();
 		this.setAttachments();
+		this.setAttachmentbarAttachmentOptions();
 	}
 	window.waitForSaveResponse = false;
 }
@@ -126,6 +188,9 @@ createmailitemmodule.prototype.item = function(action)
 				var attach_method = attachments[i].getElementsByTagName("attach_method")[0];
 				var name = attachments[i].getElementsByTagName("name")[0];
 				var size = attachments[i].getElementsByTagName("size")[0];
+				var filetype = attachments[i].getElementsByTagName("filetype")[0];
+				var cid = attachments[i].getElementsByTagName("cid")[0];
+				var hidden = attachments[i].getElementsByTagName("hidden")[0];
 				
 				if(attach_num && attach_num.firstChild) {
 					var attachment = new Object();
@@ -142,7 +207,9 @@ createmailitemmodule.prototype.item = function(action)
 					if(size && size.firstChild) {
 						attachment["size"] = size.firstChild.nodeValue;
 					}
-					
+					attachment["filetype"] = (filetype && filetype.firstChild?filetype.firstChild.nodeValue:false);
+					attachment["cid"] = (cid && cid.firstChild?cid.firstChild.nodeValue:false);
+					attachment["hidden"] = (dhtml.getTextNode(hidden, false) == "1")?true:false;
 					this.attachments.push(attachment);
 				}
 			}
@@ -153,11 +220,13 @@ createmailitemmodule.prototype.item = function(action)
 			case "reply":
 				this.setSender(message);
 				this.setSubjectBody(message, _("RE"));
+				this.setInlineAttachmentData(this.attachments); //message contains inline attachments
 				break;
 			case "replyall":
 				this.setSender(message);
 				this.setRecipients(message, "replyall");
 				this.setSubjectBody(message, _("RE"));
+				this.setInlineAttachmentData(this.attachments); //message contains inline attachments
 				break;
 			case "forward":
 				this.setSubjectBody(message, _("FW"));
@@ -186,11 +255,54 @@ createmailitemmodule.prototype.item = function(action)
 		}
 
 		this.setFrom(message);
+		this.setDelegatorAsSender(message);
 	}
 
 	setImportance(parseInt(dhtml.getElementById("importance").value));
 }
 
+createmailitemmodule.prototype.setDelegatorAsSender = function(message)
+{
+	var delegatorStoreId = message.getElementsByTagName("store_entryid")[0].firstChild.nodeValue;
+	var delegateFlag = false;
+	var stores = parentWebclient.hierarchy.stores;
+	for(var storeIndex = 0;storeIndex<stores.length;storeIndex++){
+		if(stores[storeIndex].type == "other"){
+			var storeid = stores[storeIndex].id;
+
+			// Opened folder of another user will contain id and foldertype followed by '_', so remove foldertype
+			if(storeid.indexOf("_") > 0)
+				storeid = storeid.substr(0, storeid.indexOf("_"));
+
+			if(delegatorStoreId == storeid){
+				delegateFlag = true;
+				break;
+			}
+		}
+	}
+	if(delegateFlag){
+		var delegatorName = "";
+		var delegatorEmail = "";
+		if(message.getElementsByTagName("received_by_name"))
+			delegatorName = message.getElementsByTagName("received_by_name")[0].firstChild.nodeValue;
+
+		if(message.getElementsByTagName("received_by_email_address"))
+			delegatorEmail = message.getElementsByTagName("received_by_email_address")[0].firstChild.nodeValue;
+		
+		var delegateEmailAddress = delegatorName + " <" + delegatorEmail + ">";
+		var fromSelect = dhtml.getElementById("from", "select");
+		if(fromSelect){
+			var fromRow = dhtml.getElementById("from_row", "tr");
+			if(fromRow){
+				fromRow.style.display = "";
+			}
+			fromSelect.options[fromSelect.options.length] = new Option(delegateEmailAddress, delegateEmailAddress);
+			fromSelect.options[fromSelect.options.length-1].selected = true;
+		}
+		
+	}
+}
+
 createmailitemmodule.prototype.checkNames = function(action)
 {
 	var names = action.getElementsByTagName("name");
@@ -283,7 +395,7 @@ createmailitemmodule.prototype.setSubjectBody = function(message, type)
 		subjectElement.value = type + ": ";
 	}
 	
-	this.setBody(message, true);
+	this.setBody(message, true, false);
 }
 
 createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
@@ -355,36 +467,6 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 				// HACK: Remove newlines to fix HTML
 				content = content.replace(/\n/g, " ");
 				content = content.replace(/\r/g, " ");
-
-				// Remove all image tags of all inline images
-				var images_result = content.match(/<img[^>]*>/gmi);
-				if(typeof images_result == "object" && images_result != null && images_result.length > 1){
-					// Loop through all image tags
-					for(var i=0;i<images_result.length;i++){
-						// Split the image tag up to find the source attribute
-						var image_attr = images_result[i].split(" ");
-						// Loop through all attributes
-						for(var j=0;j<image_attr.length;j++){
-							// Filter out source attribute
-							if(image_attr[j].substr(0,4).toLowerCase() == "src="){
-								// We only need to have the value of the attribute
-								var image_src = image_attr[j].substr(4, image_attr[j].length);
-								// Remove the qoutes 
-								image_src = image_src.replace(/\'/g, "");
-								image_src = image_src.replace(/\"/g, "");
-								// Filter out inline images
-								if(image_src.substr(0, 7) != "http://" && image_src.substr(0, 8) != "https://"){
-									// Get starting position of the image tag in the email content
-									var l_iStartIndex = content.indexOf(images_result[i]);
-									if(l_iStartIndex > 0){
-										// Get the part before the image tag and after the image tag and glue it together
-										content = content.slice(0, l_iStartIndex) + content.slice((images_result[i].length + l_iStartIndex), content.length);
-									}
-								}
-							}
-						}
-					}
-				}
 			}
 
 			if (!isHTML && htmlFormat){
@@ -451,31 +533,69 @@ createmailitemmodule.prototype.setBody = function(message, isReply, isConcept)
 
 		var signature = "";
 		if(!isConcept){
-			signature = this.getSignature();
-			if(signature && signature != ""){
-				if (htmlFormat){
-					signature = signature.htmlEntities();
-					signature_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+			var signatureData = this.getSignatureData();
+
+			if(signatureData && signatureData != ""){
+				if(signatureData["type"] == "plain") {
+					// signature is stored in plain format
+					if(!htmlFormat) {
+						// no conversion
+						signature = signatureData["content"];
+						signature_seperator = "\n\n";
+					} else {
+						// convert plain signature to html format
+						signature = convertPlainToHtml(signatureData["content"]);
+						signature_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+					}
 				} else {
-					signature_seperator = "\n\n";
+					// signature is stored in html format
+					if(!htmlFormat) {
+						//convert html signature to plain text format
+						signature = convertHtmlToPlain(signatureData["content"]);
+						signature_seperator = "\n\n";
+					} else {
+						// no conversion
+						signature = signatureData["content"];
+						signature_seperator = "<p>&nbsp;<br/>&nbsp;</p>";
+					}
 				}
 				signature = signature_seperator + signature;
 			}
 		}
 		
-		content = signature + reply_seperator + contentprefix + replyinfo + content + contentpostfix;
+
+		// If cursorPos is set at end then don't add signature now.
+		var cursorPos = webclient.settings.get("createmail/cursor_position", "start");
+
+		if(cursorPos == "end" && isReply) {
+			this.signature = signature;
+			content = contentprefix + replyinfo + content + contentpostfix + reply_seperator;
+		} else {
+			content = signature + reply_seperator + contentprefix + replyinfo + content + contentpostfix;
+		}
+
 		if(htmlFormat) {
 			content = content.replace(/\n/g, "<br />");
 		}
 
 		// Check if HTML editor is loaded and set the body
-		if((typeof FCKeditorAPI != "undefined") && (fckEditor = FCKeditorAPI.GetInstance("html_body"))) {
-			document.fckEditor = fckEditor;
+		if(htmlFormat) {
+			/**
+			 * Store the content in a temporary variable. If the XML data is 
+			 * loaded before the FCK editor is ready we have to hold on to the 
+			 * body until the editor is loaded.
+			 */
 			document.fckEditorContent = content;
 
-			window.setTimeout(setBodyAfterTimeOut, "500");
+			// If the editor is already available and fully loaded we can set the body already.
+			if(document.fckEditor){
+				window.bodyset = true;
+				setContentInBodyArea();
+				setCursorPosition(this.messageAction);
+			}
 		} else {
 			html_body.value = content;
+			setCursorPosition(this.messageAction);
 		}
 	}
 }
@@ -499,7 +619,7 @@ createmailitemmodule.prototype.setData = function(data)
 	}
 }
 
-createmailitemmodule.prototype.save = function(props, send, recipients, dialog_attachments)
+createmailitemmodule.prototype.save = function(props, send, recipients, dialog_attachments, inlineimages)
 {
 	var data = new Object();
 	if(this.storeid) {
@@ -509,6 +629,7 @@ createmailitemmodule.prototype.save = function(props, send, recipients, dialog_a
 	data["props"] = props;
 	data["recipients"] = recipients;
 	data["dialog_attachments"] = dialog_attachments;
+	data["inline_attachments"] = inlineimages;
 	
 	// We don't want to save attachments again if message is already saved.	
 	if(this.message_action && (typeof props["entryid"] != 'undefined' && props["entryid"] == '')) {
@@ -538,9 +659,10 @@ createmailitemmodule.prototype.save = function(props, send, recipients, dialog_a
  * If no ID is supplied then check message_action (newmsg, reply, fwd).
  * @param id number (Optional) ID of the signature that needs to be retrieved.
  */
-createmailitemmodule.prototype.getSignature = function(id){
+createmailitemmodule.prototype.getSignatureData = function(id){
 	var signatureID = false;
 	var sig_content = "";
+
 	if(id){
 		var name = parentWebclient.settings.get("createmail/signatures/"+id+"/name", false);
 		if(name){
@@ -559,13 +681,15 @@ createmailitemmodule.prototype.getSignature = function(id){
 				signatureID = parentWebclient.settings.get("createmail/signatures/select_sig_newmsg", false);
 		}
 	}
+
 	if(signatureID){
-		sig_content = parentWebclient.settings.get("createmail/signatures/"+signatureID+"/content","");
+		sig_content = parentWebclient.settings.get("createmail/signatures/"+signatureID, "");
 	}
+
 	return sig_content;
 }
 
-function setBodyAfterTimeOut()
+function setContentInBodyArea()
 {
 	if(document.fckEditor && document.fckEditor.SetHTML) {
 		document.fckEditor.SetHTML(document.fckEditorContent);
