@@ -1,11 +1,58 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 freebusymodule.prototype = new Module;
 freebusymodule.prototype.constructor = freebusymodule;
 freebusymodule.superclass = Module.prototype;
 
 function freebusymodule(startTime)
 {
-	this.daysBefore = 7;
-	this.numberOfDays = 28;//total days in the view including 'this.daysBefore'
+	this.daysBefore = FREEBUSY_DAYBEFORE_COUNT;
+	this.numberOfDays = FREEBUSY_NUMBEROFDAYS_COUNT;//total days in the view including 'this.daysBefore'
 	this.userList = new Object();
 	this.userList["all"] = new Object();
 	this.userList["all"]["items"] = new Array();
@@ -118,7 +165,7 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 	//events for "add name"
 	dhtml.addEvent(this.moduleID,dhtml.getElementById("new_name","input",this.element),"focus",fbViewFocusAddNameInputBox);
 	dhtml.addEvent(this.moduleID,dhtml.getElementById("new_name","input",this.element),"blur",fbViewBlurAddNameInputBox);
-	dhtml.addEvent(this.moduleID,dhtml.getElementById("new_name","input",this.element),"keyup",fbViewKeyupAddNameInputBox);
+	dhtml.addEvent(this.moduleID,dhtml.getElementById("new_name","input",this.element),"keydown",fbViewKeyDownAddNameInputBox);
 
 	//update freebusyinfo
 	for(var tmpUser in this.userList){
@@ -133,18 +180,28 @@ freebusymodule.prototype.initView = function(zoom,user,recips)
 		newUser[0] = new Object();
 		newUser[0]["resolvename"] = this.user;
 		newUser[0]["clientuser"] = "c_user";
-		newUser[0]["recipienttype"] = 0;
-		newUser[0]["recipient_flags"] = 3;
+		newUser[0]["recipienttype"] = MAPI_ORIG;
+		newUser[0]["recipient_flags"] = recipSendable | recipOrganizer;
+		// itemProps are not set if the new meeting request is created.
+		if(module.itemProps != undefined && module.itemProps["sent_representing_email_address"]){
+			newUser[0]["emailaddress"] = module.itemProps["sent_representing_email_address"];
+		}else{
+			newUser[0]["emailaddress"] = "";
+		}
 		
 		for(i=0;i<recips.length;i++) {
 			if(i==0){
 				continue;
 			}
 			user = new Array();
-			user['resolvename'] = recips[i]['fullname'];
-			user['recipienttype'] = recips[i]['recipienttype'];
-			user['recipient_flags'] = recips[i]['recipient_flags'];
-			newUser.push(user);
+			// if any user is organiser then not add him in userList as he is already added as c_user.
+			if((parseInt(recips[i]["recipient_flags"],10) & recipOrganizer) != recipOrganizer){
+				user['resolvename'] = recips[i]['fullname'];
+				user['recipienttype'] = recips[i]['recipienttype'];
+				user['recipient_flags'] = recips[i]['recipient_flags'];
+				user['emailaddress'] = recips[i]['emailaddress'];
+				newUser.push(user);
+			}
 		}
 		
 		this.createUsers(newUser);
@@ -201,7 +258,7 @@ freebusymodule.prototype.addBusyInfo = function(inputUserList)
 		this.userList[clientuser]["fullname"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("fullname")[0],"");
 		this.userList[clientuser]["entryid"] =      dhtml.getTextNode(inputUserList[i].getElementsByTagName("entryid")[0],"");
 		this.userList[clientuser]["username"] =     dhtml.getTextNode(inputUserList[i].getElementsByTagName("username")[0],"");
-		this.userList[clientuser]["emailaddress"] = dhtml.getTextNode(inputUserList[i].getElementsByTagName("email")[0],"");
+		this.userList[clientuser]["emailaddress"] = dhtml.getTextNode(inputUserList[i].getElementsByTagName("email")[0], this.userList[clientuser]["emailaddress"]);
 
 		//put the items in the "userList"
 		this.userList[clientuser]["items"] = new Array();
@@ -241,7 +298,7 @@ freebusymodule.prototype.createUsers = function(inputList)
 		this.userList[clientuser]["resolvename"] = inputList[i]["resolvename"];
 		this.userList[clientuser]["entryid"] = "";
 		this.userList[clientuser]["username"] = "";
-		this.userList[clientuser]["emailaddress"] = "";
+		this.userList[clientuser]["emailaddress"] = inputList[i]["emailaddress"];
 		this.userList[clientuser]["recipienttype"] = inputList[i]["recipienttype"];
 		this.userList[clientuser]["recipient_flags"] = inputList[i]["recipient_flags"];
 		this.userList[clientuser]["items"] = new Array();
@@ -256,7 +313,12 @@ freebusymodule.prototype.createUsers = function(inputList)
 
 	}
 	// create meeting request (module is the global appointment module)
-	meetingRequestSetup(1);
+	if(this.userCount == 0 || (this.userList["c_user"]["emailaddress"] == "") || (this.userList["c_user"]["emailaddress"].toLowerCase() == webclient.emailaddress.toLowerCase())){
+		meetingRequestSetup(1)
+	}else{
+		meetingRequestSetup(2);
+	}
+
 	module.setUserList(this.getUserList());
 	webclient.xmlrequest.sendRequest(false);
 }
@@ -399,87 +461,65 @@ freebusymodule.prototype.updateUserListView = function()
 	var currentElement = this.nameListElement.getElementsByTagName("div");
 	
 	var i=0;
-
 	for(var userid in this.userList){
 		if(userid != "all"){
 			var fullname = this.userList[userid]["fullname"];
+			var nameElement = false;
 			if(currentElement[i]){
 				//update item
 				if(currentElement[i].firstChild.nodeValue != fullname){
 					currentElement[i].setAttribute("clientuser",userid);
-
-					// Check if the user is not the organizer of the meetingrequest
-					if(userid != "c_user"){
-						dhtml.deleteAllChildren(currentElement[i]);
-						//dhtml.addTextNode(recipType, "TEST");
-
-						var recipType = dhtml.addElement(currentElement[i], "span", "icon", "" , "");
-						switch(this.userList[userid].recipienttype){
-							case MAPI_ORIG:
-								dhtml.addClassName(recipType, "icon_meetingrequest_organizer");
-								break;
-							case MAPI_TO:
-								dhtml.addClassName(recipType, "icon_meetingrequest_requiredattendee");
-								break;
-							case MAPI_CC:
-								dhtml.addClassName(recipType, "icon_meetingrequest_optionalattendee");
-								break;
-							case MAPI_BCC:
-								dhtml.addClassName(recipType, "icon_meetingrequest_resource");
-								break;
-						}
-						var dropdownRecipType = dhtml.addElement(recipType, "span", "icon meetingrequest_dropdownarrow", "", NBSP);
-						recipType.userid = userid;
-						dhtml.addEvent(this, recipType, "click", fbClickRecipientTypeDropdown);
-
-
-						var delUserElement = dhtml.addElement(currentElement[i],"span","icon icon_delete","",NBSP);
-
-						dhtml.addEvent(this.moduleID,delUserElement,"click",fbViewClickRemoveUser);
-						dhtml.addElement(currentElement[i],"span","","",fullname);
-					}
-					// User is the organizer of the meeting
-					else{
-						dhtml.deleteAllChildren(currentElement[i]);
-
-						var recipType = dhtml.addElement(currentElement[i], "span", "icon", "" , "");
-						dhtml.addClassName(recipType, "icon_meetingrequest_organizer");
-
-						dhtml.addElement(currentElement[i],"span","","",fullname);
-					}
-					this.updateBusyInfo(userid);
+					dhtml.deleteAllChildren(currentElement[i]);
+					nameElement = currentElement[i];
 				}
-			}
-			else{
+			} else {
 				//create item
 				var newNameElement = dhtml.addElement(this.nameListElement,"div","name_list_item")//,"namelist_"+i,fullname); @FIXME
 				newNameElement.setAttribute("clientuser",userid);
+				nameElement = newNameElement;
+			}
 
-				//var recipType = dhtml.addElement(newNameElement, "span", "icon", "" , "");
-				//dhtml.addClassName(recipType, "icon_meetingrequest_organizer");
-
-				// Check if the user is not the organizer of the meeting
-				if(userid != "c_user"){
-					//dhtml.addEvent(this.moduleID,newNameElement,"click",fbViewClickRemoveUser);
-					//dhtml.addEvent(this.id,newNameElement,"context",eventFreeBusydModuleContextMenu);
-					var delUserElement = dhtml.addElement(newNameElement,"span","icon_delete");
-
-					delUserElement.style.paddingLeft = 16+"px";
-					dhtml.addEvent(this.moduleID,delUserElement,"click",fbViewClickRemoveUser);
-
+			if(nameElement !== false) {
+				var recipType = dhtml.addElement(nameElement, "span", "icon", "" , "");
+				switch(this.userList[userid].recipienttype){
+					case MAPI_ORIG:
+						dhtml.addClassName(recipType, "icon_meetingrequest_organizer");
+						break;
+					case MAPI_TO:
+						dhtml.addClassName(recipType, "icon_meetingrequest_requiredattendee");
+						break;
+					case MAPI_CC:
+						dhtml.addClassName(recipType, "icon_meetingrequest_optionalattendee");
+						break;
+					case MAPI_BCC:
+						dhtml.addClassName(recipType, "icon_meetingrequest_resource");
+						break;
 				}
 
-				dhtml.addElement(newNameElement,"span","name_list_item_fullname","",fullname);
+				// Check if the user is not the organizer of the meetingrequest
+				if(userid != "c_user") {
+					var dropdownRecipType = dhtml.addElement(recipType, "span", "icon meetingrequest_dropdownarrow", "", NBSP);
+					recipType.userid = userid;
+					dhtml.addEvent(this, recipType, "click", fbClickRecipientTypeDropdown);
 
+					var delUserElement = dhtml.addElement(nameElement,"span","icon icon_delete","",NBSP);
+					dhtml.addEvent(this.moduleID,delUserElement,"click",fbViewClickRemoveUser);
+				}
+
+				dhtml.addElement(nameElement,"span","name_list_item_fullname","",fullname);
+				this.updateBusyInfo(userid);
 			}
+
 			i++;
 		}
 	}
-	
+
 	//remove items
 	for(;i<currentElement.length;i++){
 		dhtml.deleteElement(currentElement[i]);
 	}
+	//update the user list values in to/cc/bcc & toccbcc feild in appointment dialog
+	module.setUserList(this.getUserList());
 	this.resizeGrid();
 }
 
@@ -863,6 +903,7 @@ freebusymodule.prototype.setUserList = function(inputUserlist)
 				newUserList[i] = new Object();
 				newUserList[i]["resolvename"] = inputUserlist[userInput]["fullname"];
 				newUserList[i]["recipienttype"] = inputUserlist[userInput]["recipienttype"];
+				newUserList[i]["emailaddress"] = inputUserlist[userInput]["emailaddress"];
 				i++;
 			}
 		}
@@ -919,9 +960,10 @@ function fbViewBlurAddNameInputBox(moduleObject, element, event)
 	}
 }
 
-function fbViewKeyupAddNameInputBox(moduleObject, element, event)
+function fbViewKeyDownAddNameInputBox(moduleObject, element, event)
 {
-	if(event.keyCode == 13){
+	if(event.keyCode == 13 || event.keyCode == 9){
+		if (event.keyCode == 9 && element.value.trim() != "") event.preventDefault();
 	
 		var newUser = new Array();
 		newUser[0] = new Object();
