@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 hierarchymodule.prototype = new Module;
 hierarchymodule.prototype.constructor = hierarchymodule;
 hierarchymodule.superclass = Module.prototype;
@@ -43,8 +90,11 @@ hierarchymodule.prototype.init = function(id, element)
 		var mucLink = dhtml.addElement(this.sharedFoldersElement,"a", false, false, _("Open Multi User Calendar"));
 		dhtml.addEvent(this.id, mucLink, "click", eventAdvancedCalendarClick);
 	}
+	webclient.pluginManager.triggerHook('client.module.hierarchymodule.sharedFoldersPane.buildup', {sharedFoldersElement: this.sharedFoldersElement});
 	
 	dhtml.addEvent(this.id, document.body, "mouseup", eventHierarchyCheckSelectedContextFolder);
+	dhtml.addEvent(this.id, this.contentElement, "mousemove", eventHierarchyMouseMoveScroll);
+
 }
 
 hierarchymodule.prototype.execute = function(type, action)
@@ -84,6 +134,9 @@ hierarchymodule.prototype.execute = function(type, action)
 						case "username":
 							store["username"] = item.nodeValue;
 							break;
+						case "emailaddress":
+							store["emailaddress"] = item.nodeValue;
+							break;
 						case "foldertype":
 							store["foldertype"] = item.nodeValue;
 							break;
@@ -128,11 +181,26 @@ hierarchymodule.prototype.execute = function(type, action)
 						newStore = false;
 					}
 					
-					if(store.type=="other" && this.stores[i].type=="other" && this.stores[i].username==store.username && store.foldertype=="all"){
+					if(store.type=="other" && this.stores[i].type=="other" && this.stores[i].username.toLowerCase()==store.username.toLowerCase() && store.foldertype=="all"){
 						this.stores[i] = store;
 						newStore = false;
 					}
+
+					// we have found that we are updating an older store, so break the loop here
+					if(newStore === false) {
+						break;
+					}
 				}
+
+				if(store.type == "other" && store.foldertype == "all") {
+					// if we are adding whole store of an user then we should also remove folders that were added for same user
+					for(var i=0; i<this.stores.length; i++) {
+						if(this.stores[i].type == "other" && this.stores[i].foldertype != "all" && this.stores[i].username.toLowerCase() == store.username.toLowerCase()) {
+							this.stores.splice(i, 1);
+						}
+					}
+				}
+
 				if (newStore){
 					this.stores.push(store);
 				}
@@ -237,7 +305,7 @@ hierarchymodule.prototype.execute = function(type, action)
 		case "error":
 			var errors = action.getElementsByTagName("error")[0];
 			var hresult = dhtml.getTextNode(errors.getElementsByTagName("hresult")[0],"");
-			var username = dhtml.getTextNode(errors.getElementsByTagName("username")[0],"");
+			var username = dhtml.getTextNode(errors.getElementsByTagName("username")[0],"").toLowerCase();
 			var errorString = dhtml.getTextNode(errors.getElementsByTagName("message")[0],"");
 			if(username.length > 0){
 				webclient.settings.deleteSetting("otherstores/"+username);
@@ -475,7 +543,7 @@ hierarchymodule.prototype.createHierarchyList = function(load)
 			tree.buildTree();
 		}else{
 			//delete user if you have no access
-			webclient.settings.deleteSetting("otherstores/"+store["username"]);
+			webclient.settings.deleteSetting("otherstores/"+store["username"].toLowerCase());
 		}
 	}
 	
@@ -932,11 +1000,12 @@ hierarchymodule.prototype.showSharedFolderActions = function()
 
 hierarchymodule.prototype.openSharedFolder = function(username, foldertype)
 {
+    username = username.toLowerCase();
 	if (typeof foldertype == "undefined"){
 		foldertype = "all";
 	}
 
-	if (username == webclient.username){
+	if (username == webclient.username.toLowerCase()){
 		alert(_("This shared folder is your own folder."));
 		return false;
 	}
@@ -964,6 +1033,7 @@ hierarchymodule.prototype.openSharedFolder = function(username, foldertype)
 
 hierarchymodule.prototype.closeSharedFolder = function(username, foldertype)
 {
+    username = username.toLowerCase();
 	if (typeof foldertype == "undefined"){
 		foldertype = "all";
 	}
@@ -996,6 +1066,27 @@ function eventHierarchyCheckSelectedContextFolder(moduleObject, element, event)
 	}
 }
 
+function eventHierarchyMouseMoveScroll(moduleObject, element, event){
+	// return if the drag event is not occuring.
+	if(!dragdrop.targetover) return;
+	
+	//get the element' top position 
+	var elementTop = element.offsetTop || 0;
+	var tempEl = element.offsetParent;
+	//get the actuall top position from the very top left corner of browser area.
+	while (tempEl != null) {
+		elementTop += tempEl.offsetTop;
+		tempEl = tempEl.offsetParent;
+	}
+
+	//calculate the mouse position on element and do the scrolling
+	if(event.clientY < (elementTop+20)){
+		element.scrollTop -= 5;
+	}else if(event.clientY > (elementTop+element.offsetHeight-20)){
+		element.scrollTop += 5;
+	}
+}
+
 function eventHierarchySelectFolder(moduleObject, element, event)
 {
 	if(!event) {
@@ -1015,6 +1106,7 @@ function eventHierarchySelectFolder(moduleObject, element, event)
 		moduleObject.selectedFolder = element.parentNode.id;
 		var folderName = element.getElementsByTagName("span")[0];
 		dhtml.removeClassName(folderName, "folder_title");
+		dhtml.removeClassName(folderName, "folder_title_context");
 		dhtml.addClassName(folderName, "folder_title_selected");
 	}
 }
@@ -1067,9 +1159,15 @@ function eventHierarchyChangeFolder(moduleObject, element, event)
 		if(folder) {
 			var data = new Object();
 			var storeid = moduleObject.folderstoreid;
+
+			// Opened folder of another user will contain id and foldertype followed by '_', so remove foldertype
+			if(storeid.indexOf("_") > 0)
+				storeid = storeid.substr(0,storeid.indexOf("_"));
 			
 			moduleObject.setNumberItems(folder["content_count"], folder["content_unread"]);
 			moduleObject.sendEvent("changefolder", storeid, folder);
+
+			document.title = (folder["content_unread"] != "0") ? folder["display_name"]+" (" + folder["content_unread"] + ") " : folder["display_name"];
 		}
 	}
 }
@@ -1082,7 +1180,7 @@ function eventHierarchyContextMenu(moduleObject, element, event)
 		if(folder) {
 			var folderIcon = folder.getElementsByTagName("div")[1];
 			var folderName = folderIcon.getElementsByTagName("span")[0];
-			folderName.className = folderName.className.substring(0, folderName.className.indexOf("folder_title_context"));
+			dhtml.removeClassName("folder_title_context");
 		}
 	}
 	
@@ -1134,6 +1232,8 @@ function eventHierarchyContextMenu(moduleObject, element, event)
 		}
 		items.push(webclient.menu.createMenuItem("properties", _("Properties"), false, eventHierarchyPropertiesFolder));
 
+		webclient.pluginManager.triggerHook('client.module.hierarchymodule.contextmenu.buildup', {contextmenu: items, folder: folder});
+
 		webclient.menu.buildContextMenu(moduleObject.id, folder["entryid"], items, event.clientX, event.clientY);
 	}
 	
@@ -1199,8 +1299,13 @@ function eventHierarchyPropertiesFolder(moduleObject, element, event)
 	var folder = moduleObject.getFolder(moduleObject.selectedContextFolder);
 	var disable_permissions = 0;
 	if(moduleObject.isPublicStore(folder["storeid"])) {
-		// disable permissions tab for public root folder & favorites folder
-		if(moduleObject.isFavoritesFolder(folder["entryid"]) || moduleObject.isRootFolder) {
+		/**
+		 * Disable permissions tab for public root folder & favorites (sub)folders
+		 * The check on the entryid (if it starts with 00000001) is used 
+		 * because a folder that has been added as favorites folder will 
+		 * have a flag at the start of the entryid. 
+		 */
+		if(moduleObject.isFavoritesFolder(folder["entryid"]) || moduleObject.isRootFolder || folder["entryid"].substr(0, 8) == "00000001") {
 			disable_permissions = 1;
 		}
 	}
