@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * ListModule
  * The list module extends from Module 
@@ -101,6 +148,7 @@ ListModule.prototype.init = function(id, element, title, data, uniqueid)
 		this.menuItems.push(webclient.menu.createMenuItem("delete", false, _("Delete messages"), eventListDeleteMessages));
 		this.menuItems.push(webclient.menu.createMenuItem("copy", false, _("Copy/Move messages"), eventListCopyMessages));
 		this.menuItems.push(webclient.menu.createMenuItem("print", false, _("Print"), eventListPrintMessage));
+		this.menuItems.push(webclient.menu.createMenuItem("addressbook", false, _("Addressbook"), eventListShowAddressbook));
 	}
 	
 	var items = new Array();
@@ -142,6 +190,8 @@ ListModule.prototype.init = function(id, element, title, data, uniqueid)
 	this.events["insertrow"]["click"] = eventInputFieldClick;
 	this.events["insertrow"]["mousedown"] = eventDeselectMessages;
 	this.events["insertrow"]["keydown"]= eventClickSaveMessage;
+	this.events["insertrow"]["mousemove"]= eventListInsertRowMouseMove;
+	this.events["insertrow"]["selectstart"]= eventListInsertRowMouseMove;
 	
 	this.events["insertcolumn"] = new Object();
 	this.events["insertcolumn"]["importance"] = new Object();
@@ -152,14 +202,16 @@ ListModule.prototype.init = function(id, element, title, data, uniqueid)
 	this.events["row"]["mouseup"] = eventListMouseUpMessage;
 	this.events["row"]["dblclick"] = eventListDblClickMessage;
 	this.events["row"]["contextmenu"] = eventListContextMenuMessage;
+	this.events["row"]["mousemove"]= eventListRowMouseMove;
+	this.events["row"]["selectstart"]= eventListRowMouseMove;
 	
 	this.events["rowcolumn"] = new Object();
 	this.events["rowcolumn"]["icon_index"] = new Object();
 	this.events["rowcolumn"]["icon_index"]["click"] = eventListChangeReadFlag;
-	this.events["rowcolumn"]["flag_status"] = new Object();
-	this.events["rowcolumn"]["flag_status"]["mouseover"] = eventListMouseOverFlag;
-	this.events["rowcolumn"]["flag_status"]["mouseout"] = eventListMouseOutFlag;
-	this.events["rowcolumn"]["flag_status"]["click"] = eventListChangeFlagStatus;
+	this.events["rowcolumn"]["flag_icon"] = new Object();
+	this.events["rowcolumn"]["flag_icon"]["mouseover"] = eventListMouseOverFlag;
+	this.events["rowcolumn"]["flag_icon"]["mouseout"] = eventListMouseOutFlag;
+	this.events["rowcolumn"]["flag_icon"]["click"] = eventListChangeFlagStatus;
 	this.events["rowcolumn"]["complete"] = new Object();
 	this.events["rowcolumn"]["complete"]["click"] = eventListChangeCompleteStatus;
 	this.events["rowcolumn"]["complete"]["mouseup"] = eventListStopBubble;
@@ -311,10 +363,23 @@ ListModule.prototype.messageList = function(action)
 			property["visible"] = (visible && visible.firstChild?visible.firstChild.nodeValue:false);
 			property["type"] = (type && type.firstChild?type.firstChild.nodeValue:false);
 			
-			this.propertylist.push(property);
-			
-			if(property["visible"]) {
-				this.properties.push(property);
+			if(webclient.hasRightPane){
+				switch(property["id"]){
+					case ("display_to"):
+					case ("sent_representing_name"):
+					case ("client_submit_time"):
+					case ("message_delivery_time"):
+						this.propertylist.push(property);
+						if(property["visible"]) {
+							this.properties.push(property);
+						}
+						break;
+				}
+			}else{
+				this.propertylist.push(property);
+				if(property["visible"]) {
+					this.properties.push(property);
+				}
 			}
 		}
 	}
@@ -467,7 +532,7 @@ ListModule.prototype.selectFirstItem = function()
 ListModule.prototype.item = function(action)
 {
 	var items = action.getElementsByTagName("item");
-
+	this.editMessage = false;
 	// Loop through all updated items (add/modify)
 	if(items && items.length > 0) {
 		for(var i = 0; i < items.length; i++)
@@ -540,8 +605,11 @@ ListModule.prototype.deleteItems = function(action)
 
 	// check if one of the messages were selected
 	var isSelected = false;
+	// array which stores all rowids which are to be deleted.
+	var selectedrowids = new Array();
 	for(var i = 0; i<entryid.length; i++){
 		var rowid = this.getRowId(entryid[i].firstChild.nodeValue);
+		selectedrowids.push(rowid);
 		if (this.isMessageSelected(rowid)){
 			isSelected = true;
 		}
@@ -553,11 +621,38 @@ ListModule.prototype.deleteItems = function(action)
 		if(first_entryid && first_entryid.firstChild ) {
 			var rowid = this.getRowId(first_entryid.firstChild.nodeValue);
 			var item = dhtml.getElementById(rowid);
-	
+
 			if(item) {
 				var nextItem = item.nextSibling;
+				if(nextItem) {
+					// find next item untill we get an unselected item
+					while(inArray(nextItem.id, selectedrowids) === true) {
+						if(nextItem.nextSibling) {
+							nextItem = nextItem.nextSibling;
+							continue;
+						} else {
+							// this is the last item, so no next item left
+							nextItem = null;
+							break;
+						}
+					}
+				}
+
+				// If there isnt any next item which is unselected then go for previous items
 				if(!nextItem) {
 					nextItem = item.previousSibling;
+					if(nextItem) {
+						while(inArray(nextItem.id, selectedrowids) === true) {
+							if(nextItem.previousSibling) {
+								nextItem = nextItem.previousSibling;
+								continue;
+							} else {
+								// probably the whole view is empty or all items are selected
+								nextItem = null;
+								break;
+							}
+						}
+					}
 				}
 
 				if(nextItem) {
@@ -676,78 +771,80 @@ ListModule.prototype.getRowId = function(entryid)
  */ 
 ListModule.prototype.list = function(useTimeOut, noLoader)
 {
-	if(this.storeid && this.entryid) {
-		var data = new Object();
-		data["store"] = this.storeid;
-		data["entryid"] = this.entryid;
+    var data = new Object();
+    data["store"] = this.storeid;
+    data["entryid"] = this.entryid;
 
-		this.sort = this.loadSortSettings();
-		if(this.sort) {
-			data["sort"] = new Object();
-			data["sort"]["column"] = this.sort;
-		}
-		
-		this.columns = this.loadFieldSettings();
-		
-		if(this.columns) {
-			var tablecolumns = new Array();
-			for(var i = 0; i < this.columns.length; i++)
-			{
-				var column = new Object();
-				column["attributes"] = new Object();
-				column["attributes"]["action"] = this.columns[i]["action"];
-				
-				if(this.columns[i]["order"]) {
-					column["attributes"]["order"] = this.columns[i]["order"];
-				}
-				
-				column["_content"] = this.columns[i]["id"];
-				tablecolumns.push(column);	
-			}
-			
-			data["columns"] = new Object();
-			data["columns"]["column"] = tablecolumns;
-			
-			this.columns = new Array();
-		}
-		
-		
-		data["restriction"] = new Object();
-		
-		if(this.getRestrictionData) {
-			data["restriction"] = this.getRestrictionData(); 
-			if(data["restriction"] == false)
-				return; // Abort list if module requires restriction but has none
-		}
-		
-		data["restriction"]["start"] = this.rowstart;
+    this.sort = this.loadSortSettings();
+    if(this.sort) {
+        data["sort"] = new Object();
+        data["sort"]["column"] = this.sort;
+    }
+    
+    this.columns = this.loadFieldSettings();
+    
+    if(this.columns) {
+        var tablecolumns = new Array();
+        for(var i = 0; i < this.columns.length; i++)
+        {
+            var column = new Object();
+            column["attributes"] = new Object();
+            column["attributes"]["action"] = this.columns[i]["action"];
+            
+            if(this.columns[i]["order"] !== false) {
+                column["attributes"]["order"] = this.columns[i]["order"];
+            }
+            
+            column["_content"] = this.columns[i]["id"];
+            tablecolumns.push(column);	
+        }
+        
+        data["columns"] = new Object();
+        data["columns"]["column"] = tablecolumns;
+        
+        this.columns = new Array();
+    }
+    
+    
+    data["restriction"] = new Object();
+    
+    if(this.getRestrictionData) {
+        data["restriction"] = this.getRestrictionData(); 
+        if(data["restriction"] == false)
+            return; // Abort list if module requires restriction but has none
+    }
+    
+    data["restriction"]["start"] = this.rowstart;
 
-		if(typeof this.searchSubfolders != "undefined") {
-			// if search folder then also check for subfolders option
-			data["subfolders"] = this.searchSubfolders;
-		}
-
-		// Retrieve data in extended (address cards view, calendar view, etc...) way 
-		// or the normal (table) way.
-		data["data_retrieval"] = (this.viewController.view=="table"?"normal":"extended");
-
-		webclient.xmlrequest.addData(this, "list", data);
-		
-		if (!noLoader)
-			this.viewController.loadMessage();
+	if(typeof this.searchSubfolders != "undefined") {
+		// if search folder then also check for subfolders option
+		data["subfolders"] = this.searchSubfolders;
 	}
+
+	// Retrieve data in extended (address cards view, calendar view, etc...) way 
+	// or the normal (table) way.
+	data["data_retrieval"] = (this.viewController.view=="table"?"normal":"extended");
+
+    webclient.xmlrequest.addData(this, "list", data);
+    
+    if (!noLoader)
+        this.viewController.loadMessage();
 }
 
 /**
  * Function which saves a set of properties for a message.
  * @param object props the properties which should be saved 
  */ 
-ListModule.prototype.save = function(props, send)
+ListModule.prototype.save = function(props, send, drag)
 {
 	var data = new Object();
 	data["store"] = this.storeid;
 	data["parententryid"] = this.entryid;
 	data["props"] = props;
+	//if an  recurring appointment item is drag to some other position then true.
+	if(drag){
+		data["drag"] = true;
+	}
 
 	if (send){
 		data["send"] = true;
@@ -1078,19 +1175,26 @@ ListModule.prototype.loadSortSettings = function ()
 {
 	var path = "folders/entryid_"+this.entryid+"/sort";
 	
-	var column = new Object();
-	column["attributes"] = new Object();
 	data = webclient.settings.get(path);
+
+	// Save the rows which are to be sorted in an array.
+	var sortColumns = new Array();
 	for(var i in data){
 		if(i != "prototype"){//workarround		
+			var column = new Object();
+			column["attributes"] = new Object();
 			column["attributes"]["direction"] = data[i];
 			column["_content"] = i;
+			// push column in a sortColumns array
+			sortColumns.push(column);
 		}
 	}
-	if(!column["_content"]){
+
+	// If sortColumns is not available then return false otherwise return sortColumns.
+	if(sortColumns.length <= 0){
 		var result = false;
 	}else{
-		var result = new Array(column);
+		var result = sortColumns;
 	}
 	return result;
 }
@@ -1315,6 +1419,21 @@ ListModule.prototype.CreateEditFields = function (moduleObject, element, event)
 	}, 500);
 }
 
+/**
+ * getDragDropTargetCallback
+ * 
+ * This function returns the correct event function to handle the dragdrop event. 
+ * 
+ * @return function dragdrop even function
+ */
+ListModule.prototype.getDragDropTargetCallback = function(){
+	if(eventListDragDropTarget){
+		return eventListDragDropTarget;
+	}else{
+		return false;
+	}
+}
+
 /**
  * Receives callback from the categories window
  */
@@ -1398,15 +1517,18 @@ function eventListMouseDownMessage(moduleObject, element, event)
 			moduleObject.selectedFirstMessage = element.id;
 			moduleObject.viewController.setCursorPosition(element.id);
 		}
-		
+
+		// clear the text selection on document.
+		dhtml.clearBodySelection();
 	}
 	
 	// save changes and dactivate editmode, if 'mousedown' on other item...
 	if (moduleObject.editMessage !== false && moduleObject.editMessage !== element.id) {
 		// here we have to pass element id of message which is in edit mode
 		// not the current element
-		moduleObject.SubmitMessage(moduleObject, dhtml.getElementById(moduleObject.editMessage), event);
-		moduleObject.removeinputfields(moduleObject, element, event);
+		if (moduleObject.SubmitMessage(moduleObject, dhtml.getElementById(moduleObject.editMessage), event)){
+			moduleObject.removeinputfields(moduleObject, element, event);
+		}
 	}
 
 	// As 'mousedown' event is also registered for divelement we don't want the event to bubble to divelement.
@@ -1473,10 +1595,10 @@ function eventListDblClickMessage(moduleObject, element, event)
 			dhtml.addEvent(moduleObject.id, dhtml.getElementById("property_module"+moduleObject.id +"_"+ element.id +"_complete"), "click", eventListChangeCompleteStatus);
 		}
 		
-		moduleObject.SubmitMessage(moduleObject, element, event);
-		moduleObject.editMessage = false;
-		moduleObject.dblclick = false;
-		moduleObject.editMessage = false;
+		if (moduleObject.SubmitMessage(moduleObject, element, event)){
+			moduleObject.dblclick = false;
+			moduleObject.editMessage = false;
+		}
 	} else if(!moduleObject.editMessage) {
 		var messageClass = false;
 		var classNames = element.className.split(" ");
@@ -1501,7 +1623,7 @@ function eventListContextMenuMessage(moduleObject, element, event)
 		
 		if(message) {
 			if(message.className.indexOf(classNameContextMenu) > 0) {
-				message.className = message.className.substring(0, message.className.indexOf(classNameContextMenu));
+				dhtml.removeClassName(message, classNameContextMenu);
 			}
 		}
 	}
@@ -1602,6 +1724,7 @@ function eventListNewMessage(moduleObject, element, event)
 	}
 
 	var parententryID = moduleObject.entryid;
+	var storeID = moduleObject.storeid;
 
 	if(messageClass) {
 		var extraParams = "";
@@ -1613,13 +1736,18 @@ function eventListNewMessage(moduleObject, element, event)
 			var dtmodule = webclient.getModulesByName("datepickerlistmodule");
 			if (dtmodule[0] && dtmodule[0].selectedDate){
 				if (!new Date(dtmodule[0].selectedDate).isSameDay(new Date())){
-					newappDate = timeToZero(new Date(dtmodule[0].selectedDate).getTime()/1000)+((webclient.settings.get("calendar/workdaystart",9*60)*(ONE_HOUR/1000))/60);
-					extraParams = "&date="+newappDate;
+					var hourCount = webclient.settings.get("calendar/workdaystart",9 * 60) / 60;
+					var newAppDateTimeStamp = addHoursToUnixTimeStamp(dtmodule[0].selectedDate / 1000, hourCount);
+					extraParams = "&date=" + newAppDateTimeStamp;
 				}
 			}
+		} else if (messageClass == "createmail"){
+			// Select default store when creating new mail while other's Inbox is opened
+			storeID = webclient.hierarchy.defaultstore.id;
+			parententryID = webclient.hierarchy.defaultstore.defaultfolders.outbox;
 		}
 
-		webclient.openWindow(moduleObject, messageClass, DIALOG_URL+"task=" + messageClass + "_standard&storeid=" + moduleObject.storeid + "&parententryid=" + parententryID + extraParams);
+		webclient.openWindow(moduleObject, messageClass, DIALOG_URL+"task=" + messageClass + "_standard&storeid=" + storeID + "&parententryid=" + parententryID + extraParams);
 	}
 }
 
@@ -1648,6 +1776,12 @@ function eventListPrintMessage(moduleObject, element, event)
 	}
 }
 
+function eventListShowAddressbook(moduleObject, element, event)
+{
+    // Although this window is not modal, we're using the modal addressbook dialog anyway
+    webclient.openWindow(moduleObject, 'addressbook', DIALOG_URL+'task=addressbook_modal&storeid=' + moduleObject.storeid, 550, 410, true);    
+}
+
 function eventListMouseOverFlag(moduleObject, element, event)
 {
 	element.className += "_over";
@@ -1766,6 +1900,14 @@ function eventListColumnSort(moduleObject, element, event)
 	
 	var sortSaveList = Object();
 	sortSaveList[sortColumn] = sortDirection
+	
+	/**
+	 * flag status column value depends on values of flag_status and flag_icon properties,
+	 * so do sorting on both properties.
+	 */
+	if(sortColumn == "flag_icon")
+		sortSaveList["flag_status"] = sortDirection;
+
 	moduleObject.saveSortSettings(sortSaveList);
 
 	//Check if there is any restriction on sorting
@@ -1848,7 +1990,14 @@ function eventListColumnDelete(moduleObject, element, event)
 function eventListFieldChooser(moduleObject, element, event)
 {
 	element.parentNode.style.display = "none";
-	webclient.openModalDialog(moduleObject, "fieldchooser", DIALOG_URL+"task=fieldchooser_modal", 550, 470, fieldChooserCallBack, moduleObject);
+	/**
+	 * If field chooser is opened by main window then take webclient as its parent window.
+	 * If field chooser is opened from some dialog box then take it's parentwebclient object to open.
+	 */
+	if (typeof parentWebclient != "undefined")
+		parentWebclient.openModalDialog(moduleObject, "fieldchooser", DIALOG_URL+"task=fieldchooser_modal", 550, 470, fieldChooserCallBack, moduleObject);
+	else
+		webclient.openModalDialog(moduleObject, "fieldchooser", DIALOG_URL+"task=fieldchooser_modal", 550, 470, fieldChooserCallBack, moduleObject);
 }
 
 function eventListDragDropTarget(moduleObject, targetElement, element, event)
@@ -1873,18 +2022,72 @@ function eventListDragDropTarget(moduleObject, targetElement, element, event)
 		selectedMessages = selectedMessagesArr;
 	}
 
-	// Message entryids
-	var entryid = Array();
-	for(var i=0;i<selectedMessages.length;i++){
-		entryid.push(moduleObject.entryids[selectedMessages[i]]);
-	}
-	
-	//var entryid = moduleObject.entryids[element.elementid];
+	// Flag for checking whether target is waste basket (Deleted items folder) or not.
+	var targetIsWasteBasket = false;
 
 	var folderObject = webclient.hierarchy.getFolder(folder);
 
-	if(folder != moduleObject.entryid && folderObject) {
+	// get target folder entryid
+	var targetStoreID = folderObject.storeid;
+	var targetEntryID = folderObject.entryid;
+
+	// get target folder properties
+	var targetFolderProperties = webclient.hierarchy.getFolder(targetEntryID);
+	var targetFolderContainerClass = targetFolderProperties.container_class;
+	var targetFolderContainerClassParts = targetFolderContainerClass.split('.') ;
+
+	if(targetFolderProperties["entryid"] == webclient.hierarchy.defaultstore.defaultfolders.wastebasket) {
+		// allow copy/move operation for all items if destination folder is deleted items
+		targetIsWasteBasket = true;
+	}
+
+	// Message entryids
+	var entryid = Array();
+	for(var i=0;i<selectedMessages.length;i++){
+		if (moduleObject.entryids[selectedMessages[i]]) {
+			if(targetIsWasteBasket) {
+				// If target is waste basket (Deleted items folder) then move all items to entryid array
+				entryid.push(moduleObject.entryids[selectedMessages[i]]);
+			} else {
+				var selectedItemMessageClassParts = moduleObject.itemProps[moduleObject.entryids[selectedMessages[i]]].message_class.split(".");
+				if(targetFolderContainerClassParts[1] == selectedItemMessageClassParts[1]) {
+					// If target folder is of same message class as selected item's message class then move item to entryid array
+					entryid.push(moduleObject.entryids[selectedMessages[i]]);
+				} else if (selectedItemMessageClassParts[1] == "Schedule" && targetFolderContainerClassParts[1] == "Note") {
+					/**
+					 * If selected item's message class is IPM.Schedule.Meeting.Request 
+					 * then allow it to move in Note folder.
+					 */
+					entryid.push(moduleObject.entryids[selectedMessages[i]]);
+				} else if (selectedItemMessageClassParts[0] == "REPORT" && targetFolderContainerClassParts[1] == "Note") {
+					/**
+					 * If selected item's message class is of report type
+					 * REPORT.IPM.Note.NDR -> undelivered mail.
+					 * REPORT.IPM.Note.IPNNRN -> unread notification mail.
+					 * REPORT.IPM.Note.IPNRN -> read notification mail.
+					 * then allow it to move in Note folder.
+					 */
+					entryid.push(moduleObject.entryids[selectedMessages[i]]);
+				} else if (selectedItemMessageClassParts[1] == "DistList" && targetFolderContainerClassParts[1] == "Contact") {
+					/**
+					 * If selected item's message class is IPM.DistList 
+					 * then allow it to move in Contact folder.
+					 */
+					entryid.push(moduleObject.entryids[selectedMessages[i]]);
+				}
+			}
+		}
+	}
+	
+	if(folder != moduleObject.entryid && folderObject && entryid.length > 0) {
 		moduleObject.copyMessages(folderObject.storeid, folder, "move", true, entryid);
+	} else if(entryid.length == 0) {
+		/**
+		 * TODO: When there multiple messages of different classes are dragged/dropped
+		 * from deleted items, It just allows to transfer messages that are type of destination messages.
+		 * for other it is not showing any error messages.
+		 */
+		alert(_("Can not move selected items to destination folder."));
 	}
 }
 
@@ -1964,6 +2167,13 @@ function fieldChooserCallBack(result, module)
 	module.saveFieldSettings(properties);
 	module.columns = properties;	
 	module.list(true);
+	
+	//If the user has selected 'open inbox at startup',then to save column settings while login we 
+	//set inbox storid and entryid in  folders settings.
+	if(module.title == "Inbox"){
+		webclient.settings.set("folders/entryid_inbox/entryid",module.entryid);
+		webclient.settings.set("folders/entryid_inbox/storeid",module.storeid);
+	}
 }
 
 function eventInputFieldClick(moduleObject, element, event)
@@ -2015,12 +2225,13 @@ function eventClickSaveMessage (moduleObject, element, event)
 				break;
 			}
 		}
-		moduleObject.SubmitMessage(moduleObject, element);
-		
-		var form = dhtml.getElementById("insertmessage");
-		if (form) {
-			form.reset();
-			form.blur();
+		if (moduleObject.SubmitMessage(moduleObject, element)){
+			var form = dhtml.getElementById("insertmessage");
+
+			if (form) {
+				form.reset();
+				form.blur();
+			}
 		}
 	}
 	
@@ -2095,6 +2306,7 @@ function eventDeselectMessages(moduleObject, element, event)
 		}
 	}
 	moduleObject.prevselectedMessage = false;
+	event.stopPropagation();
 }
 
 //Function which creates importance menu
@@ -2145,7 +2357,25 @@ function eventClickChangeImportance(moduleObject, element, event)
 		moduleObject.messageID = element.parentNode.id;
 	}
 }
-	
+
+/**
+ * Fucntion stops propagating event for quicktime insert row which is text field in tasks folder.
+ * So selection in text field becomes possible
+ */
+function eventListInsertRowMouseMove(moduleObject, element, event)
+{
+	event.stopPropagation();
+}
+
+/**
+ * Fucntion stops propagating event for quicktime row in tasks folder in edit time mode.
+ * So selection in text field becomes possible
+ */
+function eventListRowMouseMove(moduleObject, element, event)
+{
+	if(this.editMessage !== false)
+		event.stopPropagation();
+}
 
 /**
 * Function which set the IMPORTANCE STATUS...
