@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 maillistmodule.prototype = new ListModule;
 maillistmodule.prototype.constructor = maillistmodule;
 maillistmodule.superclass = ListModule.prototype;
@@ -25,6 +72,9 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	//Add one more button to the main menu bar for performing the action of restore items
 	this.menuItems.push(webclient.menu.createMenuItem("restoreitem", _("Restore Items"), _("Restore deleted Items") , eventRestoreItems));
 
+	this.menuItems.push(webclient.menu.createMenuItem("seperator", ""));
+	this.menuItems.push(webclient.menu.createMenuItem("send_receive", _("Send/Receive"), _("Send or Receive mails") , eventSendReceiveItems));
+
 	webclient.menu.buildTopMenu(this.id, "createmail", this.menuItems, eventListNewMessage);
 	
 	var items = new Array();
@@ -43,13 +93,13 @@ maillistmodule.prototype.init = function(id, element, title, data)
 	items.push(webclient.menu.createMenuItem("flag_status_complete", _("Flag Complete"), false, eventMailListContextMenuFlagComplete));
 	items.push(webclient.menu.createMenuItem("flagno", _("Delete Flag"), false, eventMailListContextMenuDeleteFlag));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
-	if (webclient.hierarchy.getStore(this.storeid).defaultfolders["junk"]){
-		items.push(webclient.menu.createMenuItem("junk", _("Move to Junk Folder"), false, eventListContextMenuMoveJunkMessage));
-	}
+	items.push(webclient.menu.createMenuItem("junk", _("Move to Junk Folder"), false, eventListContextMenuMoveJunkMessage));
 	items.push(webclient.menu.createMenuItem("delete", _("Delete"), false, eventListContextMenuDeleteMessage));
 	//items.push(webclient.menu.createMenuItem("copy", _("Copy/Move Message"), false, eventListContextMenuCopyMessage));
 	items.push(webclient.menu.createMenuItem("seperator", ""));
 	items.push(webclient.menu.createMenuItem("options", _("Options")+"...", false, eventListContextMenuMessageOptions));
+
+	webclient.pluginManager.triggerHook('client.module.maillistmodule.contextmenu.buildup', {contextmenu: items});
 	this.contextmenu = items;
 	
 	this.layoutmenu = new Array();
@@ -69,8 +119,9 @@ maillistmodule.prototype.init = function(id, element, title, data)
 
 maillistmodule.prototype.execute = function(type, action)
 {
+	webclient.pluginManager.triggerHook('client.module.maillistmodule.execute.before', {type: type, action: action});
 	webclient.menu.showMenu();
-	
+		
 	switch(type)
 	{
 		case "list":
@@ -94,6 +145,34 @@ maillistmodule.prototype.execute = function(type, action)
 	}
 }
 
+maillistmodule.prototype.messageList = function(action)
+{
+    var title = dhtml.getXMLValue(action, "folder_title");
+	var entryid = dhtml.getXMLValue(action, "entryid");
+    var storeid = dhtml.getXMLValue(action, "storeid");
+    var isinbox = dhtml.getXMLValue(action, "isinbox");
+
+	if(title) {
+		// if title is already added, then change only folder name
+		titleBar = dhtml.getElementsByClassNameInElement(dhtml.getElementById("main"), "zarafa_title")[0];
+		if(titleBar) {
+			titleBar.firstChild.firstChild.nodeValue = title;
+		} else {
+			this.setTitle(title, false, true);
+		}
+    }
+
+    if(storeid && entryid) {
+        this.entryid = entryid;
+        this.storeid = storeid;
+        if(this.previewreadmailitemmodule)
+            this.previewreadmailitemmodule.setData(this.storeid, this.entryid);
+    }
+    this.isinbox = isinbox;
+
+    maillistmodule.superclass.messageList.call(this, action);
+}
+
 
 function eventLayoutSwitchPreviewpane(moduleObject, element, event){
 	element.parentNode.style.display = "none";
@@ -105,8 +184,11 @@ function eventLayoutSwitchPreviewpane(moduleObject, element, event){
 	}else if (dhtml.hasClassName(element, "icon_previewpane_bottom")){
 		previewMode = "bottom";
 	}
-	webclient.settings.set("folders/entryid_"+this.entryid+"/previewpane",previewMode);
 	
+	webclient.settings.set("folders/entryid_"+this.entryid+"/previewpane",previewMode);
+	if(this.isinbox)
+	    webclient.settings.set("folders/entryid_inbox/previewpane",previewMode);
+
 	webclient.hierarchy.selectLastFolder(true); // reload this folder
 }
 
@@ -121,8 +203,12 @@ maillistmodule.prototype.initializeView = function()
 
 	this.viewController.initView(this.id, "email", this.contentElement, this.events);
 	
+	// If the entryid is not set, then we're viewing the inbox
 	var previewMode = webclient.settings.get("global/previewpane","right"); // global default
-	previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
+	if(!this.entryid)
+    	previewMode = webclient.settings.get("folders/entryid_inbox/previewpane",previewMode);
+    else
+    	previewMode = webclient.settings.get("folders/entryid_"+this.entryid+"/previewpane",previewMode);
 	
 	if (previewMode == "right" || previewMode == "bottom"){
 		this.previewreadmailitemmodule = webclient.dispatcher.loadModule("previewreadmailitemmodule");
@@ -225,6 +311,28 @@ maillistmodule.prototype.disableSearchIndicator = function()
 	searchButton.className = "searchfilterbutton";
 }
 
+maillistmodule.prototype.loadFieldSettings = function()
+{
+	if(webclient.hasRightPane){
+		var path = "folders/entryid_"+this.entryid+"/fields";
+		data = webclient.settings.get(path);
+		var result = new Array();
+		for(var i in data){
+			switch(data[i]['id']){
+				case ("display_to"):
+				case ("sent_representing_name"):
+				case ("client_submit_time"):
+				case ("message_delivery_time"):
+					result.push(data[i]);
+					break;
+			}
+		}
+		return result;
+	}else {
+		 return maillistmodule.superclass.loadFieldSettings.call(this);
+	}
+}
+
 maillistmodule.prototype.updateSearch = function(action)
 {
 	var searchfolderentryid = dhtml.getXMLValue(action, "searchfolderentryid", false);
@@ -578,7 +686,7 @@ function eventMailListSearchBar(moduleObject, element, event)
 		moduleObject.topElement.style.display = "none";
 
 		// when there is a restriction active, remove it and reload maillist
-		if (moduleObject.filterRestriction != false){
+		if (typeof moduleObject.filterRestriction != "undefined" && moduleObject.filterRestriction != false){
 			eventMailListSearchBarClear(moduleObject, element, event);
 		}
 	}
@@ -672,3 +780,14 @@ function eventRestoreItems(moduleObject, element, event){
 		DIALOG_URL+"task=restoreitems_standard&storeid=" + this.storeid + "&parententryid=" + this.entryid,
 		700, 500, false);
 }
+
+/**
+ * function for sent the outbox mails and receive the new mail.
+ * @param object moduleObject Contains all the properties of a module object.
+ * @param dom_element element The dom element's reference on which the event gets fired.
+ * @param event event Event name
+ */
+function eventSendReceiveItems(moduleObject, element, event){
+	moduleObject.list();
+}
+
