@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 previewreadmailitemmodule.prototype= new ItemModule;
 previewreadmailitemmodule.prototype.constructor = previewreadmailitemmodule;
 previewreadmailitemmodule.superclass = ItemModule.prototype;
@@ -151,13 +198,13 @@ previewreadmailitemmodule.prototype.item = function(action)
 	if(!message) return false;
 	
 	this.initializeView();
+	// remember item properties
+	this.updateItemProps(message);
+	this.setConflictInfo(message);
 
 	if(message && message.childNodes) {
-		var subject = message.getElementsByTagName("subject")[0];
-		if(subject && subject.firstChild) {
-			var subjectElement = dhtml.getElementById("subject");
-			dhtml.addTextNode(subjectElement, subject.firstChild.nodeValue);
-		}
+
+		webclient.pluginManager.triggerHook("client.module.previewreadmailitemmodule.item.before", {message: message});
 
 		// Use functions from 'readmailitemmodule', to prevent double implementations.
 		// First check if the 'readmailitemmodule' exists.
@@ -169,7 +216,7 @@ previewreadmailitemmodule.prototype.item = function(action)
 
 			readmailitemmodule.prototype.setRecipients(message);
 			readmailitemmodule.prototype.setProperties(message);
-			readmailitemmodule.prototype.setAttachments(message);
+			readmailitemmodule.prototype.setAttachments.call(this, message);
 			readmailitemmodule.prototype.setBody(message);
 			readmailitemmodule.prototype.setFrom(message);
 			readmailitemmodule.prototype.setRepliedForwardedInfo(message);
