@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 readmailitemmodule.prototype = new ItemModule;
 readmailitemmodule.prototype.constructor = readmailitemmodule;
 readmailitemmodule.superclass = ItemModule.prototype;
@@ -19,6 +66,9 @@ readmailitemmodule.prototype.item = function(action)
 	var message = action.getElementsByTagName("item")[0];
 	
 	if(message && message.childNodes) {
+
+		webclient.pluginManager.triggerHook("client.module.readmailitemmodule.item.before", {message: message});
+
 		this.setRepliedForwardedInfo(message);
 
 		this.setImportanceSensitivityInfo(message);
@@ -123,53 +173,23 @@ readmailitemmodule.prototype.setAttachments = function(message)
 				var attach_num = attachment.getElementsByTagName("attach_num")[0];
 				var attach_method = attachment.getElementsByTagName("attach_method")[0];
 				var name = attachment.getElementsByTagName("name")[0];
-				var size = attachment.getElementsByTagName("size")[0];		
-				if(attach_num && attach_num.firstChild) {
+				var size = attachment.getElementsByTagName("size")[0];
+				var cid = attachment.getElementsByTagName("cid")[0];
+				var hidden = dhtml.getXMLValue(attachment, "hidden", false);
+
+				if(attach_num && attach_num.firstChild && !hidden) {
 					if(name && size && size.firstChild) {
 						var attachmentElement = dhtml.addElement(attachmentsElement, "a", "attachment");
-						
-						var attachNum = "";
-						if(this.attachNum && this.attachNum.push) {
-							for(var j = 0; j < this.attachNum.length; j++)
-							{
-								attachNum += "&attachNum[]=" + this.attachNum[j];
-							}
-						}
+						attachmentElement.setAttribute("attach_num", dhtml.getTextNode(attach_num, false));
+						attachmentElement.href = "#";
 
-						if(attach_method && attach_method.firstChild && attach_method.firstChild.nodeValue == "5") { // ATTACH_EMBEDDED_MSG
-							var attach_message_class = dhtml.getXMLValue(attachment, "attach_message_class", "IPM.Note");
-							attach_message_class = attach_message_class.replace(/\./g, "_").toLowerCase();
-					
-							switch(attach_message_class) {
-								case "ipm_note":
-								case "ipm_post":
-								case "report_ipm_note_ndr":
-								case "ipm_schedule_meeting_request":
-								case "ipm_schedule_meeting_resp_pos":
-								case "ipm_schedule_meeting_resp_tent":
-								case "ipm_schedule_meeting_resp_neg":
-								case "ipm_schedule_meeting_canceled":
-								case "report_ipm_note_ipnnrn":
-								case "report_ipm_note_ipnrn":
-									attach_message_class = "ipm_readmail";
-									break;
-							}
-							if(attach_message_class.indexOf("ipm_") >= 0) {
-								attach_message_class = attach_message_class.substring(attach_message_class.indexOf("_") + 1);
-							}
-						
-							attachmentElement.href = "javascript:var attachmentDialog = webclient.openWindow(false, '"+attach_message_class+"', '" + webclient.base_url + DIALOG_URL+"task="+attach_message_class+"_standard&storeid=" + this.storeid + "&rootentryid=" + this.rootentryid + "&entryid=" + this.messageentryid + attachNum + "&attachNum[]=" + attach_num.firstChild.nodeValue + "');";
-						} else {
-							attachmentElement.href = webclient.base_url + "index.php?load=download_attachment&store=" + this.storeid + "&entryid=" + this.rootentryid + attachNum + "&attachNum[]=" + attach_num.firstChild.nodeValue + "&openType=attachment";
-						}
-						
 						var kb = Math.round(size.firstChild.nodeValue / 1024) + _("kb");
 						if(size.firstChild.nodeValue < 1024) {
 							kb = size.firstChild.nodeValue + _("B");
 						}
-						
-						attachmentElement.innerHTML = dhtml.getTextNode(name, _("Untitled Attachment")) + " (" + kb + ");";
-						attachmentsElement.innerHTML += "&nbsp;";
+
+						attachmentElement.innerHTML = dhtml.getTextNode(name, _("Untitled Attachment")) + " (" + kb + ");"+ NBSP;
+						dhtml.addEvent(this, attachmentElement, "mousedown", eventAttachmentClick);
 					}
 				}
 			}
@@ -210,9 +230,21 @@ readmailitemmodule.prototype.setBody = function(message)
 			    content = convertAnchors(content);
 			}
 
+			var data = new Object();
+			data["content"] = content;
+			webclient.pluginManager.triggerHook("client.module.readmailitemmodule.setbody.predisplay", data);
+			// Magical whiteline fix. Somehow this whiteline makes the content 
+			// variable to not hold undefined as value after the next line
+			// "I'll take weird fixes for 500, Alex"
+			content = data["content"];
+
 			html_body.contentWindow.document.open();
 			html_body.contentWindow.document.write(content);
 			html_body.contentWindow.document.close();
+
+			var data = new Object();
+			data["iframedocument"] = html_body.contentWindow.document;
+			webclient.pluginManager.triggerHook("client.module.readmailitemmodule.setbody.postdisplay", data);
 		}
 	}
 }
@@ -371,14 +403,16 @@ readmailitemmodule.prototype.setRecipients = function(message)
 				sender += " <"+sender_email_address+">";
 			}
 			
-			var recipientItemSenderRepresentation = dhtml.addElement(fromElement,"span","emailaddress","sender_label",sender);
+			var recipientItemSenderRepresentation = dhtml.addElement(fromElement,"a","emailaddress","sender_label", sender);
+			recipientItemSenderRepresentation.href = "#";
 			dhtml.addEvent(this, recipientItemSenderRepresentation, "click", eventReadmailClickEmail);
 			dhtml.addEvent(this, recipientItemSenderRepresentation, "contextmenu", eventReadmailAddressContextMenu);
 
 			dhtml.addElement(fromElement,"span","emailaddress","", NBSP+_("on behalf of")+NBSP);
 		}
 
-		var recipientItemSenderRepresentation = dhtml.addElement(fromElement,"span","emailaddress","senderrepresentatation_label",sender_representation);
+		var recipientItemSenderRepresentation = dhtml.addElement(fromElement,"a","emailaddress","senderrepresentatation_label",sender_representation);
+		recipientItemSenderRepresentation.href = "#";
 		dhtml.addEvent(this, recipientItemSenderRepresentation, "click", eventReadmailClickEmail);
 		dhtml.addEvent(this, recipientItemSenderRepresentation, "contextmenu", eventReadmailAddressContextMenu);
 	}
@@ -414,7 +448,8 @@ readmailitemmodule.prototype.setRecipients = function(message)
 					if(recipientString.length > 0 && name != email_address) {
 						recipientString += " <"+email_address+">";
 					}
-					var recipientItem = dhtml.addElement(element,"span","emailaddress",type+"_label"+i,recipientString);
+					var recipientItem = dhtml.addElement(element,"a","emailaddress",type+"_label"+i,recipientString);
+					recipientItem.href = "#";
 					dhtml.addEvent(this, recipientItem, "click", eventReadmailClickEmail);
 					dhtml.addEvent(this, recipientItem, "contextmenu", eventReadmailAddressContextMenu);
 				}
