@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * --Calendar Day View--
  * @type	View
@@ -195,6 +242,15 @@ CalendarDayView.prototype.setDayHeaders = function()
 		var date = new Date(this.days[i]);
 		var dayOfWeek = date.getDay();
 		days[i].innerHTML = DAYS_SHORT[dayOfWeek] + " " + date.getDate() + " " + MONTHS_SHORT[date.getMonth()];
+		// select today in view.
+		var todayCount = (new Date().getDay()== 0) ? 7 : new Date().getDay();
+		if((todayCount-1 == i  && date.isSameDay(new Date())) || (this.data["days"]==1 && date.isSameDay(new Date()))){
+			dhtml.addClassName(days[i], "selectedToday");
+			dhtml.addClassName(this.daysElement.childNodes[i+1], "selectedToday");
+		}else {
+			dhtml.removeClassName(days[i], "selectedToday");
+			dhtml.removeClassName(this.daysElement.childNodes[i+1], "selectedToday");
+		}
 	}
 
 	// Set the range header ('1 january - 7 janary')
@@ -484,30 +540,10 @@ CalendarDayView.prototype.createItem = function(daysElement, appointment, item,
 	}
 	var className = "ipm_appointment appointment";
 
+	// Label is also used further on in the code
 	var label = dhtml.getTextNode(item.getElementsByTagName("label")[0]);
 	className += this.convertLabelNrToString(label);
 	
-	var busystatus = item.getElementsByTagName("busystatus")[0];
-	if(busystatus && busystatus.firstChild) {
-		switch(busystatus.firstChild.nodeValue)
-		{
-			case "0":
-				className += " free";
-				break;
-			case "1":
-				className += " tentative";
-				break;
-			case "3":
-				className += " outofoffice";
-				break;
-			default:
-				className += " busy";
-				break;
-		}
-	} else {
-		className += " busy";
-	}
-	
 	appointment.className = className;
 	if (!appointment.is_disabled){
 		dragdrop.addDraggable(appointment, "appointment", true, APPOINTMENT_RESIZABLE);
@@ -584,6 +620,13 @@ CalendarDayView.prototype.createItem = function(daysElement, appointment, item,
 		var duetime = duedate.getAttribute("unixtime");
 		if (duetime==starttime) duetime = (starttime*1)+60; // make duetime +1 minute when equals to starttime
 		
+		// Normalize reversed start/end
+		if(starttime > duetime) {
+			var tmp = starttime;
+			starttime = duetime;
+			duetime = tmp;
+		}
+
 		var start_date = new Date(starttime * 1000);
 		var due_date = new Date(duetime * 1000);
 		
@@ -619,6 +662,77 @@ CalendarDayView.prototype.createItem = function(daysElement, appointment, item,
 		
 		// This attribute is used for saving. 
 		appointment.setAttribute("starttime", startDateId);
+
+		var busyStatus;
+		var bstext = dhtml.getTextNode(item.getElementsByTagName("busystatus")[0]);
+		switch(bstext)
+		{
+			case "0":
+				busyStatus += " free";
+				break;
+			case "1":
+				busyStatus += " tentative";
+				break;
+			case "3":
+				busyStatus += " outofoffice";
+				break;
+			default:
+				busyStatus += " busy";
+				break;
+		}
+
+		// Next we are going to set up the duration bar that will indicate how long the appointment will run.
+		var durationBar = dhtml.addElement(appointment, "div", "durationbar "+busyStatus, false);
+
+		var barStartDate = new Date(start_date.getTime());
+		var barDueDate = new Date(due_date.getTime());
+
+		var barStartDateMinutes = barStartDate.getMinutes();
+		var barDueDateMinutes = barDueDate.getMinutes();
+
+		// Set the date to either 0 min or 30 min, this is because the appointment block snaps to 
+		// halfhour slots and we want the start date of that block.
+		barStartDate.setMinutes( barStartDateMinutes - (barStartDateMinutes % 30) );
+		if(barDueDateMinutes > 30){
+			barDueDate.setMinutes(60);
+		}else if(barDueDateMinutes > 0){
+			barDueDate.setMinutes(30);
+		}else{
+			barDueDate.setMinutes(0);
+		}
+
+		// The blockTimeDiff is the number of seconds that the block covers (not the appointment)
+		var blockTimeDiff = barDueDate.getTime() - barStartDate.getTime();
+		// The offsetDate is the number of seconds after the start of the block.
+		var offsetAppointmentStartDate = start_date.getTime() - barStartDate.getTime();
+		var offsetAppointmentDueDate = due_date.getTime() - barStartDate.getTime();
+		// The deltaAppointmentStart and Due will be used to convert the seconds into pixels
+		var deltaAppointmentStart = offsetAppointmentStartDate / blockTimeDiff;
+		var deltaAppointmentDue = offsetAppointmentDueDate / blockTimeDiff;
+
+		// For some reason I have to recalculate the height of the block here
+		var blockHeight = parseInt(endDateElem.offsetTop, 10) - parseInt(startDateElem.offsetTop, 10);
+		// Calculating the number of pixels where the duration bar needs to start and end
+		// The height value is calculated earlier on in this function
+		var durationBarStart = Math.round(blockHeight * deltaAppointmentStart);
+		var durationBarEnd = Math.round(blockHeight * deltaAppointmentDue); // Using "End" now instead of "Due"
+
+		/** 
+		 * If the appointment ends at xx:59 we should make it look like it ends on the next whole 
+		 * hour. Multiday appointments split up in two parts ranging from xx:xx till 23:59 and 0:00 
+		 * till yy:yy. This way the duration block will stretch to the end.
+		 */
+		if(due_date.getMinutes() == 59){
+			durationBarEnd = blockHeight;
+		}
+
+		// If the durationBar becomes too small, force the bar to show at least one pixel
+		if(durationBarEnd - durationBarStart < 2){
+			durationBar.style.height = "1px";
+		}
+
+		durationBar.style.top = durationBarStart + "px";
+		durationBar.style.bottom = (blockHeight - durationBarEnd) + "px";
 	}
 	
 	appointment.type = "normal";
@@ -667,6 +781,7 @@ CalendarDayView.prototype.createAllDayItem = function(appointElement, item)
 	var duration = dhtml.getTextNode(item.getElementsByTagName("duration")[0]);
 	var label = dhtml.getTextNode(item.getElementsByTagName("label")[0]);
 	var alldayevent = dhtml.getTextNode(item.getElementsByTagName("alldayevent")[0]);
+	var busystatus = dhtml.getTextNode(item.getElementsByTagName("busystatus")[0]);
 	var location = dhtml.getTextNode(item.getElementsByTagName("location")[0],"");
 	if(location){
 		location = " ("+location+")";
@@ -700,17 +815,34 @@ CalendarDayView.prototype.createAllDayItem = function(appointElement, item)
 	appointElement.setAttribute("end",endUnixtime);
 	appointElement.setAttribute("alldayevent",alldayevent);
 	//style
-	appointElement.className = "";
-	dhtml.addClassName(appointElement,"ipm_appointment allday_appointment");
-	dhtml.addClassName(appointElement,this.convertLabelNrToString(label));
-		
+	var className = "ipm_appointment allday_appointment";
+	switch(busystatus){
+		case "0":
+			className += " free";
+			break;
+		case "1":
+			className += " tentative";
+			break;
+		case "3":
+			className += " outofoffice";
+			break;
+		default:
+			className += " busy";
+			break;
+	}
+	dhtml.addClassName(appointElement, className);
+	dhtml.addClassName(appointElement, this.convertLabelNrToString(label));
 
 	//addevents
-	if (this.events && this.events["row"]){
-		dhtml.setEvents(this.moduleID, appointElement, this.events["row"]);
+	appointElement.is_disabled = dhtml.getTextNode(item.getElementsByTagName("disabled_item")[0],0) != 0;		// for private items, no events may be added to this item 
+	if(!appointElement.is_disabled) {
+		if (this.events && this.events["row"]){ 
+			dhtml.setEvents(this.moduleID, appointElement, this.events["row"]); 
+		}
+		dhtml.addEvent(this.moduleID, appointElement, "click", eventCalendarDayViewOnClick);
+		dhtml.addEvent(this.moduleID, appointElement, "keyup", eventCalendarDayViewKeyboard);
 	}
-	dhtml.addEvent(this.moduleID, appointElement, "click", eventCalendarDayViewOnClick);
-	
+
 	appointElement.type = "allday";
 }
 
@@ -1081,7 +1213,8 @@ function eventCalendarDayViewDblClick(moduleObject, element, event){
 	// Get time/day of new appointment
 	var offsetDay = element.offsetDay;
 	var offsetTime = element.offsetTime;
-	var starttime = moduleObject.viewController.viewObject.days[offsetDay]/1000 + (offsetTime * 60);
+
+	var starttime = addUnixTimestampToUnixTimeStamp(moduleObject.viewController.viewObject.days[offsetDay] / 1000, offsetTime * 60);
 
 	var uri = DIALOG_URL+"task=appointment_standard&storeid=" + moduleObject.storeid + "&parententryid=" + moduleObject.entryid + "&date=" + starttime;
 	webclient.openWindow(moduleObject, "appointment", uri);
@@ -1117,8 +1250,9 @@ function eventCalendarDayViewAddAppointment(moduleObject, element, event)
 
 	// when quickElem still exists, exit this function, nothing to do here
 	if (!moduleObject.quickElem){
-		moduleObject.quickElem = dhtml.addElement(element, "input", null, "quickappointment");
+		moduleObject.quickElem = dhtml.addElement(null, "input", null, "quickappointment");
 		moduleObject.quickElem.setAttribute("type", "text");
+		element.appendChild(moduleObject.quickElem);
 		moduleObject.quickElem.offsetDay =  element.offsetDay;
 		moduleObject.quickElem.offsetTime = element.offsetTime;
 		dhtml.addEvent(moduleObject, moduleObject.quickElem, "keypress", eventQuickAppointmentKey);
@@ -1157,11 +1291,16 @@ function eventQuickAppointmentKey(moduleObject, element, event)
 					// Get time/day of new appointment
 					var offsetDay = moduleObject.quickElem.offsetDay;
 					var offsetTime = moduleObject.quickElem.offsetTime;
-					
-					var starttime = moduleObject.viewController.viewObject.days[offsetDay]/1000 + (offsetTime * 60);
-					var endtime = starttime + (30*60);
-					
-					moduleObject.createAppointment(starttime, endtime, subject);
+
+					var starttime = addUnixTimestampToUnixTimeStamp(moduleObject.viewController.viewObject.days[offsetDay] / 1000, offsetTime * 60);
+					var endtime = addUnixTimestampToUnixTimeStamp(starttime, HALF_HOUR / 1000);
+
+					var reminderTime = null; 
+					if(webclient.settings.get("calendar/reminder","true") == "true"){
+						reminderTime = webclient.settings.get("calendar/reminder_minutes", 15); 
+					}
+
+					moduleObject.createAppointment(starttime, endtime, subject, null, null, null, reminderTime);
 				}
 				dhtml.deleteElement(moduleObject.quickElem);
 				moduleObject.quickElem = null;
@@ -1201,9 +1340,11 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	var startTimeOffset = getTimeOffsetByPixelOffset(firstTargetElement, topOffset);
 	var endTimeOffset = getTimeOffsetByPixelOffset(firstTargetElement, bottomOffset);
 
-	starttime = new Date(dayStart + (startTimeOffset * 60 * 1000));
-	endtime = new Date(dayStart + (endTimeOffset * 60 * 1000));
-	
+	var starttime = new Date(dayStart);
+	starttime.addUnixTimeStampToDate(startTimeOffset * 60);
+	var endtime = new Date(dayStart);
+	endtime.addUnixTimeStampToDate(endTimeOffset * 60);
+
 	var props = new Object();
 	props["store"] = moduleObject.storeid;
 	props["parent_entryid"] = moduleObject.entryid;
@@ -1214,57 +1355,62 @@ function eventAppointmentListDragDropTarget(moduleObject, targetElement, element
 	props["commonstart"] = props["startdate"];
 	props["commonend"] = props["duedate"];
 	props["duration"] = (props["duedate"]-props["startdate"])/60;
-	
+	props["remindertime"] = parseInt(props["startdate"]);
+
 	var basedate = (element.getAttribute("basedate") == "undefined" || !element.getAttribute("basedate")?false:element.getAttribute("basedate"));
 	if(basedate) {
 		props["basedate"] = basedate;
 	}
-	
+
+	var occurrenceBaseDate = element.id.substring(element.id.indexOf("_")+1);
 	var send = false;
+	var moveOccAllowFlag = true;
 	if (element.meetingrequest && parseInt(element.meetingrequest) == 1) { // 1 = olResponseOrganized
 		if( endtime.getTime()>(new Date().getTime())) {
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 		}
+	}else if(basedate){
+		moveOccAllowFlag = confirmAppointMoved(moduleObject, element.offsetDay, targetElement.offsetDay);
+	}
+	if(moveOccAllowFlag){
+		moduleObject.save(props, send);
+		moduleObject.viewController.updateItem(element);
 	}
-
-	moduleObject.save(props, send);
-
-	moduleObject.viewController.updateItem(element);
 }
 
 function eventDayViewClickPrev(moduleObject, element, event)
 {
 	var datepickerlistmodule = webclient.getModulesByName("datepickerlistmodule")[0];
 	var numberOfDays = (moduleObject.duedate-moduleObject.startdate)/ONE_DAY;
-	var timestamp;
+	var startdate;
+
 	if(numberOfDays == 1){
-		timestamp = new Date(moduleObject.startdate-ONE_DAY);
+		startdate = new Date(moduleObject.startdate);
+		startdate.addDays(-1);
 	} else {
-		timestamp = new Date(moduleObject.startdate-(ONE_DAY*7));
+		startdate = new Date(moduleObject.startdate);
+		startdate.addDays(-7);
 	}
-	datepickerlistmodule.changeMonth(timestamp.getMonth() + 1, timestamp.getFullYear(), true);
-	datepickerlistmodule.changeSelectedDate(timestamp.getTime(),true);
+	datepickerlistmodule.changeMonth(startdate.getMonth() + 1, startdate.getFullYear(), true);
+	datepickerlistmodule.changeSelectedDate(startdate.getTime(),true);
 }
 
 function eventDayViewClickNext(moduleObject, element, event)
 {
 	var datepickerlistmodule = webclient.getModulesByName("datepickerlistmodule")[0];
 	var numberOfDays = (moduleObject.duedate-moduleObject.startdate)/ONE_DAY;
-	var timestamp;
+	var startdate;
 	
-	// Skip to the next day or week. The time we skip is either a day or a week, plus
-	// an hour, to make sure that DST changes will not matter.... ie in october, next week
-	// is 7 days and 1 hour ago, and in april, it's 6 days and 23 hours. Becuase we round down
-	// to the whole day, just adding 1 hour is enough, unless your DST offset is > 1 hour. But 
-	// this never happens I think.
 	if(numberOfDays == 1){
-		timestamp = new Date(moduleObject.startdate+ONE_DAY+ONE_HOUR);
+		startdate = new Date(moduleObject.startdate);
+		startdate.addDays(1);
 	} else {
-		timestamp = new Date(moduleObject.startdate+(ONE_DAY*7)+ONE_HOUR);
+		startdate = new Date(moduleObject.startdate);
+		startdate.addDays(7);
 	}
 	
-	datepickerlistmodule.changeMonth(timestamp.getMonth() + 1, timestamp.getFullYear(), true);
-	datepickerlistmodule.changeSelectedDate(timestamp.getTime(),true);
+	datepickerlistmodule.changeMonth(startdate.getMonth() + 1, startdate.getFullYear(), true);
+	datepickerlistmodule.changeSelectedDate(startdate.getTime(),true);
 }
 
 function eventCalendarDayViewOnClick(moduleObject, element, event)
