@@ -1,6 +1,52 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * --Calendar Month View--
- * @author	Frans van Veen <f.vanveen@zarafa.com>
  * @type View
  * @classDescription	This view can be used for appointement
  * list module to display the calendar items
@@ -283,31 +329,33 @@ CalendarMonthView.prototype.createItem = function(item,element)
 	var startDate = new Date(unixTimeStart*1000);
 	var dueDate = new Date(unixTimeDue*1000);
 	var subject = dhtml.getTextNode(item.getElementsByTagName("subject")[0], NBSP);
+	var duration = dhtml.getTextNode(item.getElementsByTagName("duration")[0], 0);
 	var parent_entryid = item.getElementsByTagName("parent_entryid")[0].firstChild.nodeValue;
-	var alldayevent = dhtml.getTextNode(item.getElementsByTagName("alldayevent")[0], 0);
 	var entryid = item.getElementsByTagName("entryid")[0].firstChild.nodeValue;
-	var startTime = new Date(startDate);
+	var today = new Date(startDate);
+	var endday = new Date(dueDate);
 	var privateAppointment = dhtml.getTextNode(item.getElementsByTagName("private")[0], 0);
 	var privateSensitivity = dhtml.getTextNode(item.getElementsByTagName("sensitivity")[0], 0);
 	
 	var AppointmentElement;
 	
-	startTime.setHours(0);
-	startTime.setMinutes(0);
-	startTime.setSeconds(0);
+	var today = new Date(startDate);
+	var endday = new Date(dueDate);
+	today.setHours(0);
+	today.setMinutes(0);
+	today.setSeconds(0);
+	today.setMilliseconds(0);
+	endday.setHours(0);
+	endday.setMinutes(0);
+	endday.setSeconds(0);
+	endday.setMilliseconds(0);
+	
+	// Treat the item as an 'allday' event if it starts on a different day than it ends
+	var alldayevent = today.getTime() != endday.getTime();
 
-	// Check how many days this event takes TODO: check DST
-	var numberOfItems = Math.ceil((dueDate-startDate)/ONE_DAY);
-	var timeDiff = dueDate.strftime(_("%H%M%S")) - startDate.strftime(_("%H%M%S"));
-	if(timeDiff <= 0 && alldayevent != "1") {
-		numberOfItems++;
-	}
-
-	if(numberOfItems < 1)
-	    numberOfItems = 1;
-	for(var i=0;i<numberOfItems;i++){
+	while(today < dueDate){
 		var unixTimeId = startDate.getTime()/1000;
-		var selDay = dhtml.getElementById(parent_entryid+"_"+(startTime.getTime()/1000));
+		var selDay = dhtml.getElementById(parent_entryid+"_"+(today.getTime()/1000));
 	
 		if(selDay){
 			if(element){
@@ -320,15 +368,16 @@ CalendarMonthView.prototype.createItem = function(item,element)
 			AppointmentElement.setAttribute("startdate",unixTimeId);
 			AppointmentElement.setAttribute("duedate",unixTimeDue);
 	
-			if(alldayevent ==  "1"){
+			if(alldayevent){
 				// allday event
 				AppointmentElement.className = "event_item ipm_appointment event_day_item";			
 				AppointmentElement.setAttribute("title",subject);
-			} else{
+			} else{				
 				// normal event
-				AppointmentElement.className = "event_item ipm_appointment";			
-				AppointmentElement.setAttribute("title","["+startDate.toTime()+" - "+dueDate.toTime()+"] "+subject);
-				dhtml.addElement(AppointmentElement,"span","event_time","",startDate.toTime()+NBSP);
+				AppointmentElement.className = "event_item ipm_appointment";
+				//strftime func calculates starttime and endtime and support both 24/12Hrs Time format according to language settings
+				AppointmentElement.setAttribute("title","["+strftime(_('%H:%M'),unixTimeId)+" - "+strftime(_('%H:%M'),unixTimeDue)+"] "+subject);
+				dhtml.addElement(AppointmentElement,"span","event_time","",strftime(_('%H:%M'),unixTimeId)+NBSP);
 			}	
 			
 			// private item
@@ -399,7 +448,7 @@ CalendarMonthView.prototype.createItem = function(item,element)
 		}
 		
 		// add one_day for more day event
-		startTime.addDays(1);
+		today.addDays(1);
 	}
 
 	return entry;
@@ -487,15 +536,22 @@ function eventCalenderMonthViewDragDropTarget(moduleObject, targetElement, eleme
 
 	if(draggableBasedate){
 		props["basedate"] = draggableBasedate;
+		var drag = true;
 	}
 	props["duration"] = duration/60; 
 
 	var send = false;
+	var moveOccAllowFlag = true;
 	if (element.meetingrequest && element.meetingrequest==1) // 1 = olResponseOrganized
 		if( newDraggableDuedate>(new Date().getTime()/1000))
 			send = confirm(_("Would you like to send an update to the attendees regarding changes to this meeting?"));
 
-	moduleObject.save(props, send);
+	if(draggableBasedate){
+		moveOccAllowFlag = confirmAppointMoved(moduleObject, draggableBasedate, targetElement.getAttribute("unixtime"));
+	}
+	if(moveOccAllowFlag){
+		moduleObject.save(props, send);
+	}
 
 	// moduleObject.viewController.updateItem(element);//not necessary
 }
