@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 /**
  * --Table View--
  * @type	View
@@ -332,7 +379,7 @@ TableView.prototype.addInsertColumns = function(columns, sortColumn, sortDirecti
 	if(tableElement) {
 		var columnRow = tableElement.rows[0];
 		if(columnRow) {
-			for(var i = 0; i < columnRow.cells.length - 1; i++)
+			for(var i = 0; i < columnRow.cells.length - 1 && i < columns.length; i++)
 			{
 				if (this.events["insertcolumn"][columns[i]["name"]])
 				dhtml.setEvents(this.moduleID, columnRow.cells[i], this.events["insertcolumn"][columns[i]["name"]]);
@@ -582,6 +629,19 @@ TableView.prototype.addRows = function(rows)
 					if(property && property.firstChild) {
 						value = property.firstChild.nodeValue;
 					}
+					// Hide attachment icon if message has only inline attachments
+					if (column["id"] == "hasattach"){
+						var hideattachments = row.getElementsByTagName("hideattachments")[0];
+						if (hideattachments && hideattachments.firstChild) {
+							hideattachments = hideattachments.firstChild.nodeValue;
+							
+							if (value) {
+								if (hideattachments){
+									value = 0;
+								}
+							}
+						}
+					}
 					this.renderRowColumn(table, column["id"], column["type"], column["length"], value, row,i);
 				}
 				
@@ -601,7 +661,7 @@ TableView.prototype.addRows = function(rows)
 	var tableElement = this.divElement.getElementsByTagName("table")[0];
 	
 	// Resize table width. Only in IE.
-	if(window.BROWSER_IE) {
+	if(window.BROWSER_IE && !window.BROWSER_IE8) {
 		tableElement.style.width = this.divElement.clientWidth + "px";
 	}
 	
@@ -642,6 +702,7 @@ TableView.prototype.renderColumn = function(table, name, title, type, length)
 		case "hasattach":
 		case "icon_index":
 		case "flag_status":
+		case "flag_icon":
 		case "importance":
 		case "complete":
 			className += " message_icon icon_" + type;
@@ -854,9 +915,10 @@ TableView.prototype.getRowColumnSettings = function(fieldname, type, length, val
 			break;
 		case "flag":
 		case "flag_status":
+		case "flag_icon":
 			className += " message_icon ";
 			
-			className += this.getFlagClass(parseInt(value, 10), parseInt(dhtml.getXMLValue(item, "flag_icon")));
+			className += this.getFlagClass(parseInt(dhtml.getXMLValue(item, "flag_status")), parseInt(dhtml.getXMLValue(item, "flag_icon")));
 			break;
 
 		case "importance":
@@ -1189,37 +1251,51 @@ TableView.prototype.getElemIdByRowNumber = function(rownum)
 TableView.prototype.getFlagClass = function(flagStatus, flagIcon)
 {
 	var className = "";
-	
-	switch(flagStatus)
+
+	switch(flagIcon)
 	{
 		case 1:
-			className = "icon_flag_complete";
+			className = "icon_flag_purple";
 			break;
 		case 2:
-			switch(flagIcon)
+			className = "icon_flag_orange";
+			break;
+		case 3:
+			className = "icon_flag_green";
+			break;
+		case 4:
+			className = "icon_flag_yellow";
+			break;
+		case 5:
+			className = "icon_flag_blue";
+			break;
+		case 6:
+			className = "icon_flag_red";
+			break;
+		case 0:
+			switch(flagStatus)
 			{
 				case 1:
-					className = "icon_flag_purple";
-					break;
-				case 2:
-					className = "icon_flag_orange";
-					break;
-				case 3:
-					className = "icon_flag_green";
-					break;
-				case 4:
-					className = "icon_flag_yellow";
-					break;
-				case 5:
-					className = "icon_flag_blue";
+					className = "icon_flag_complete";
 					break;
 				default:
-					className = "icon_flag_red";
+					className = "icon_flag_none";
 					break;
 			}
 			break;
 		default:
-			className += "icon_flag";
+			switch(flagStatus)
+			{
+				case 1:
+					className = "icon_flag_complete";
+					break;
+				case 2:
+					className = "icon_flag_none";
+					break;
+				default:
+					className = "icon_flag";
+					break;
+			}
 			break;
 	}
 	
@@ -1233,17 +1309,17 @@ TableView.prototype.setCursorPosition = function(id)
 
 	if (element){
 		this.cursorElementL.style.top = (element.offsetTop) + "px";	
-		this.cursorElementL.style.height = (element.offsetHeight - 3) + "px";
+		if(element.offsetHeight != 0) this.cursorElementL.style.height = (element.offsetHeight - 3) + "px";
 		this.cursorElementL.style.visibility = "visible";	
 		this.cursorElementT.style.top = (element.offsetTop) + "px";	
-		this.cursorElementT.style.width = (element.offsetWidth - 2) + "px";
+		if(element.offsetWidth != 0) this.cursorElementT.style.width = (element.offsetWidth - 2) + "px";
 		this.cursorElementT.style.visibility = "visible";	
 		this.cursorElementR.style.top = (element.offsetTop) + "px";	
-		this.cursorElementR.style.left = (element.offsetWidth - 2) + "px";
-		this.cursorElementR.style.height = (element.offsetHeight - 3) + "px";
+		if(element.offsetWidth != 0) this.cursorElementR.style.left = (element.offsetWidth - 2) + "px";
+		if(element.offsetHeight != 0) this.cursorElementR.style.height = (element.offsetHeight - 3) + "px";
 		this.cursorElementR.style.visibility = "visible";	
 		this.cursorElementB.style.top = (element.offsetTop + element.offsetHeight - 2) + "px";
-		this.cursorElementB.style.width = (element.offsetWidth - 2 ) + "px";
+		if(element.offsetWidth != 0) this.cursorElementB.style.width = (element.offsetWidth - 2 ) + "px";
 		this.cursorElementB.style.visibility = "visible";	
 
 		this.cursorMessage = id;
@@ -1416,7 +1492,7 @@ function setcal(inputfield,showbutton) {
 function eventTableViewMouseDown(moduleObject, element, event)
 {		
 	// first check that any message is in edit form...
-	if (moduleObject && moduleObject.editMessage && moduleObject.stopbubble == false){
+	if (moduleObject && moduleObject.editMessage !== false && moduleObject.stopbubble == false){
 		// here we have to pass element id of message which is in edit mode
 		// not the current element
 		moduleObject.SubmitMessage(moduleObject, dhtml.getElementById(moduleObject.editMessage), event);
