@@ -1,3 +1,50 @@
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
 DragDrop.prototype = new Widget;
 DragDrop.prototype.constructor = DragDrop;
 DragDrop.superclass = Widget.prototype;
@@ -77,6 +124,10 @@ DragDrop.prototype.addDraggable = function(element, group, isFixed, resizable, m
 		dhtml.addEvent(moduleObj, element, "mousemove", eventDragDropMouseMoveFixedDraggable);
 		element.setAttribute("resizable", resizable?"true":"false");
 	}
+
+	if(moduleId){
+		element.setAttribute("moduleID", moduleId);
+	}
 }
 
 DragDrop.prototype.deleteGroup = function(group)
@@ -340,6 +391,8 @@ function eventDragDropMouseDownDraggable(moduleObject, element, event)
 		dragdrop.dragPointY = 0;
 	}
 
+	dragdrop.draggable.moduleID = moduleObject.id;
+
 	return false;
 }
 
@@ -390,8 +443,20 @@ function eventDragDropMouseUpDraggable(moduleObject, element, event)
 				target["element"].className = target["element"].className.substring(0, target["element"].className.indexOf("dragover"));
 			}
 			
-			if(targetGroup["moduleID"] && targetGroup["callbackfunction"] && !target["notallowed"]) {
-				targetGroup.callbackfunction(webclient.getModule(targetGroup["moduleID"]), target["element"], draggableElem, event);
+			if(!target["notallowed"]){
+				var draggableCallback = false;
+				if(draggableElem.moduleID){
+					var draggableModule = webclient.getModule(draggableElem.moduleID);
+
+					if(typeof draggableModule.getDragDropTargetCallback == "function"){
+						draggableCallback = draggableModule.getDragDropTargetCallback();
+					}
+				}
+				if(typeof draggableCallback == "function"){
+					draggableCallback(webclient.getModule(draggableElem.moduleID), target["element"], draggableElem, event);
+				}else if(targetGroup["moduleID"] && targetGroup["callbackfunction"]) {
+					targetGroup.callbackfunction(webclient.getModule(targetGroup["moduleID"]), target["element"], draggableElem, event);
+				}
 			}
 		}
 		
