@@ -1,3 +1,52 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	* Server-wide properties class
@@ -122,6 +171,7 @@
 			$properties["basedate"] = "PT_SYSTIME:PSETID_Appointment:0x8228";
 			$properties["timezone_data"] = "PT_BINARY:PSETID_Appointment:0x8233";
 			$properties["commonassign"] = "PT_LONG:PSETID_Common:0x8518";
+			$properties["remindertime"] = "PT_SYSTIME:PSETID_Common:0x8502";
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 			
@@ -196,6 +246,7 @@
 			$properties["mailing_address"] = "PT_LONG:PSETID_Address:0x8022";
 			$properties["im"] = "PT_STRING8:PSETID_Address:0x8062";
 			$properties["webpage"] = "PT_STRING8:PSETID_Address:0x802b";
+			$properties["business_home_page"] = PR_BUSINESS_HOME_PAGE;
 			$properties["email_address_entryid_1"] = "PT_BINARY:PSETID_Address:0x8085";
 			$properties["email_address_entryid_2"] = "PT_BINARY:PSETID_Address:0x8095";
 			$properties["email_address_entryid_3"] = "PT_BINARY:PSETID_Address:0x80a5";
@@ -211,6 +262,64 @@
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 			$properties["deleted_on"] = PR_DELETED_ON;
 
+			// Detailed contacts properties
+			// Properties for phone numbers
+			$properties["assistant_telephone_number"] = PR_ASSISTANT_TELEPHONE_NUMBER;
+			$properties["business2_telephone_number"] = PR_BUSINESS2_TELEPHONE_NUMBER;
+			$properties["callback_telephone_number"] = PR_CALLBACK_TELEPHONE_NUMBER;
+			$properties["car_telephone_number"] = PR_CAR_TELEPHONE_NUMBER;
+			$properties["company_telephone_number"] = PR_COMPANY_MAIN_PHONE_NUMBER;
+			$properties["home2_telephone_number"] = PR_HOME2_TELEPHONE_NUMBER;
+			$properties["home_fax_number"] = PR_HOME_FAX_NUMBER;
+			$properties["isdn_number"] = PR_ISDN_NUMBER;
+			$properties["other_telephone_number"] = PR_OTHER_TELEPHONE_NUMBER;
+			$properties["pager_telephone_number"] = PR_PAGER_TELEPHONE_NUMBER;
+			$properties["primary_fax_number"] = PR_PRIMARY_FAX_NUMBER;
+			$properties["primary_telephone_number"] = PR_PRIMARY_TELEPHONE_NUMBER;
+			$properties["radio_telephone_number"] = PR_RADIO_TELEPHONE_NUMBER;
+			$properties["telex_telephone_number"] = PR_TELEX_NUMBER;
+			$properties["ttytdd_telephone_number"] = PR_TTYTDD_PHONE_NUMBER;
+			// Additional fax properties
+			$properties["fax_1_address_type"] = "PT_STRING8:PSETID_Address:0x80B2";
+			$properties["fax_1_email_address"] = "PT_STRING8:PSETID_Address:0x80B3";
+			$properties["fax_1_original_display_name"] = "PT_STRING8:PSETID_Address:0x80B4";
+			$properties["fax_1_original_entryid"] = "PT_BINARY:PSETID_Address:0x80B5";
+			$properties["fax_2_address_type"] = "PT_STRING8:PSETID_Address:0x80C2";
+			$properties["fax_2_email_address"] = "PT_STRING8:PSETID_Address:0x80C3";
+			$properties["fax_2_original_display_name"] = "PT_STRING8:PSETID_Address:0x80C4";
+			$properties["fax_2_original_entryid"] = "PT_BINARY:PSETID_Address:0x80C5";
+			$properties["fax_3_address_type"] = "PT_STRING8:PSETID_Address:0x80D2";
+			$properties["fax_3_email_address"] = "PT_STRING8:PSETID_Address:0x80D3";
+			$properties["fax_3_original_display_name"] = "PT_STRING8:PSETID_Address:0x80D4";
+			$properties["fax_3_original_entryid"] = "PT_BINARY:PSETID_Address:0x80D5";
+
+			// Properties for addresses
+			// Home address
+			$properties["home_address_street"] = PR_HOME_ADDRESS_STREET;
+			$properties["home_address_city"] = PR_HOME_ADDRESS_CITY;
+			$properties["home_address_state"] = PR_HOME_ADDRESS_STATE_OR_PROVINCE;
+			$properties["home_address_postal_code"] = PR_HOME_ADDRESS_POSTAL_CODE;
+			$properties["home_address_country"] = PR_HOME_ADDRESS_COUNTRY;
+			// Other address
+			$properties["other_address_street"] = PR_OTHER_ADDRESS_STREET;
+			$properties["other_address_city"] = PR_OTHER_ADDRESS_CITY;
+			$properties["other_address_state"] = PR_OTHER_ADDRESS_STATE_OR_PROVINCE;
+			$properties["other_address_postal_code"] = PR_OTHER_ADDRESS_POSTAL_CODE;
+			$properties["other_address_country"] = PR_OTHER_ADDRESS_COUNTRY;
+			// Business address
+			$properties["business_address_street"] = "PT_STRING8:PSETID_Address:0x8045";
+			$properties["business_address_city"] = "PT_STRING8:PSETID_Address:0x8046";
+			$properties["business_address_state"] = "PT_STRING8:PSETID_Address:0x8047";
+			$properties["business_address_postal_code"] = "PT_STRING8:PSETID_Address:0x8048";
+			$properties["business_address_country"] = "PT_STRING8:PSETID_Address:0x8049";
+			// Mailing address
+			$properties["country"] = PR_COUNTRY;
+			$properties["city"] = PR_LOCALITY;
+			$properties["postal_address"] = PR_POSTAL_ADDRESS;
+			$properties["postal_code"] = PR_POSTAL_CODE;
+			$properties["state"] = PR_STATE_OR_PROVINCE;
+			$properties["street"] = PR_STREET_ADDRESS;
+
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 
@@ -229,6 +338,7 @@
 			$properties["message_class"] = PR_MESSAGE_CLASS;
 			$properties["message_flags"] = PR_MESSAGE_FLAGS;
 			$properties["display_name"] = PR_DISPLAY_NAME;
+			$properties["smtp_address"] = PR_SMTP_ADDRESS;
 			$properties["fileas"] = "PT_STRING8:PSETID_Address:0x8005";
 			$properties["email_address_1"] = "PT_STRING8:PSETID_Address:0x8083";
 			$properties["email_address_display_name_1"] = "PT_STRING8:PSETID_Address:0x8080";
@@ -302,6 +412,7 @@
 
 			$properties = array();
 			$properties["entryid"] = PR_ENTRYID;
+			$properties["store_entryid"] = PR_STORE_ENTRYID;
 			$properties["parent_entryid"] = PR_PARENT_ENTRYID;
 			$properties["message_class"] = PR_MESSAGE_CLASS;
 			$properties["icon_index"] = PR_ICON_INDEX;
@@ -358,7 +469,7 @@
 
 			$properties["deleted_on"] = PR_DELETED_ON;
 			$properties["updatecounter"] = "PT_LONG:PSETID_Appointment:0x8201";
-			
+			$properties["hideattachments"] = "PT_BOOLEAN:PSETID_Common:0x8514";
 
 			return getPropIdsFromStrings($this->store, $properties);
 		}
@@ -433,11 +544,23 @@
 			$properties["commonstart"] = "PT_SYSTIME:PSETID_Common:0x8516";
 			$properties["commonend"] = "PT_SYSTIME:PSETID_Common:0x8517";
 			$properties["commonassign"] = "PT_LONG:PSETID_Common:0x8518";
+			$properties["flagdueby"] = "PT_SYSTIME:PSETID_Common:0x8560";
 			// Conflict properties
 			$properties["conflictitems"] = PR_CONFLICT_ITEMS;
 
 			$properties["deleted_on"] = PR_DELETED_ON;
 			
+			$properties["sent_representing_entryid"] = PR_SENT_REPRESENTING_ENTRYID;
+			$properties["sent_representing_name"] = PR_SENT_REPRESENTING_NAME;
+			$properties["sent_representing_addrtype"] = PR_SENT_REPRESENTING_ADDRTYPE;
+			$properties["sent_representing_email_address"] = PR_SENT_REPRESENTING_EMAIL_ADDRESS;
+			$properties["sent_representing_search_key"] = PR_SENT_REPRESENTING_SEARCH_KEY;
+			$properties["sender_email_address"] = PR_SENDER_EMAIL_ADDRESS;
+			$properties["sender_name"] = PR_SENDER_NAME;
+			$properties["sender_addrtype"] = PR_SENDER_ADDRTYPE;
+			$properties["sender_entryid"] = PR_SENDER_ENTRYID;
+			$properties["sender_search_key"] = PR_SENDER_SEARCH_KEY;
+			
 			return getPropIdsFromStrings($this->store, $properties);
 		}
 
