@@ -1,7 +1,55 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Addressbook Module
-	 * @author Michael Erkens <m.erkens@connectux.com> 
 	 */
 	class AddressbookListModule extends ListModule
 	{	
@@ -76,6 +124,8 @@
 		function messageList($store, $entryid, $action)
 		{
 			$result = false;
+			$searchPerformed = false;				// flag to check the request is for search or not
+			$disableFullContactlist = false;		// flag for disabling the contact list
 
 			if(!$entryid) {
 				$rootcontainer = mapi_msgstore_openentry($store);
@@ -122,6 +172,7 @@
 				}
 
 				if(isset($action["restriction"])) {
+					$searchPerformed = true;
 					if(isset($action["restriction"]["name"])) {
 						$restrictions = array();
 						$props = array($this->properties["fileas"], 
@@ -177,67 +228,116 @@
 				
 				$this->parseSortOrder($action, $map, true);
 
-
 				$data = array();
 				$data["attributes"] = array("type" => "list");
 				$data["column"] = $this->tablecolumns;
 				$data["sort"] = $this->generateSortOrder($map);
-				
-				// Get all rows
-				$table = $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, 0, 0x7fffffff, $restriction);
 
-				// Search for distribution lists and get all email adresses in the distribution lists.
-				$items = array();
-				foreach($table["item"] as $position => $item)
-				{
-					if (is_array($item["entryid"])){
-						$item["entryid"] = $item["entryid"]["_content"];
-					}
+				// open contacts folder
+				$folder = mapi_msgstore_openentry($store, $entryid);
+				if(mapi_last_hresult() == NOERROR) {
+					$contentsTable = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
 
-					$item["message_flags"] = MSGFLAG_READ; // in the addressbook we don't use message flags, but we want to show them as "read"
-					if(isset($item["message_class"])) {
-						switch($item["message_class"])
-						{
-							case "IPM.Contact":
-								if(isset($item["address_book_mv"]) && is_array($item["address_book_mv"])){
-									$email_addresses = $item["address_book_mv"];
-									$entryid = $item["entryid"];
+					// apply restriction & sorting
+					mapi_table_restrict($contentsTable, $restriction, TBL_BATCH);
+					mapi_table_sort($contentsTable, $this->sort, TBL_BATCH);
 
-									foreach($email_addresses as $email_address)
-									{
-										$email_address += 1; // address_book_mv starts with 0, so we add '1' here
-
-										if(isset($item["email_address_" . $email_address])) {
-											$item["entryid"] = $entryid . "_" . $email_address;
-											$item["email_address"] = $item["email_address_" . $email_address];
-											$item["display_name"] = $item["email_address_display_name_" . $email_address];
-											$item["addrtype"] = $item["email_address_type_" . $email_address];
-											$item["email_address_number"] = $email_address;
-											array_push($items, $item);
-										}
-									}
-								}
-								break;
-							case "IPM.DistList":
-								$entryid = hex2bin($item["entryid"]); // need real entryid here
-								$item["email_address"] = $item["display_name"];
-								$item["members"] = array("member"=>$this->expandDistributionList($store, $entryid));
-
-								array_push($items, $item);
-								break;
+					/**
+					 * Check whether we have to disable the full contactlist listing using the config: 
+					 * DISABLE_FULL_CONTACTLIST_THRESHOLD. we are checking here if in case 
+					 * mapi_table_getrowcount returns number greater then this config value then we
+					 * don't have to do any processing, so it will lessen processing time
+					 */
+					if(defined('DISABLE_FULL_CONTACTLIST_THRESHOLD') && DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed) {
+						if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && mapi_table_getrowcount($contentsTable) > DISABLE_FULL_CONTACTLIST_THRESHOLD) {
+							$disableFullContactlist = true;
 						}
 					}
-				}
-				
-				$table["item"] = $items;
-				$data = array_merge($data, $table);
-				
-				array_push($this->responseData["action"], $data);
-				$GLOBALS["bus"]->addData($this->responseData);
 
-				$result = true;
+					if(!$disableFullContactlist) {
+						// Get all rows
+						/**
+						 * we can also use mapi_table_queryallrows but it internally calls queryrows with 
+						 * start as 0 and end as 0x7fffffff, so we are directly calling mapi_table_queryrows
+						 */
+						$rows = mapi_table_queryrows($contentsTable, $this->properties, 0, 0x7fffffff);
+
+						// Search for distribution lists and get all email adresses in the distribution lists.
+						$items = array();
+						foreach($rows as $row)
+						{
+							$item = Conversion::mapMAPI2XML($this->properties, $row);
+
+							if (is_array($item["entryid"])){
+								$item["entryid"] = $item["entryid"]["_content"];
+							}
+
+							$item["message_flags"] = MSGFLAG_READ; // in the addressbook we don't use message flags, but we want to show them as "read"
+							if(isset($item["message_class"])) {
+								switch($item["message_class"])
+								{
+									case "IPM.Contact":
+										if(isset($item["address_book_mv"]) && is_array($item["address_book_mv"])){
+											$email_addresses = $item["address_book_mv"];
+											$entryid = $item["entryid"];
+
+											foreach($email_addresses as $email_address)
+											{
+												$email_address += 1; // address_book_mv starts with 0, so we add '1' here
+
+												if(isset($item["email_address_" . $email_address])) {
+													$item["entryid"] = $entryid . "_" . $email_address;
+													$item["email_address"] = $item["email_address_" . $email_address];
+													$item["display_name"] = $item["email_address_display_name_" . $email_address];
+													$item["addrtype"] = $item["email_address_type_" . $email_address];
+													$item["email_address_number"] = $email_address;
+													array_push($items, $item);
+												}
+											}
+										}
+										break;
+									case "IPM.DistList":
+										$entryid = hex2bin($item["entryid"]); // need real entryid here
+										$item["email_address"] = $item["display_name"];
+										$item["members"] = array("member"=>$this->expandDistributionList($store, $entryid));
+
+										array_push($items, $item);
+										break;
+								}
+							}
+						}
+
+						/**
+						 * Check whether we have to disable the full contactlist listing using the config: 
+						 * DISABLE_FULL_CONTACTLIST_THRESHOLD. We check this after we have looped through all the
+						 * items (code above) becuase it could happen then after expanding the groups the number
+						 * of rows crosses the limit. This is because we need to know how many rows the contactlist
+						 * will contain. Also note that when the user conducts a search the list should be displayed 
+						 * regardless of the number of items returned.
+						 */
+						if(defined('DISABLE_FULL_CONTACTLIST_THRESHOLD') && DISABLE_FULL_CONTACTLIST_THRESHOLD != -1 && !$searchPerformed){
+							if(DISABLE_FULL_CONTACTLIST_THRESHOLD >= 0 && count($items) > DISABLE_FULL_CONTACTLIST_THRESHOLD){
+								$disableFullContactlist = true;
+							}
+						}
+					}
+
+					if(!$disableFullContactlist){
+						$data = array_merge($data, array("item" => $items));
+					}else{
+						// Provide clue that full contactlist is disabled.
+						$disable_clist_treshold = array();
+						$disable_clist_treshold["value"] = true;
+						$data = array_merge($data, array("disable_full_gab"=>$disable_clist_treshold));
+					}
+
+					array_push($this->responseData["action"], $data);
+					$GLOBALS["bus"]->addData($this->responseData);
+
+					$result = true;
+				}
 			}
-			
+
 			return $result;
 		}
 		
@@ -283,7 +383,6 @@
 
 			$map = array();
 			$map["fileas"] = PR_ACCOUNT;
-			$map["email_address"] = PR_SMTP_ADDRESS;
 			
 			// Parse incoming sort order
 			$this->parseSortOrder($action, $map, true);
@@ -359,7 +458,7 @@
 
 				$data["page"]["start"] = 0;
 				$data["page"]["rowcount"] = mapi_table_getrowcount($table);
-				$data["page"]["totalrowcount"] = mapi_table_getrowcount($table);
+				$data["page"]["totalrowcount"] = $data["page"]["rowcount"];
 				
 				// Only add restriction when it is used
 				mapi_table_restrict($table, ($restriction)?$restriction:Array());
