@@ -1,3 +1,52 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	include_once('mapi/class.recurrence.php');
 	
@@ -5,7 +54,6 @@
 	 * Appointment ItemModule
 	 * Module which openes, creates, saves and deletes an item. It 
 	 * extends the Module class.
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	 */
 	class AppointmentItemModule extends ItemModule
 	{
@@ -41,6 +89,10 @@
 					// First add all the properties from the series-message and than overwrite them with the ones form the exception
 					$data["item"] = $GLOBALS["operations"]->getMessageProps($store, $message, $this->properties, true);
             	    $exceptionProps = $GLOBALS["operations"]->getMessageProps($store, $exception, $this->properties, true);
+
+					// HACK: when occurrence is dragged in OL, recipients are not set in occurrence
+					if (isset($exceptionProps['recipients']) && count($exceptionProps['recipients']['recipient']) == 0)
+						unset($exceptionProps['recipients']);
 					// HACK: When body is empty use the body of the series-message
 					if(strlen($exceptionProps['body']) == 0){
 						unset($exceptionProps['body'], $exceptionProps['isHTML']);
@@ -49,6 +101,9 @@
                 
             	    // The entryid should be the entryid of the main message, not that of the attachment
             	    $data["item"]["entryid"] = bin2hex($entryid);
+                    
+                    // Make sure we are using the passed basedate and not something wrong in the opened item
+                    $data["item"]["basedate"] = $basedate;
                      
             	    array_push($this->responseData["action"], $data);
 					$GLOBALS["bus"]->addData($this->responseData);
