@@ -1,7 +1,55 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Appointment Module
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	*/
 	
 	require_once("mapi/class.recurrence.php");
@@ -126,76 +174,16 @@
 														 )
 												   )
 											 ),
-									   // OR
-									   Array(RES_OR,
-											 Array(
-												   // OR
-												   // (EXIST(recurrence_enddate_property) && item[isRecurring] == true && (item[end] < item[start] || item[end] >= start))
-												   Array(RES_AND,
-														 Array(
-															   Array(RES_EXIST,
-																	 Array(ULPROPTAG => $this->properties["enddate_recurring"],
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_EQ,
-																		   ULPROPTAG => $this->properties["recurring"],
-																		   VALUE => true
-																		   )
-																	 ),
-															   Array(RES_OR,
-															   		// This is a hack. If we can see that the enddate_recurring is BEFORE the startdate, 
-															   		// then the enddate_recurring is bogus and we should ignore it!
-															   		Array(
-																		Array(RES_COMPAREPROPS,
-																			Array(RELOP => RELOP_LT,
-																				ULPROPTAG1 => $this->properties["enddate_recurring"],
-																				ULPROPTAG2 => $this->properties["startdate"]
-																			)
-																		),
-																	
-																		
-																	   Array(RES_PROPERTY,
-																			 Array(RELOP => RELOP_GE,
-																				   ULPROPTAG => $this->properties["enddate_recurring"],
-																				   VALUE => $start
-																				   )
-																			 )
-																		)
-																	)
-															   )
-														 ),
-												   // OR
-												   // (!EXIST(recurrence_enddate_property) && item[isRecurring] == true && item[start] <= end)
-
-												   Array(RES_AND,
-														 Array(
-															   Array(RES_NOT,
-																	 Array(
-																		   Array(RES_EXIST,
-																				 Array(ULPROPTAG => $this->properties["enddate_recurring"]
-																					   )
-																				 )
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_LE,
-																		   ULPROPTAG => $this->properties["startdate"],
-																		   VALUE => $end
-																		   )
-																	 ),
-															   Array(RES_PROPERTY,
-																	 Array(RELOP => RELOP_EQ,
-																		   ULPROPTAG => $this->properties["recurring"],
-																		   VALUE => true
-																		   )
-																	 )
-															   )
-														 )
-												   )
-											 ) // EXISTS OR
-									   )
-								 );		// global OR
+										//OR
+										//(item[isRecurring] == true)
+										Array(RES_PROPERTY,
+											Array(RELOP => RELOP_EQ,
+												ULPROPTAG => $this->properties["recurring"],
+												VALUE => true
+													)
+											)		
+									)
+							);// global OR
 
 			$folder = mapi_msgstore_openentry($store, $entryid);
 			$table = mapi_folder_getcontentstable($folder);
@@ -312,17 +300,30 @@
 		function save($store, $parententryid, $action)
 		{
 			$result = false;
-			
+
 			// Save the properties
 			$messageProps = $GLOBALS["operations"]->saveAppointment($store, $parententryid, $action);
-					
-			if($messageProps) {
-				// Send notifications that this object has changed					
+			
+			/**
+			 * If there is an error in exception then send the failed action to the client
+			 * and send the error message with it.
+			 */
+			if(isset($messageProps["isexceptionallowed"])) {
+				$data = array();
+				$data["attributes"] = array("type" => "failed");
+				
+				if($messageProps["isexceptionallowed"] === "false"){
+					$data["action_type"] = "moveoccurence";
+					$data["error_message"] = _("Unable to reschedule occurrence: Either the new occurrence skips over an existing occurrence, or an occurrence is already present on this day");
+				}
+ 				array_push($this->responseData["action"],$data);
+ 				$GLOBALS["bus"]->addData($this->responseData);
+ 			}
+			// Send notifications that this object has changed					
+			if($messageProps){
 				$GLOBALS["bus"]->notify($this->entryid, TABLE_SAVE, $messageProps);
-
 				$result = true;
 			}
-			
 			return $result;
 		}
 		
