@@ -1,9 +1,57 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Create Mail ItemModule
 	 * Module which openes, creates, saves and deletes an item. It 
 	 * extends the Module class.
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	 */
 	class CreateMailItemModule extends ItemModule
 	{
@@ -78,6 +126,29 @@
 				$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
 			}
 			
+			// Get inline information.
+			$add_inline_attachments = array();
+			$delete_inline_attachments = array();
+			if (isset($action["inline_attachments"]) && isset($action["inline_attachments"]["images"]) && is_array($action["inline_attachments"]["images"])) {
+				// Inline images which are to be added.
+				if(is_array($action["inline_attachments"]["images"]["add"])){
+					if (!isset($action["inline_attachments"]["images"]["add"][0])){
+						$add_inline_attachments = array($action["inline_attachments"]["images"]["add"]);
+					}else{
+						$add_inline_attachments = $action["inline_attachments"]["images"]["add"];
+					}
+				}
+
+				// Inline images which are to be deleted.
+				if(is_array($action["inline_attachments"]["images"]["delete"])){
+					if (!isset($action["inline_attachments"]["images"]["delete"][0])){
+						$delete_inline_attachments = array($action["inline_attachments"]["images"]["delete"]);
+					}else{
+						$delete_inline_attachments = $action["inline_attachments"]["images"]["delete"];
+					}
+				}
+			}
+						
 			if($store) {
 				if(isset($action["props"]) && isset($action["recipients"])){
 					/**
@@ -96,12 +167,25 @@
 					
 					$copyAttachments = false;
 					$copyAttachmentsStore = false;
-					if(isset($action["message_action"]) && isset($action["message_action"]["action_type"]) && $action["message_action"]["action_type"] == "forward") {
-						// we need to copy the original attachments when it is an forwarded message
+					$copy_only_inline_attachments = false;
+					$replyOrigMessageDetails = false;
+					if(isset($action["message_action"]) && isset($action["message_action"]["action_type"])) {
+						/** we need to copy the original attachments when it is an forwarded message
+						 *  OR
+						 *  we need to copy ONLY original inline(HIDDEN) attachments when it is reply/replyall message
+						 */
 						$copyAttachments = hex2bin($action["message_action"]["entryid"]);
 						$copyAttachmentsStore = hex2bin($action["message_action"]["storeid"]);
 						// Open store (this => $GLOBALS['mapisession'])
 						$copyAttachmentsStore = $GLOBALS['mapisession']->openMessageStore($copyAttachmentsStore);
+							
+						if ($action["message_action"]["action_type"] == "reply" || $action["message_action"]["action_type"] == "replyall") {
+							$copy_only_inline_attachments = true;
+							$replyOrigMessageDetails = array(
+								"entryid"=>$action["message_action"]["entryid"],
+								"storeid"=>$action["message_action"]["storeid"]
+							);
+						}
 					}
 
 
@@ -114,8 +198,6 @@
 						 * for which current user is sending mail on behalf of, so
 						 * get delegator's store.
 						 */
-						$addrbook = mapi_openaddressbook($session);
-
 						if (!empty($prop[PR_SENT_REPRESENTING_NAME]) && !empty($prop[PR_SENT_REPRESENTING_EMAIL_ADDRESS])) {
 							$addrbook = mapi_openaddressbook($session);
 							// resolve users based on email address
@@ -126,12 +208,16 @@
 							 *
 							 * EMS_AB_ADDRESS_LOOKUP is used to specify strict matching
 							 */
-							$user = array( array( PR_DISPLAY_NAME => $prop[PR_SENT_REPRESENTING_EMAIL_ADDRESS] ) );
+							$user = array( array( PR_DISPLAY_NAME => u2w($prop[PR_SENT_REPRESENTING_EMAIL_ADDRESS]) ) );
 							$user = mapi_ab_resolvename($addrbook, $user, EMS_AB_ADDRESS_LOOKUP);
 							if(mapi_last_hresult() == NOERROR) {
 								$user2_entryid = mapi_msgstore_createentryid($store, $user[0][PR_EMAIL_ADDRESS]);
 								$store = mapi_openmsgstore($session, $user2_entryid);
 							}
+						} else if(!$action["props"]["from"]) {
+							// if from address is not specified and we are sending mail from
+							// delegate's mailbox then don't send mail on behalf of
+							$store = false;
 						}
 
 						if(!$store) {
@@ -139,7 +225,7 @@
 						}
 
 						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
-						$result = $GLOBALS["operations"]->submitMessage($store, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore);
+						$result = $GLOBALS["operations"]->submitMessage($store, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore, $add_inline_attachments, $delete_inline_attachments, $copy_only_inline_attachments, $replyOrigMessageDetails);
 						
 						// If draft is send from the drafts folder, delete notification
 						if($result) {
@@ -159,7 +245,7 @@
 						if ($action["props"]["entryid"]==""){
 							$action["props"]["entryid"] = $state->read("createmail".$action["dialog_attachments"]);
 						}
-						$result = $GLOBALS["operations"]->saveMessage($GLOBALS["mapisession"]->getDefaultMessageStore(), $parententryid, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore);
+						$result = $GLOBALS["operations"]->saveMessage($GLOBALS["mapisession"]->getDefaultMessageStore(), $parententryid, Conversion::mapXML2MAPI($this->properties, $action["props"]), $action["recipients"]["recipient"], $action["dialog_attachments"], $messageProps, $copyAttachments, $copyAttachmentsStore, array(), $add_inline_attachments, $delete_inline_attachments, $copy_only_inline_attachments);
 						$state->write("createmail".$action["dialog_attachments"], bin2hex($messageProps[PR_ENTRYID]));
 
 						// Update the client with the (new) entryid and parententryid to allow the draft message to be removed when submitting.						
@@ -184,7 +270,7 @@
 						$hasattachProp = mapi_getprops($savedMsg, array(PR_HASATTACH));
 						if (isset($hasattachProp[PR_HASATTACH])&& $hasattachProp[PR_HASATTACH]){
 							$attachmentTable = mapi_message_getattachmenttable($savedMsg);
-							$attachments = mapi_table_queryallrows($attachmentTable, array(PR_ATTACH_NUM, PR_ATTACH_SIZE, PR_ATTACH_LONG_FILENAME, PR_ATTACH_FILENAME, PR_ATTACHMENT_HIDDEN, PR_DISPLAY_NAME, PR_ATTACH_METHOD));
+							$attachments = mapi_table_queryallrows($attachmentTable, array(PR_ATTACH_NUM, PR_ATTACH_SIZE, PR_ATTACH_LONG_FILENAME, PR_ATTACH_FILENAME, PR_ATTACHMENT_HIDDEN, PR_DISPLAY_NAME, PR_ATTACH_METHOD, PR_ATTACH_CONTENT_ID, PR_ATTACH_MIME_TAG));
 							$attachment_props["attachments"] = array();
 							$attachment_props["attachments"]["attachment"] = array();
 
@@ -195,6 +281,8 @@
 									$attachment["attach_num"] = $attachmentRow[PR_ATTACH_NUM];
 									$attachment["attach_method"] = $attachmentRow[PR_ATTACH_METHOD];
 									$attachment["size"] = $attachmentRow[PR_ATTACH_SIZE];
+									$attachment["cid"] = $attachmentRow[PR_ATTACH_CONTENT_ID];
+									$attachment["filetype"] = $attachmentRow[PR_ATTACH_MIME_TAG];
 
 									if(isset($attachmentRow[PR_ATTACH_LONG_FILENAME]))
 										$attachment["name"] = $attachmentRow[PR_ATTACH_LONG_FILENAME];
