@@ -1,7 +1,55 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Hierarchy Module
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	 *
 	 * @todo
 	 * - Check the code at deleteFolder and at copyFolder. Looks the same.
@@ -34,20 +82,24 @@
 		
 		/**
 		 * Function which returns a list of entryids, which is used to register this module. It
-		 * returns the root contaciner entryids of every message store.
+		 * returns the ipm_subtree entryids of every message store.
 		 * @return array list of entryids
 		 */
 		function getEntryID()
 		{
 			$entryid = array();
-			
 			$storelist = $GLOBALS["mapisession"]->getAllMessageStores();
 			
 			foreach($storelist as $store)
 			{
-				$rootcontainer = mapi_msgstore_openentry($store);
-				$props = mapi_getprops($rootcontainer, array(PR_ENTRYID));
-				array_push($entryid, bin2hex($props[PR_ENTRYID]));
+				$store_props = mapi_getprops($store, array(PR_IPM_SUBTREE_ENTRYID));
+				/**
+				 * register notification events to IPM_SUBTREE folder of every store
+				 * because we are not doing anything above folder IPM_SUBTREE
+				 */
+				$ipm_subtree = mapi_msgstore_openentry($store, $store_props[PR_IPM_SUBTREE_ENTRYID]);
+				$ipm_subtree_props = mapi_getprops($ipm_subtree, array(PR_ENTRYID));
+				array_push($entryid, bin2hex($ipm_subtree_props[PR_ENTRYID]));
 			}
 			
 			return $entryid;
@@ -135,9 +187,9 @@
 							$store = $GLOBALS["mapisession"]->addUserStore($action["username"], $action["foldertype"]);
 							if ($store){
 								$data = $GLOBALS["operations"]->getHierarchyList($this->columns, HIERARCHY_GET_ONE, $store);
-								if(!mapi_is_error(mapi_last_hresult())){
+								if(!mapi_is_error(mapi_last_hresult()) && (is_array($data["store"]) && count($data["store"]) > 0)) {
 									array_push($this->responseData["action"], $data);
-									$GLOBALS["bus"]->addData($this->responseData);								
+									$GLOBALS["bus"]->addData($this->responseData);	
 									$result = true;
 								} else {
 									// access denied
@@ -219,7 +271,20 @@
 			$folder = mapi_msgstore_openentry($store, $entryid);
 			if($folder)
 				$result = mapi_favorite_add($GLOBALS["mapisession"]->getSession(), $folder, $favoritename, intval($flags));
-				
+
+			/**
+			 * folders of public store can only be added in favorites folder
+			 * so $store passed here will be always public store
+			 */
+			// open public store and find favorites folder entryid
+			$storeProps = mapi_getprops($store, array(PR_IPM_FAVORITES_ENTRYID));
+			$favoritesFolder = mapi_msgstore_openentry($store, $storeProps[PR_IPM_FAVORITES_ENTRYID]);
+
+			$favoritesFolderProps = mapi_getprops($favoritesFolder, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
+
+			// notify favorites folder that folder has been added
+			$GLOBALS["bus"]->notify(bin2hex($favoritesFolderProps[PR_ENTRYID]), OBJECT_SAVE, $favoritesFolderProps);
+
 			return $result;
 		}
 		
@@ -273,11 +338,19 @@
 				$props[PR_PARENT_ENTRYID] = $parententryid;
 				
 				if($result) {
-					$storeprops = mapi_getprops($store, array(PR_ENTRYID));
+					$storeprops = mapi_getprops($store, array(PR_ENTRYID, PR_IPM_FAVORITES_ENTRYID));
 					$props[PR_STORE_ENTRYID] = $storeprops[PR_ENTRYID];
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_SAVE, $props);
 					
 					$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_DELETE, $props);
+
+					// Notifying corresponding folder in 'Favorites'
+					if (isset($storeprops[PR_IPM_FAVORITES_ENTRYID])){
+						$folderEntryID = "00000001". substr(bin2hex($entryid), 8);
+						$props[PR_ENTRYID] = hex2bin($folderEntryID);
+						$props[PR_PARENT_ENTRYID] = $storeprops[PR_IPM_FAVORITES_ENTRYID];
+						$GLOBALS["bus"]->notify(bin2hex($parententryid), OBJECT_DELETE, $props);
+					}
 				}
 			}
 			
