@@ -1,9 +1,57 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * ItemModule
 	 * Module which openes, creates, saves and deletes an item. It 
 	 * extends the Module class.
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	 */
 	class ItemModule extends Module
 	{
@@ -55,13 +103,14 @@
 						case "declineMeetingRequest":
 						case "acceptMeetingRequest":
 							$message = $GLOBALS["operations"]->openMessage($store, $entryid);
+							$basedate = (isset($action['basedate']) ? $action['basedate'] : false);
+							$delete = false;
 							/**
 							 * Get message class from original message. This can be changed to 
 							 * IPM.Appointment if the item is a Meeting Request in the maillist. 
 							 * After Accepting/Declining the message is moved and changed.
 							 */
 							$originalMessageProps = mapi_getprops($message, array(PR_MESSAGE_CLASS));
-
 							$req = new Meetingrequest($store, $message, $GLOBALS["mapisession"]->getSession());
 
 							if($action["attributes"]["type"] == 'acceptMeetingRequest') {      				
@@ -70,9 +119,19 @@
 								$newProposedEndTime = isset($action["proposed_endtime"]) ? $action["proposed_endtime"] : false;
 								$body = isset($action["body"]) ? $action["body"] : false;
 
-								$req->doAccept($tentative, true, true, $newProposedStartTime, $newProposedEndTime, $body, true, $store);
+								// sendResponse flag if it is set then send the mail response to the organzer.
+								$sendResponse = true;
+								if(isset($action["noResponse"]) && $action["noResponse"] == "true") {
+									$sendResponse = false;
+								}
+
+								// When accepting occurrence by opening occurrence itself , we dont move occurrence.
+								$move = (stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false) ? true : false;
+								
+								// get the new entry id 
+								$newEntryid = $req->doAccept($tentative, $sendResponse, $move, $newProposedStartTime, $newProposedEndTime, $body, true, $store, $basedate);
 							} else {
-								$req->doDecline(true, $store);
+								$delete = $req->doDecline(true, $store, $basedate);
 							}
 
 
@@ -87,18 +146,21 @@
 							 * check the PR_MESSAGE_CLASS and see if it is "IPM.Meeting*".
 							 */
 							$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID, PR_MESSAGE_CLASS));
-							if(stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false || $action["attributes"]["type"] == "declineMeetingRequest"){
+							if(stristr($originalMessageProps[PR_MESSAGE_CLASS], 'IPM.Schedule.Meeting') !== false || $delete){
 								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_DELETE, $messageProps); // send TABLE_DELETE event because the message has moved
 							}
+
+							if ($action["attributes"]["type"] == "declineMeetingRequest" && !$delete)
+								$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps); // send TABLE_SAVE event because an occurrence is deleted
 							break;
 						case "cancelInvitation":
-							$GLOBALS["operations"]->cancelInvitation($store, $entryid);
+							$GLOBALS["operations"]->cancelInvitation($store, $entryid, $action);
 							
 							break;
-                        case "removeFromCalendar":
-                            $GLOBALS["operations"]->removeFromCalendar($store, $entryid);
-                            break;
-                            
+						case "removeFromCalendar":
+							$GLOBALS["operations"]->removeFromCalendar($store, $entryid);
+							break;
+
 						case "resolveConflict":
 							$result = $this->resolveConflict($store, $parententryid, $entryid, $action);
 							break;
@@ -224,40 +286,22 @@
 					if($req->isLocalOrganiser()) {
 						// We received a meeting request response, and we're the organiser
 						$req->processMeetingRequestResponse();
+						mapi_savechanges($message);
 					}
 				} else if($req->isMeetingRequest()) {
 					if(!$req->isLocalOrganiser()) {
-						
-						//Check for meeting request if out of date.
-						$meetingrequest_messageprops = mapi_getprops($req->message, array($req->proptags['goid'], PR_OWNER_APPT_ID));
-						$meetingrequest_goid = $meetingrequest_messageprops[$req->proptags['goid']];
-						$meetingrequest_apptid = $meetingrequest_messageprops[PR_OWNER_APPT_ID];
-						
-						$message_entryids = $req->findCalendarItems($meetingrequest_goid, $meetingrequest_apptid);
-						
-						foreach ($message_entryids as $item_entryid) {
-							$calendaritem_message = $GLOBALS["operations"]->openmessage($store, $item_entryid);
-							$calendaritem_messageprops = mapi_getprops($calendaritem_message, array($this->properties['updatecounter']));
-	
-							if (isset($data["item"]["updatecounter"]) && isset($calendaritem_messageprops[$this->properties['updatecounter']])) {
-								if ($data["item"]["updatecounter"] < $calendaritem_messageprops[$this->properties['updatecounter']]) {
-									$data["item"]["out_of_date"] = true;
-								}
-							}
-						}
-						
-						
-						/**
-						 * put item in calendar if this is latest update,
-						 * i.e if meeting request is not out of date.
-						 */
-						if(!isset($data["item"]["out_of_date"]) || !$data["item"]["out_of_date"]) {
-							// Put the item in the calendar 'tentatively'
+						if ($req->isMeetingOutOfDate()) {
+							$data["item"]["out_of_date"] = true;
+							$messageProps = mapi_getprops($message, array(PR_ENTRYID, PR_PARENT_ENTRYID, PR_STORE_ENTRYID));
+							$GLOBALS["bus"]->notify(bin2hex($messageProps[PR_PARENT_ENTRYID]), TABLE_SAVE, $messageProps);
+						} else {
+							/**
+							 * put item in calendar 'tentatively' if this is latest update,
+							 * i.e if meeting request is not out of date.
+							 */
 							$req->doAccept(true, false, false);
-
 							// Publish updated free/busy information
 							$GLOBALS["operations"]->publishFreeBusy($store);
-
 						}
 
 						// We received a meeting request, show it to the user
@@ -311,11 +355,14 @@
 						$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
 						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
 					}
+				}else if(!$parententryid){
+					if(isset($action["props"]["message_class"]))
+						$parententryid = $this->getDefaultFolderEntryID($store, $action["props"]["message_class"]);
 				}
 
 				if($store && $parententryid) {
 					$messageProps = array(); // returned props
-					$result = $GLOBALS["operations"]->saveMessage($store, $parententryid, Conversion::mapXML2MAPI($this->properties, $action["props"]), array(), (isset($action["dialog_attachments"])?$action["dialog_attachments"]:null), $messageProps);
+					$result = $GLOBALS["operations"]->saveMessage($store, $parententryid, Conversion::mapXML2MAPI($this->properties, $action["props"]), false, (isset($action["dialog_attachments"])?$action["dialog_attachments"]:null), $messageProps);
 					
 					if($result) {
 						$GLOBALS["bus"]->notify(bin2hex($parententryid), TABLE_SAVE, $messageProps);
