@@ -1,7 +1,55 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Mail Module
-	 * @author Johnny Biemans <j.biemans@connectux.com> 
 	 */
 	class MailListModule extends ListModule
 	{
@@ -37,7 +85,7 @@
 			$this->addColumn($this->tablecolumns, "hasattach", true, 2, _("Attachments"), _("Sort On Attachments"));
 			$this->addColumn($this->tablecolumns, "subject", true, 4, _("Subject"), _("Sort On Subject"), PERCENTAGE);
 			$this->addColumn($this->tablecolumns, "message_size", true, 6, _("Size"), _("Sort On Size"), 80);
-			$this->addColumn($this->tablecolumns, "flag_status", true, 7, _("Flag Status"), _("Sort On Flag Status"));
+			$this->addColumn($this->tablecolumns, "flag_icon", true, 7, _("Flag Status"), _("Sort On Flag Status"));
 			$this->addColumn($this->tablecolumns, "categories", false, 8, _("Categories"), _("Sort On Categories"));
 
 			// Columns & Sort: Mail Folders
@@ -61,6 +109,27 @@
 			$this->searchCriteriaCheck = false;
 		}
 
+		/**
+		 * Function which returns an entryid, which is used to register this module. 
+		 * The maillistmodule has a special feature that it supports an empty store 
+		 * entryid and folder entryid, which means the default inbox of your default 
+		 * store. This is used when opening the initial view when loggin on to the 
+		 * webaccess.
+		 * It first tries to use the normal Module::getEntryID method, but if that 
+		 * returns false it will look for the default values.
+		 * @return string an entryid if found, false if entryid not found.
+		 */
+		function getEntryID(){
+			$entryid = parent::getEntryID();
+			if(!$entryid) {
+				$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+				$inbox = mapi_msgstore_getreceivefolder($store);
+				$props = mapi_getprops($inbox, array(PR_ENTRYID));
+				$entryid = bin2hex($props[PR_ENTRYID]);
+			}
+			return $entryid;
+		}
+
 		/**
 		 * Executes all the actions in the $data variable.
 		 * @return boolean true on success of false on fialure.
@@ -68,22 +137,40 @@
 		function execute()
 		{
 			$result = false;
-		
+			$GLOBALS['PluginManager']->triggerHook("server.module.maillistmodule.execute.before", array('moduleObject' =>& $this));
+
 			foreach($this->data as $action)
 			{
 				if(isset($action["attributes"]) && isset($action["attributes"]["type"])) {
 					$store = $this->getActionStore($action);
 					$parententryid = $this->getActionParentEntryID($action);
 					$entryid = $this->getActionEntryID($action);
-				
+
 					switch($action["attributes"]["type"])
 					{
 						case "list":
-							if ($this->searchActive)
+							if ($this->searchActive) {
 								$result = $this->search($store, $entryid, $action);
-							else
-								$result = $this->messageList($store, $entryid, $action);
+							} else {
+								/**
+								 * The maillist module has a special feature that it supports an empty
+								 * store entryid and folder entryid, which means the default inbox
+								 * of your default store. This is used when opening the initial view
+								 * when logging on to the webaccess.
+								 * this feature is only needed when action type is list
+								 */
+								if(!$store) {
+									$store = $GLOBALS["mapisession"]->getDefaultMessageStore();
+								}
 
+								if(!$entryid) {
+									// The maillistmodule implements it's own getEntryID function, so 
+									// $this->entryid property should contain the correct entryid.
+									$entryid = hex2bin($this->entryid);
+								}
+
+								$result = $this->messageList($store, $entryid, $action);
+							}
 							break;
 						case "search":
 							$result = $this->search($store, $entryid, $action);
@@ -106,13 +193,13 @@
 						case "copy":
 							$result = $this->copy($store, $parententryid, $entryid, $action);
 							break;
-                        case "cancelInvitation":
-                            $GLOBALS["operations"]->cancelInvitation($store, $entryid);
-
-                            break;
+						case "cancelInvitation":
+							$GLOBALS["operations"]->cancelInvitation($store, $entryid);
+							break;
 					}
 				}
 			}
+			$GLOBALS['PluginManager']->triggerHook("server.module.maillistmodule.execute.after", array('moduleObject' =>& $this));
 			
 			return $result;
 		}
@@ -406,6 +493,11 @@
 			$props = mapi_getprops($store, array(PR_IPM_OUTBOX_ENTRYID, PR_IPM_SENTMAIL_ENTRYID));
 			$rootcontainer = mapi_msgstore_openentry($store);
 			$props = array_merge($props, mapi_getprops($rootcontainer, array(PR_IPM_DRAFTS_ENTRYID)));
+			
+			$inbox = mapi_msgstore_getreceivefolder($store);
+			$inboxprops = mapi_getprops($inbox, array(PR_ENTRYID));
+			$inboxentryid = $inboxprops[PR_ENTRYID];
+			
 			if(array_search($entryid, $props) !== false) {
 				if(($key = $this->getColumn($this->tablecolumns, "sent_representing_name")) !== false) {
 					$this->tablecolumns[$key]["visible"] = false;
@@ -454,6 +546,23 @@
 			$data["sort"]["attributes"]["direction"] = (isset($this->sort[$firstSortColumn]) && $this->sort[$firstSortColumn] == TABLE_SORT_ASCEND) ? "asc":"desc";
 			$data["sort"]["_content"] = array_search($firstSortColumn, $this->properties);
 				
+            // Return some information about the folder. The entryid and storeid may be unknown to the client if it passed
+            // an empty storeid and folder entryid.
+			$folder = mapi_msgstore_openentry($store, $entryid);
+			$folderprops = mapi_getprops($folder, array(PR_DISPLAY_NAME, PR_ENTRYID, PR_STORE_ENTRYID, PR_PARENT_ENTRYID));
+			
+			//check if the folder is not the root folder.
+			if($entryid != $folderprops[PR_ENTRYID]){
+				$data["folder_title"] = array();
+				$data["folder_title"]["_content"] = w2u($folderprops[PR_DISPLAY_NAME]);
+			}
+			$data["entryid"] = array();
+			$data["entryid"]["_content"] = bin2hex($folderprops[PR_ENTRYID]);
+			$data["storeid"] = array();
+			$data["storeid"]["_content"] = bin2hex($folderprops[PR_STORE_ENTRYID]);
+			$data["isinbox"] = array();
+			$data["isinbox"]["_content"] = $folderprops[PR_ENTRYID] == $inboxentryid;
+				
 			// Get the table and merge the arrays
 			$data = array_merge($data, $GLOBALS["operations"]->getTable($store, $entryid, $this->properties, $this->sort, $this->start, false, $this->searchRestriction));
 				
