@@ -1,8 +1,56 @@
+<?php
+/*
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License, version 3, 
+ * as published by the Free Software Foundation with the following additional 
+ * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
+ * 
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *  
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * 
+ */
+
+?>
 <?php
 	/**
 	 * Module
 	 * Superclass of every module. Many default functions are defined in this class.
-	 * @author Johnny Biemans <j.biemans@connectux.com>
 	 */
 	class Module
 	{
@@ -86,13 +134,12 @@
 		 */
 		function getEntryID()
 		{
-			$entryid = 0;
-			
+			$entryid = false;
 			foreach($this->data as $action)
 			{
-				if(isset($action["parententryid"])) {
+				if(isset($action["parententryid"]) && $action["parententryid"] != "") {
 					$entryid = $action["parententryid"];
-				} else if(isset($action["entryid"])) {
+				} else if(isset($action["entryid"]) && $action["entryid"] != "") {
 					$entryid = $action["entryid"];
 				}
 			}
@@ -157,8 +204,8 @@
 		function getActionStore($action)
 		{
 			$store = false;
-			
-			if(isset($action["store"])) {
+
+			if(isset($action["store"]) && $action["store"] != "") {
 				$store = $GLOBALS["mapisession"]->openMessageStore(hex2bin($action["store"]));
 			}
 			
@@ -175,7 +222,7 @@
 		{
 			$parententryid = false;
 			
-			if(isset($action["parententryid"])) {
+			if(isset($action["parententryid"]) && $action["parententryid"] != "") {
 				$parententryid = hex2bin($action["parententryid"]);
 			}
 			
@@ -192,13 +239,15 @@
 		{
 			$entryid = false;
 			
-			if(isset($action["entryid"]) && !is_array($action["entryid"])) {
-				$entryid = hex2bin($action["entryid"]);
-			} else if(isset($action["entryid"]) && is_array($action["entryid"])) {
-				$entryid = array();
-				foreach($action["entryid"] as $action_entryid)
-				{
-					array_push($entryid, hex2bin($action_entryid));
+			if(isset($action["entryid"]) && $action["entryid"] != "") {
+				if(!is_array($action["entryid"])) {
+					$entryid = hex2bin($action["entryid"]);
+				} else if(is_array($action["entryid"])) {
+					$entryid = array();
+					foreach($action["entryid"] as $action_entryid)
+					{
+						array_push($entryid, hex2bin($action_entryid));
+					}
 				}
 			}
 			
